@@ -386,6 +386,6 @@ Vivid = [
 # Prefix variable names with _ so that they will not be added to the swatches
 _contents = dict(globals())
 for _k, _cols in _contents.items():
-    if _k.startswith("_") or _k == "swatches" or _k.endswith("_r"):
+    if _k.startswith("_") or _k.startswith("swatches") or _k.endswith("_r"):
         continue
     globals()[_k + "_r"] = _cols[::-1]
