@@ -36,6 +36,7 @@ __all__ = [
     "label_rgb",
     "make_colorscale",
     "n_colors",
+    "sample_colorscale",
     "unconvert_from_RGB_255",
     "unlabel_rgb",
     "validate_colors",
@@ -45,4 +46,5 @@ __all__ = [
     "plotlyjs",
     "DEFAULT_PLOTLY_COLORS",
     "PLOTLY_SCALES",
+    "get_colorscale",
 ]
