@@ -46,7 +46,9 @@ def scatter(
     marginal_x=None,
     marginal_y=None,
     trendline=None,
+    trendline_options=None,
     trendline_color_override=None,
+    trendline_scope="trace",
     log_x=False,
     log_y=False,
     range_x=None,
@@ -90,7 +92,9 @@ def density_contour(
     marginal_x=None,
     marginal_y=None,
     trendline=None,
+    trendline_options=None,
     trendline_color_override=None,
+    trendline_scope="trace",
     log_x=False,
     log_y=False,
     range_x=None,
@@ -212,6 +216,7 @@ def line(
     line_group=None,
     color=None,
     line_dash=None,
+    symbol=None,
     hover_name=None,
     hover_data=None,
     custom_data=None,
@@ -234,6 +239,9 @@ def line(
     color_discrete_map=None,
     line_dash_sequence=None,
     line_dash_map=None,
+    symbol_sequence=None,
+    symbol_map=None,
+    markers=False,
     log_x=False,
     log_y=False,
     range_x=None,
@@ -261,6 +269,7 @@ def area(
     y=None,
     line_group=None,
     color=None,
+    symbol=None,
     hover_name=None,
     hover_data=None,
     custom_data=None,
@@ -276,6 +285,9 @@ def area(
     labels=None,
     color_discrete_sequence=None,
     color_discrete_map=None,
+    symbol_sequence=None,
+    symbol_map=None,
+    markers=False,
     orientation=None,
     groupnorm=None,
     log_x=False,
@@ -308,6 +320,7 @@ def bar(
     x=None,
     y=None,
     color=None,
+    pattern_shape=None,
     facet_row=None,
     facet_col=None,
     facet_col_wrap=0,
@@ -329,6 +342,8 @@ def bar(
     color_discrete_sequence=None,
     color_discrete_map=None,
     color_continuous_scale=None,
+    pattern_shape_sequence=None,
+    pattern_shape_map=None,
     range_color=None,
     color_continuous_midpoint=None,
     opacity=None,
@@ -410,6 +425,7 @@ def histogram(
     x=None,
     y=None,
     color=None,
+    pattern_shape=None,
     facet_row=None,
     facet_col=None,
     facet_col_wrap=0,
@@ -423,6 +439,8 @@ def histogram(
     labels=None,
     color_discrete_sequence=None,
     color_discrete_map=None,
+    pattern_shape_sequence=None,
+    pattern_shape_map=None,
     marginal=None,
     opacity=None,
     orientation=None,
@@ -471,6 +489,72 @@ histogram.__doc__ = make_docstring(
 )
 
 
+def ecdf(
+    data_frame=None,
+    x=None,
+    y=None,
+    color=None,
+    text=None,
+    line_dash=None,
+    symbol=None,
+    facet_row=None,
+    facet_col=None,
+    facet_col_wrap=0,
+    facet_row_spacing=None,
+    facet_col_spacing=None,
+    hover_name=None,
+    hover_data=None,
+    animation_frame=None,
+    animation_group=None,
+    markers=False,
+    lines=True,
+    category_orders=None,
+    labels=None,
+    color_discrete_sequence=None,
+    color_discrete_map=None,
+    line_dash_sequence=None,
+    line_dash_map=None,
+    symbol_sequence=None,
+    symbol_map=None,
+    marginal=None,
+    opacity=None,
+    orientation=None,
+    ecdfnorm="probability",
+    ecdfmode="standard",
+    render_mode="auto",
+    log_x=False,
+    log_y=False,
+    range_x=None,
+    range_y=None,
+    title=None,
+    template=None,
+    width=None,
+    height=None,
+):
+    """
+    In a Empirical Cumulative Distribution Function (ECDF) plot, rows of `data_frame`
+    are sorted by the value `x` (or `y` if `orientation` is `'h'`) and their cumulative
+    count (or the cumulative sum of `y` if supplied and `orientation` is `h`) is drawn
+    as a line.
+    """
+    return make_figure(args=locals(), constructor=go.Scatter)
+
+
+ecdf.__doc__ = make_docstring(
+    ecdf,
+    append_dict=dict(
+        x=[
+            "If `orientation` is `'h'`, the cumulative sum of this argument is plotted rather than the cumulative count."
+        ]
+        + _wide_mode_xy_append,
+        y=[
+            "If `orientation` is `'v'`, the cumulative sum of this argument is plotted rather than the cumulative count."
+        ]
+        + _wide_mode_xy_append,
+    ),
+)
+
+
 def violin(
     data_frame=None,
     x=None,
@@ -686,6 +770,7 @@ def line_3d(
     line_dash=None,
     text=None,
     line_group=None,
+    symbol=None,
     hover_name=None,
     hover_data=None,
     custom_data=None,
@@ -703,6 +788,9 @@ def line_3d(
     color_discrete_map=None,
     line_dash_sequence=None,
     line_dash_map=None,
+    symbol_sequence=None,
+    symbol_map=None,
+    markers=False,
     log_x=False,
     log_y=False,
     log_z=False,
@@ -772,6 +860,7 @@ def line_ternary(
     color=None,
     line_dash=None,
     line_group=None,
+    symbol=None,
     hover_name=None,
     hover_data=None,
     custom_data=None,
@@ -784,6 +873,9 @@ def line_ternary(
     color_discrete_map=None,
     line_dash_sequence=None,
     line_dash_map=None,
+    symbol_sequence=None,
+    symbol_map=None,
+    markers=False,
     line_shape=None,
     title=None,
     template=None,
@@ -856,6 +948,7 @@ def line_polar(
     custom_data=None,
     line_group=None,
     text=None,
+    symbol=None,
     animation_frame=None,
     animation_group=None,
     category_orders=None,
@@ -864,6 +957,9 @@ def line_polar(
     color_discrete_map=None,
     line_dash_sequence=None,
     line_dash_map=None,
+    symbol_sequence=None,
+    symbol_map=None,
+    markers=False,
     direction="clockwise",
     start_angle=90,
     line_close=False,
@@ -892,6 +988,7 @@ def bar_polar(
     r=None,
     theta=None,
     color=None,
+    pattern_shape=None,
     hover_name=None,
     hover_data=None,
     custom_data=None,
@@ -903,6 +1000,8 @@ def bar_polar(
     color_discrete_sequence=None,
     color_discrete_map=None,
     color_continuous_scale=None,
+    pattern_shape_sequence=None,
+    pattern_shape_map=None,
     range_color=None,
     color_continuous_midpoint=None,
     barnorm=None,
@@ -1058,6 +1157,7 @@ def line_geo(
     hover_data=None,
     custom_data=None,
     line_group=None,
+    symbol=None,
     animation_frame=None,
     animation_group=None,
     category_orders=None,
@@ -1066,6 +1166,9 @@ def line_geo(
     color_discrete_map=None,
     line_dash_sequence=None,
     line_dash_map=None,
+    symbol_sequence=None,
+    symbol_map=None,
+    markers=False,
     projection=None,
     scope=None,
     center=None,
@@ -1472,6 +1575,56 @@ def treemap(
 treemap.__doc__ = make_docstring(treemap)
 
 
+def icicle(
+    data_frame=None,
+    names=None,
+    values=None,
+    parents=None,
+    path=None,
+    ids=None,
+    color=None,
+    color_continuous_scale=None,
+    range_color=None,
+    color_continuous_midpoint=None,
+    color_discrete_sequence=None,
+    color_discrete_map=None,
+    hover_name=None,
+    hover_data=None,
+    custom_data=None,
+    labels=None,
+    title=None,
+    template=None,
+    width=None,
+    height=None,
+    branchvalues=None,
+    maxdepth=None,
+):
+    """
+    An icicle plot represents hierarchial data with adjoined rectangular
+    sectors that all cascade from root down to leaf in one direction.
+    """
+    if color_discrete_sequence is not None:
+        layout_patch = {"iciclecolorway": color_discrete_sequence}
+    else:
+        layout_patch = {}
+    if path is not None and (ids is not None or parents is not None):
+        raise ValueError(
+            "Either `path` should be provided, or `ids` and `parents`."
+            "These parameters are mutually exclusive and cannot be passed together."
+        )
+    if path is not None and branchvalues is None:
+        branchvalues = "total"
+    return make_figure(
+        args=locals(),
+        constructor=go.Icicle,
+        trace_patch=dict(branchvalues=branchvalues, maxdepth=maxdepth),
+        layout_patch=layout_patch,
+    )
+
+
+icicle.__doc__ = make_docstring(icicle)
+
+
 def funnel(
     data_frame=None,
     x=None,
