@@ -182,6 +182,11 @@ docs = dict(
         colref_desc,
         "Values from this column or array_like are used to assign symbols to marks.",
     ],
+    pattern_shape=[
+        colref_type,
+        colref_desc,
+        "Values from this column or array_like are used to assign pattern shapes to marks.",
+    ],
     size=[
         colref_type,
         colref_desc,
@@ -283,6 +288,18 @@ docs = dict(
         "Strings should define valid plotly.js dash-patterns.",
         "When `line_dash` is set, values in that column are assigned dash-patterns by cycling through `line_dash_sequence` in the order described in `category_orders`, unless the value of `line_dash` is a key in `line_dash_map`.",
     ],
+    pattern_shape_map=[
+        "dict with str keys and str values (default `{}`)",
+        "Strings values define plotly.js patterns-shapes.",
+        "Used to override `pattern_shape_sequences` to assign a specific patterns-shapes to lines corresponding with specific values.",
+        "Keys in `pattern_shape_map` should be values in the column denoted by `pattern_shape`.",
+        "Alternatively, if the values of `pattern_shape` are valid patterns-shapes names, the string `'identity'` may be passed to cause them to be used directly.",
+    ],
+    pattern_shape_sequence=[
+        "list of str",
+        "Strings should define valid plotly.js patterns-shapes.",
+        "When `pattern_shape` is set, values in that column are assigned patterns-shapes by cycling through `pattern_shape_sequence` in the order described in `category_orders`, unless the value of `pattern_shape` is a key in `pattern_shape_map`.",
+    ],
     color_discrete_sequence=[
         "list of str",
         "Strings should define valid CSS-colors.",
@@ -308,6 +325,11 @@ docs = dict(
         "Setting this value is recommended when using `plotly.express.colors.diverging` color scales as the inputs to `color_continuous_scale`.",
     ],
     size_max=["int (default `20`)", "Set the maximum mark size when using `size`."],
+    markers=["boolean (default `False`)", "If `True`, markers are shown on lines."],
+    lines=[
+        "boolean (default `True`)",
+        "If `False`, lines are not drawn (forced to `True` if `markers` is `False`).",
+    ],
     log_x=[
         "boolean (default `False`)",
         "If `True`, the x-axis is log-scaled in cartesian coordinates.",
@@ -384,14 +406,28 @@ docs = dict(
     ],
     trendline=[
         "str",
-        "One of `'ols'` or `'lowess'`.",
+        "One of `'ols'`, `'lowess'`, `'rolling'`, `'expanding'` or `'ewm'`.",
         "If `'ols'`, an Ordinary Least Squares regression line will be drawn for each discrete-color/symbol group.",
         "If `'lowess`', a Locally Weighted Scatterplot Smoothing line will be drawn for each discrete-color/symbol group.",
+        "If `'rolling`', a Rolling (e.g. rolling average, rolling median) line will be drawn for each discrete-color/symbol group.",
+        "If `'expanding`', an Expanding (e.g. expanding average, expanding sum) line will be drawn for each discrete-color/symbol group.",
+        "If `'ewm`', an Exponentially Weighted Moment (e.g. exponentially-weighted moving average) line will be drawn for each discrete-color/symbol group.",
+        "See the docstrings for the functions in `plotly.express.trendline_functions` for more details on these functions and how",
+        "to configure them with the `trendline_options` argument.",
+    ],
+    trendline_options=[
+        "dict",
+        "Options passed as the first argument to the function from `plotly.express.trendline_functions` ",
+        "named in the `trendline` argument.",
     ],
     trendline_color_override=[
         "str",
         "Valid CSS color.",
-        "If provided, and if `trendline` is set, all trendlines will be drawn in this color.",
+        "If provided, and if `trendline` is set, all trendlines will be drawn in this color rather than in the same color as the traces from which they draw their inputs.",
+    ],
+    trendline_scope=[
+        "str (one of `'trace'` or `'overall'`, default `'trace'`)",
+        "If `'trace'`, then one trendline is drawn per trace (i.e. per color, symbol, facet, animation frame etc) and if `'overall'` then one trendline is computed for the entire dataset, and replicated across all facets.",
     ],
     render_mode=[
         "str",
@@ -449,7 +485,7 @@ docs = dict(
         "str (default `'group'`)",
         "One of `'group'` or `'overlay'`",
         "In `'overlay'` mode, boxes are on drawn top of one another.",
-        "In `'group'` mode, baxes are placed beside each other.",
+        "In `'group'` mode, boxes are placed beside each other.",
     ],
     violinmode=[
         "str (default `'group'`)",
@@ -541,10 +577,26 @@ docs = dict(
         "Sets the number of rendered sectors from any given `level`. Set `maxdepth` to -1 to render all the"
         "levels in the hierarchy.",
     ],
+    ecdfnorm=[
+        "string or `None` (default `'probability'`)",
+        "One of `'probability'` or `'percent'`",
+        "If `None`, values will be raw counts or sums.",
+        "If `'probability', values will be probabilities normalized from 0 to 1.",
+        "If `'percent', values will be percentages normalized from 0 to 100.",
+    ],
+    ecdfmode=[
+        "string (default `'standard'`)",
+        "One of `'standard'`, `'complementary'` or `'reversed'`",
+        "If `'standard'`, the ECDF is plotted such that values represent data at or below the point.",
+        "If `'complementary'`, the CCDF is plotted such that values represent data above the point.",
+        "If `'reversed'`, a variant of the CCDF is plotted such that values represent data at or above the point.",
+    ],
 )
 
 
-def make_docstring(fn, override_dict={}, append_dict={}):
+def make_docstring(fn, override_dict=None, append_dict=None):
+    override_dict = {} if override_dict is None else override_dict
+    append_dict = {} if append_dict is None else append_dict
     tw = TextWrapper(width=75, initial_indent="    ", subsequent_indent="    ")
     result = (fn.__doc__ or "") + "\nParameters\n----------\n"
     for param in getfullargspec(fn)[0]:
