@@ -47,4 +47,6 @@ __all__ = [
     "plotlyjs",
     "DEFAULT_PLOTLY_COLORS",
     "PLOTLY_SCALES",
+    "get_colorscale",
+    "sample_colorscale",
 ]
