@@ -973,7 +973,7 @@ def create_gantt(
             raise exceptions.PlotlyError(
                 "Error. You have set colors to a dictionary but have not "
                 "picked an index. An index is required if you are "
-                "assigning colors to particular values in a dictioanry."
+                "assigning colors to particular values in a dictionary."
             )
         fig = gantt(
             chart,
