@@ -19,6 +19,7 @@ class Pointcloud(_BaseTraceType):
         "indices",
         "indicessrc",
         "legendgroup",
+        "legendgrouptitle",
         "legendrank",
         "marker",
         "meta",
@@ -75,8 +76,8 @@ class Pointcloud(_BaseTraceType):
     @property
     def customdatasrc(self):
         """
-        Sets the source reference on Chart Studio Cloud for  customdata
-        .
+        Sets the source reference on Chart Studio Cloud for
+        `customdata`.
     
         The 'customdatasrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -122,8 +123,8 @@ class Pointcloud(_BaseTraceType):
     @property
     def hoverinfosrc(self):
         """
-        Sets the source reference on Chart Studio Cloud for  hoverinfo
-        .
+        Sets the source reference on Chart Studio Cloud for
+        `hoverinfo`.
     
         The 'hoverinfosrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -158,19 +159,19 @@ class Pointcloud(_BaseTraceType):
                     more lines
                 alignsrc
                     Sets the source reference on Chart Studio Cloud
-                    for  align .
+                    for `align`.
                 bgcolor
                     Sets the background color of the hover labels
                     for this trace
                 bgcolorsrc
                     Sets the source reference on Chart Studio Cloud
-                    for  bgcolor .
+                    for `bgcolor`.
                 bordercolor
                     Sets the border color of the hover labels for
                     this trace.
                 bordercolorsrc
                     Sets the source reference on Chart Studio Cloud
-                    for  bordercolor .
+                    for `bordercolor`.
                 font
                     Sets the font used in hover labels.
                 namelength
@@ -185,7 +186,7 @@ class Pointcloud(_BaseTraceType):
                     ellipsis.
                 namelengthsrc
                     Sets the source reference on Chart Studio Cloud
-                    for  namelength .
+                    for `namelength`.
 
         Returns
         -------
@@ -224,7 +225,7 @@ class Pointcloud(_BaseTraceType):
     @property
     def idssrc(self):
         """
-        Sets the source reference on Chart Studio Cloud for  ids .
+        Sets the source reference on Chart Studio Cloud for `ids`.
     
         The 'idssrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -270,7 +271,7 @@ class Pointcloud(_BaseTraceType):
     @property
     def indicessrc(self):
         """
-        Sets the source reference on Chart Studio Cloud for  indices .
+        Sets the source reference on Chart Studio Cloud for `indices`.
     
         The 'indicessrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -308,6 +309,34 @@ class Pointcloud(_BaseTraceType):
     def legendgroup(self, val):
         self["legendgroup"] = val
 
+    # legendgrouptitle
+    # ----------------
+    @property
+    def legendgrouptitle(self):
+        """
+        The 'legendgrouptitle' property is an instance of Legendgrouptitle
+        that may be specified as:
+          - An instance of :class:`plotly.graph_objs.pointcloud.Legendgrouptitle`
+          - A dict of string/value properties that will be passed
+            to the Legendgrouptitle constructor
+    
+            Supported dict properties:
+                
+                font
+                    Sets this legend group's title font.
+                text
+                    Sets the title of the legend group.
+
+        Returns
+        -------
+        plotly.graph_objs.pointcloud.Legendgrouptitle
+        """
+        return self["legendgrouptitle"]
+
+    @legendgrouptitle.setter
+    def legendgrouptitle(self, val):
+        self["legendgrouptitle"] = val
+
     # legendrank
     # ----------
     @property
@@ -421,7 +450,7 @@ class Pointcloud(_BaseTraceType):
     @property
     def metasrc(self):
         """
-        Sets the source reference on Chart Studio Cloud for  meta .
+        Sets the source reference on Chart Studio Cloud for `meta`.
     
         The 'metasrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -564,7 +593,7 @@ class Pointcloud(_BaseTraceType):
     @property
     def textsrc(self):
         """
-        Sets the source reference on Chart Studio Cloud for  text .
+        Sets the source reference on Chart Studio Cloud for `text`.
     
         The 'textsrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -729,7 +758,7 @@ class Pointcloud(_BaseTraceType):
     @property
     def xboundssrc(self):
         """
-        Sets the source reference on Chart Studio Cloud for  xbounds .
+        Sets the source reference on Chart Studio Cloud for `xbounds`.
     
         The 'xboundssrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -749,7 +778,7 @@ class Pointcloud(_BaseTraceType):
     @property
     def xsrc(self):
         """
-        Sets the source reference on Chart Studio Cloud for  x .
+        Sets the source reference on Chart Studio Cloud for `x`.
     
         The 'xsrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -792,7 +821,7 @@ class Pointcloud(_BaseTraceType):
     @property
     def xysrc(self):
         """
-        Sets the source reference on Chart Studio Cloud for  xy .
+        Sets the source reference on Chart Studio Cloud for `xy`.
     
         The 'xysrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -879,7 +908,7 @@ class Pointcloud(_BaseTraceType):
     @property
     def yboundssrc(self):
         """
-        Sets the source reference on Chart Studio Cloud for  ybounds .
+        Sets the source reference on Chart Studio Cloud for `ybounds`.
     
         The 'yboundssrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -899,7 +928,7 @@ class Pointcloud(_BaseTraceType):
     @property
     def ysrc(self):
         """
-        Sets the source reference on Chart Studio Cloud for  y .
+        Sets the source reference on Chart Studio Cloud for `y`.
     
         The 'ysrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -932,7 +961,7 @@ class Pointcloud(_BaseTraceType):
             the markers DOM elements
         customdatasrc
             Sets the source reference on Chart Studio Cloud for
-            customdata .
+            `customdata`.
         hoverinfo
             Determines which trace information appear on hover. If
             `none` or `skip` are set, no information is displayed
@@ -940,7 +969,7 @@ class Pointcloud(_BaseTraceType):
             events are still fired.
         hoverinfosrc
             Sets the source reference on Chart Studio Cloud for
-            hoverinfo .
+            `hoverinfo`.
         hoverlabel
             :class:`plotly.graph_objects.pointcloud.Hoverlabel`
             instance or dict with compatible properties
@@ -950,7 +979,7 @@ class Pointcloud(_BaseTraceType):
             array of strings, not numbers or any other type.
         idssrc
             Sets the source reference on Chart Studio Cloud for
-            ids .
+            `ids`.
         indices
             A sequential value, 0..n, supply it to avoid creating
             this array inside plotting. If specified, it must be a
@@ -962,11 +991,14 @@ class Pointcloud(_BaseTraceType):
             it on each `Plotly.restyle()` call.
         indicessrc
             Sets the source reference on Chart Studio Cloud for
-            indices .
+            `indices`.
         legendgroup
             Sets the legend group for this trace. Traces part of
             the same legend group hide/show at the same time when
             toggling legend items.
+        legendgrouptitle
+            :class:`plotly.graph_objects.pointcloud.Legendgrouptitl
+            e` instance or dict with compatible properties
         legendrank
             Sets the legend rank for this trace. Items and groups
             with smaller ranks are presented on top/left side while
@@ -993,7 +1025,7 @@ class Pointcloud(_BaseTraceType):
             index.
         metasrc
             Sets the source reference on Chart Studio Cloud for
-            meta .
+            `meta`.
         name
             Sets the trace name. The trace name appear as the
             legend item and on hover.
@@ -1015,7 +1047,7 @@ class Pointcloud(_BaseTraceType):
             the hover labels.
         textsrc
             Sets the source reference on Chart Studio Cloud for
-            text .
+            `text`.
         uid
             Assign an id to this trace, Use this to provide object
             constancy between traces during animations and
@@ -1057,18 +1089,18 @@ class Pointcloud(_BaseTraceType):
             benefits.
         xboundssrc
             Sets the source reference on Chart Studio Cloud for
-            xbounds .
+            `xbounds`.
         xsrc
-            Sets the source reference on Chart Studio Cloud for  x
-            .
+            Sets the source reference on Chart Studio Cloud for
+            `x`.
         xy
             Faster alternative to specifying `x` and `y`
             separately. If supplied, it must be a typed
             `Float32Array` array that represents points such that
             `xy[i * 2] = x[i]` and `xy[i * 2 + 1] = y[i]`
         xysrc
-            Sets the source reference on Chart Studio Cloud for  xy
-            .
+            Sets the source reference on Chart Studio Cloud for
+            `xy`.
         y
             Sets the y coordinates.
         yaxis
@@ -1083,10 +1115,10 @@ class Pointcloud(_BaseTraceType):
             benefits.
         yboundssrc
             Sets the source reference on Chart Studio Cloud for
-            ybounds .
+            `ybounds`.
         ysrc
-            Sets the source reference on Chart Studio Cloud for  y
-            .
+            Sets the source reference on Chart Studio Cloud for
+            `y`.
         """
 
     def __init__(
@@ -1102,6 +1134,7 @@ class Pointcloud(_BaseTraceType):
         indices=None,
         indicessrc=None,
         legendgroup=None,
+        legendgrouptitle=None,
         legendrank=None,
         marker=None,
         meta=None,
@@ -1148,7 +1181,7 @@ class Pointcloud(_BaseTraceType):
             the markers DOM elements
         customdatasrc
             Sets the source reference on Chart Studio Cloud for
-            customdata .
+            `customdata`.
         hoverinfo
             Determines which trace information appear on hover. If
             `none` or `skip` are set, no information is displayed
@@ -1156,7 +1189,7 @@ class Pointcloud(_BaseTraceType):
             events are still fired.
         hoverinfosrc
             Sets the source reference on Chart Studio Cloud for
-            hoverinfo .
+            `hoverinfo`.
         hoverlabel
             :class:`plotly.graph_objects.pointcloud.Hoverlabel`
             instance or dict with compatible properties
@@ -1166,7 +1199,7 @@ class Pointcloud(_BaseTraceType):
             array of strings, not numbers or any other type.
         idssrc
             Sets the source reference on Chart Studio Cloud for
-            ids .
+            `ids`.
         indices
             A sequential value, 0..n, supply it to avoid creating
             this array inside plotting. If specified, it must be a
@@ -1178,11 +1211,14 @@ class Pointcloud(_BaseTraceType):
             it on each `Plotly.restyle()` call.
         indicessrc
             Sets the source reference on Chart Studio Cloud for
-            indices .
+            `indices`.
         legendgroup
             Sets the legend group for this trace. Traces part of
             the same legend group hide/show at the same time when
             toggling legend items.
+        legendgrouptitle
+            :class:`plotly.graph_objects.pointcloud.Legendgrouptitl
+            e` instance or dict with compatible properties
         legendrank
             Sets the legend rank for this trace. Items and groups
             with smaller ranks are presented on top/left side while
@@ -1209,7 +1245,7 @@ class Pointcloud(_BaseTraceType):
             index.
         metasrc
             Sets the source reference on Chart Studio Cloud for
-            meta .
+            `meta`.
         name
             Sets the trace name. The trace name appear as the
             legend item and on hover.
@@ -1231,7 +1267,7 @@ class Pointcloud(_BaseTraceType):
             the hover labels.
         textsrc
             Sets the source reference on Chart Studio Cloud for
-            text .
+            `text`.
         uid
             Assign an id to this trace, Use this to provide object
             constancy between traces during animations and
@@ -1273,18 +1309,18 @@ class Pointcloud(_BaseTraceType):
             benefits.
         xboundssrc
             Sets the source reference on Chart Studio Cloud for
-            xbounds .
+            `xbounds`.
         xsrc
-            Sets the source reference on Chart Studio Cloud for  x
-            .
+            Sets the source reference on Chart Studio Cloud for
+            `x`.
         xy
             Faster alternative to specifying `x` and `y`
             separately. If supplied, it must be a typed
             `Float32Array` array that represents points such that
             `xy[i * 2] = x[i]` and `xy[i * 2 + 1] = y[i]`
         xysrc
-            Sets the source reference on Chart Studio Cloud for  xy
-            .
+            Sets the source reference on Chart Studio Cloud for
+            `xy`.
         y
             Sets the y coordinates.
         yaxis
@@ -1299,10 +1335,10 @@ class Pointcloud(_BaseTraceType):
             benefits.
         yboundssrc
             Sets the source reference on Chart Studio Cloud for
-            ybounds .
+            `ybounds`.
         ysrc
-            Sets the source reference on Chart Studio Cloud for  y
-            .
+            Sets the source reference on Chart Studio Cloud for
+            `y`.
 
         Returns
         -------
@@ -1377,6 +1413,10 @@ an instance of :class:`plotly.graph_objs.Pointcloud`"""
         _v = legendgroup if legendgroup is not None else _v
         if _v is not None:
             self["legendgroup"] = _v
+        _v = arg.pop("legendgrouptitle", None)
+        _v = legendgrouptitle if legendgrouptitle is not None else _v
+        if _v is not None:
+            self["legendgrouptitle"] = _v
         _v = arg.pop("legendrank", None)
         _v = legendrank if legendrank is not None else _v
         if _v is not None:
