@@ -371,17 +371,17 @@ class Marker(_BaseTraceHierarchyType):
                 tickformat
                     Sets the tick label formatting rule using d3
                     formatting mini-languages which are very
-                    similar to those in Python. For numbers, see:
-                    https://github.com/d3/d3-3.x-api-
-                    reference/blob/master/Formatting.md#d3_format.
-                    And for dates see:
+                    similar to those in Python. For numbers, see: h
+                    ttps://github.com/d3/d3-format/tree/v1.4.5#d3-f
+                    ormat. And for dates see:
                     https://github.com/d3/d3-time-
-                    format#locale_format. We add two items to d3's
-                    date formatter: "%h" for half of the year as a
-                    decimal number as well as "%{n}f" for
-                    fractional seconds with n digits. For example,
-                    *2016-10-13 09:15:23.456* with tickformat
-                    "%H~%M~%S.%2f" would display "09~15~23.46"
+                    format/tree/v2.2.3#locale_format. We add two
+                    items to d3's date formatter: "%h" for half of
+                    the year as a decimal number as well as "%{n}f"
+                    for fractional seconds with n digits. For
+                    example, *2016-10-13 09:15:23.456* with
+                    tickformat "%H~%M~%S.%2f" would display
+                    "09~15~23.46"
                 tickformatstops
                     A tuple of :class:`plotly.graph_objects.bar.mar
                     ker.colorbar.Tickformatstop` instances or dicts
@@ -428,14 +428,14 @@ class Marker(_BaseTraceHierarchyType):
                     `tickvals`.
                 ticktextsrc
                     Sets the source reference on Chart Studio Cloud
-                    for  ticktext .
+                    for `ticktext`.
                 tickvals
                     Sets the values at which ticks on this axis
                     appear. Only has an effect if `tickmode` is set
                     to "array". Used with `ticktext`.
                 tickvalssrc
                     Sets the source reference on Chart Studio Cloud
-                    for  tickvals .
+                    for `tickvals`.
                 tickwidth
                     Sets the tick width (in px).
                 title
@@ -500,9 +500,9 @@ class Marker(_BaseTraceHierarchyType):
         example, `[[0, 'rgb(0,0,255)'], [1, 'rgb(255,0,0)']]`. To
         control the bounds of the colorscale in color space,
         use`marker.cmin` and `marker.cmax`. Alternatively, `colorscale`
-        may be a palette name string of the following list: Greys,YlGnB
-        u,Greens,YlOrRd,Bluered,RdBu,Reds,Blues,Picnic,Rainbow,Portland
-        ,Jet,Hot,Blackbody,Earth,Electric,Viridis,Cividis.
+        may be a palette name string of the following list: Blackbody,B
+        luered,Blues,Cividis,Earth,Electric,Greens,Greys,Hot,Jet,Picnic
+        ,Portland,Rainbow,RdBu,Reds,Viridis,YlGnBu,YlOrRd.
     
         The 'colorscale' property is a colorscale and may be
         specified as:
@@ -546,7 +546,7 @@ class Marker(_BaseTraceHierarchyType):
     @property
     def colorsrc(self):
         """
-        Sets the source reference on Chart Studio Cloud for  color .
+        Sets the source reference on Chart Studio Cloud for `color`.
     
         The 'colorsrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -643,12 +643,12 @@ class Marker(_BaseTraceHierarchyType):
                     color space, use`marker.line.cmin` and
                     `marker.line.cmax`. Alternatively, `colorscale`
                     may be a palette name string of the following
-                    list: Greys,YlGnBu,Greens,YlOrRd,Bluered,RdBu,R
-                    eds,Blues,Picnic,Rainbow,Portland,Jet,Hot,Black
-                    body,Earth,Electric,Viridis,Cividis.
+                    list: Blackbody,Bluered,Blues,Cividis,Earth,Ele
+                    ctric,Greens,Greys,Hot,Jet,Picnic,Portland,Rain
+                    bow,RdBu,Reds,Viridis,YlGnBu,YlOrRd.
                 colorsrc
                     Sets the source reference on Chart Studio Cloud
-                    for  color .
+                    for `color`.
                 reversescale
                     Reverses the color mapping if true. Has an
                     effect only if in `marker.line.color`is set to
@@ -661,7 +661,7 @@ class Marker(_BaseTraceHierarchyType):
                     the marker points.
                 widthsrc
                     Sets the source reference on Chart Studio Cloud
-                    for  width .
+                    for `width`.
 
         Returns
         -------
@@ -699,7 +699,7 @@ class Marker(_BaseTraceHierarchyType):
     @property
     def opacitysrc(self):
         """
-        Sets the source reference on Chart Studio Cloud for  opacity .
+        Sets the source reference on Chart Studio Cloud for `opacity`.
     
         The 'opacitysrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -737,7 +737,7 @@ class Marker(_BaseTraceHierarchyType):
                     background.
                 bgcolorsrc
                     Sets the source reference on Chart Studio Cloud
-                    for  bgcolor .
+                    for `bgcolor`.
                 fgcolor
                     When there is no colorscale sets the color of
                     foreground pattern fill. Defaults to a
@@ -746,7 +746,7 @@ class Marker(_BaseTraceHierarchyType):
                     white to increase contrast with the `bgcolor`.
                 fgcolorsrc
                     Sets the source reference on Chart Studio Cloud
-                    for  fgcolor .
+                    for `fgcolor`.
                 fgopacity
                     Sets the opacity of the foreground pattern
                     fill. Defaults to a 0.5 when `fillmode` is
@@ -759,14 +759,14 @@ class Marker(_BaseTraceHierarchyType):
                     no pattern is used for filling the area.
                 shapesrc
                     Sets the source reference on Chart Studio Cloud
-                    for  shape .
+                    for `shape`.
                 size
                     Sets the size of unit squares of the pattern
                     fill in pixels, which corresponds to the
                     interval of repetition of the pattern.
                 sizesrc
                     Sets the source reference on Chart Studio Cloud
-                    for  size .
+                    for `size`.
                 solidity
                     Sets the solidity of the pattern fill. Solidity
                     is roughly the fraction of the area filled by
@@ -776,7 +776,7 @@ class Marker(_BaseTraceHierarchyType):
                     pattern.
                 soliditysrc
                     Sets the source reference on Chart Studio Cloud
-                    for  solidity .
+                    for `solidity`.
 
         Returns
         -------
@@ -898,12 +898,12 @@ class Marker(_BaseTraceHierarchyType):
             To control the bounds of the colorscale in color space,
             use`marker.cmin` and `marker.cmax`. Alternatively,
             `colorscale` may be a palette name string of the
-            following list: Greys,YlGnBu,Greens,YlOrRd,Bluered,RdBu
-            ,Reds,Blues,Picnic,Rainbow,Portland,Jet,Hot,Blackbody,E
-            arth,Electric,Viridis,Cividis.
+            following list: Blackbody,Bluered,Blues,Cividis,Earth,E
+            lectric,Greens,Greys,Hot,Jet,Picnic,Portland,Rainbow,Rd
+            Bu,Reds,Viridis,YlGnBu,YlOrRd.
         colorsrc
             Sets the source reference on Chart Studio Cloud for
-            color .
+            `color`.
         line
             :class:`plotly.graph_objects.bar.marker.Line` instance
             or dict with compatible properties
@@ -911,7 +911,7 @@ class Marker(_BaseTraceHierarchyType):
             Sets the opacity of the bars.
         opacitysrc
             Sets the source reference on Chart Studio Cloud for
-            opacity .
+            `opacity`.
         pattern
             Sets the pattern within the marker.
         reversescale
@@ -1015,12 +1015,12 @@ class Marker(_BaseTraceHierarchyType):
             To control the bounds of the colorscale in color space,
             use`marker.cmin` and `marker.cmax`. Alternatively,
             `colorscale` may be a palette name string of the
-            following list: Greys,YlGnBu,Greens,YlOrRd,Bluered,RdBu
-            ,Reds,Blues,Picnic,Rainbow,Portland,Jet,Hot,Blackbody,E
-            arth,Electric,Viridis,Cividis.
+            following list: Blackbody,Bluered,Blues,Cividis,Earth,E
+            lectric,Greens,Greys,Hot,Jet,Picnic,Portland,Rainbow,Rd
+            Bu,Reds,Viridis,YlGnBu,YlOrRd.
         colorsrc
             Sets the source reference on Chart Studio Cloud for
-            color .
+            `color`.
         line
             :class:`plotly.graph_objects.bar.marker.Line` instance
             or dict with compatible properties
@@ -1028,7 +1028,7 @@ class Marker(_BaseTraceHierarchyType):
             Sets the opacity of the bars.
         opacitysrc
             Sets the source reference on Chart Studio Cloud for
-            opacity .
+            `opacity`.
         pattern
             Sets the pattern within the marker.
         reversescale
