@@ -429,14 +429,14 @@ class Marker(_BaseTraceHierarchyType):
                     `tickvals`.
                 ticktextsrc
                     Sets the source reference on Chart Studio Cloud
-                    for  ticktext .
+                    for `ticktext`.
                 tickvals
                     Sets the values at which ticks on this axis
                     appear. Only has an effect if `tickmode` is set
                     to "array". Used with `ticktext`.
                 tickvalssrc
                     Sets the source reference on Chart Studio Cloud
-                    for  tickvals .
+                    for `tickvals`.
                 tickwidth
                     Sets the tick width (in px).
                 title
@@ -547,7 +547,7 @@ class Marker(_BaseTraceHierarchyType):
     @property
     def colorsrc(self):
         """
-        Sets the source reference on Chart Studio Cloud for  color .
+        Sets the source reference on Chart Studio Cloud for `color`.
     
         The 'colorsrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -649,7 +649,7 @@ class Marker(_BaseTraceHierarchyType):
                     bow,RdBu,Reds,Viridis,YlGnBu,YlOrRd.
                 colorsrc
                     Sets the source reference on Chart Studio Cloud
-                    for  color .
+                    for `color`.
                 reversescale
                     Reverses the color mapping if true. Has an
                     effect only if in `marker.line.color`is set to
@@ -662,7 +662,7 @@ class Marker(_BaseTraceHierarchyType):
                     the marker points.
                 widthsrc
                     Sets the source reference on Chart Studio Cloud
-                    for  width .
+                    for `width`.
 
         Returns
         -------
@@ -700,7 +700,7 @@ class Marker(_BaseTraceHierarchyType):
     @property
     def opacitysrc(self):
         """
-        Sets the source reference on Chart Studio Cloud for  opacity .
+        Sets the source reference on Chart Studio Cloud for `opacity`.
     
         The 'opacitysrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -738,7 +738,7 @@ class Marker(_BaseTraceHierarchyType):
                     background.
                 bgcolorsrc
                     Sets the source reference on Chart Studio Cloud
-                    for  bgcolor .
+                    for `bgcolor`.
                 fgcolor
                     When there is no colorscale sets the color of
                     foreground pattern fill. Defaults to a
@@ -747,7 +747,7 @@ class Marker(_BaseTraceHierarchyType):
                     white to increase contrast with the `bgcolor`.
                 fgcolorsrc
                     Sets the source reference on Chart Studio Cloud
-                    for  fgcolor .
+                    for `fgcolor`.
                 fgopacity
                     Sets the opacity of the foreground pattern
                     fill. Defaults to a 0.5 when `fillmode` is
@@ -760,14 +760,14 @@ class Marker(_BaseTraceHierarchyType):
                     no pattern is used for filling the area.
                 shapesrc
                     Sets the source reference on Chart Studio Cloud
-                    for  shape .
+                    for `shape`.
                 size
                     Sets the size of unit squares of the pattern
                     fill in pixels, which corresponds to the
                     interval of repetition of the pattern.
                 sizesrc
                     Sets the source reference on Chart Studio Cloud
-                    for  size .
+                    for `size`.
                 solidity
                     Sets the solidity of the pattern fill. Solidity
                     is roughly the fraction of the area filled by
@@ -777,7 +777,7 @@ class Marker(_BaseTraceHierarchyType):
                     pattern.
                 soliditysrc
                     Sets the source reference on Chart Studio Cloud
-                    for  solidity .
+                    for `solidity`.
 
         Returns
         -------
@@ -904,7 +904,7 @@ class Marker(_BaseTraceHierarchyType):
             Bu,Reds,Viridis,YlGnBu,YlOrRd.
         colorsrc
             Sets the source reference on Chart Studio Cloud for
-            color .
+            `color`.
         line
             :class:`plotly.graph_objects.barpolar.marker.Line`
             instance or dict with compatible properties
@@ -912,7 +912,7 @@ class Marker(_BaseTraceHierarchyType):
             Sets the opacity of the bars.
         opacitysrc
             Sets the source reference on Chart Studio Cloud for
-            opacity .
+            `opacity`.
         pattern
             Sets the pattern within the marker.
         reversescale
@@ -1022,7 +1022,7 @@ class Marker(_BaseTraceHierarchyType):
             Bu,Reds,Viridis,YlGnBu,YlOrRd.
         colorsrc
             Sets the source reference on Chart Studio Cloud for
-            color .
+            `color`.
         line
             :class:`plotly.graph_objects.barpolar.marker.Line`
             instance or dict with compatible properties
@@ -1030,7 +1030,7 @@ class Marker(_BaseTraceHierarchyType):
             Sets the opacity of the bars.
         opacitysrc
             Sets the source reference on Chart Studio Cloud for
-            opacity .
+            `opacity`.
         pattern
             Sets the pattern within the marker.
         reversescale
