@@ -78,7 +78,7 @@ class Line(_BaseTraceHierarchyType):
     @property
     def colorsrc(self):
         """
-        Sets the source reference on Chart Studio Cloud for  color .
+        Sets the source reference on Chart Studio Cloud for `color`.
     
         The 'colorsrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -119,7 +119,7 @@ class Line(_BaseTraceHierarchyType):
     @property
     def widthsrc(self):
         """
-        Sets the source reference on Chart Studio Cloud for  width .
+        Sets the source reference on Chart Studio Cloud for `width`.
     
         The 'widthsrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -147,13 +147,13 @@ class Line(_BaseTraceHierarchyType):
             `marker.line.cmax` if set.
         colorsrc
             Sets the source reference on Chart Studio Cloud for
-            color .
+            `color`.
         width
             Sets the width (in px) of the lines bounding the marker
             points.
         widthsrc
             Sets the source reference on Chart Studio Cloud for
-            width .
+            `width`.
         """
 
     def __init__(
@@ -176,13 +176,13 @@ class Line(_BaseTraceHierarchyType):
             `marker.line.cmax` if set.
         colorsrc
             Sets the source reference on Chart Studio Cloud for
-            color .
+            `color`.
         width
             Sets the width (in px) of the lines bounding the marker
             points.
         widthsrc
             Sets the source reference on Chart Studio Cloud for
-            width .
+            `width`.
 
         Returns
         -------
