@@ -121,9 +121,9 @@ class Contours(_BaseTraceHierarchyType):
     def labelformat(self):
         """
         Sets the contour label formatting rule using d3 formatting
-        mini-language which is very similar to Python, see:
-        https://github.com/d3/d3-3.x-api-
-        reference/blob/master/Formatting.md#d3_format
+        mini-languages which are very similar to those in Python. For
+        numbers, see:
+        https://github.com/d3/d3-format/tree/v1.4.5#d3-format.
     
         The 'labelformat' property is a string and must be specified as:
           - A string
@@ -320,9 +320,9 @@ class Contours(_BaseTraceHierarchyType):
             default family and size come from `layout.font`.
         labelformat
             Sets the contour label formatting rule using d3
-            formatting mini-language which is very similar to
-            Python, see: https://github.com/d3/d3-3.x-api-
-            reference/blob/master/Formatting.md#d3_format
+            formatting mini-languages which are very similar to
+            those in Python. For numbers, see:
+            https://github.com/d3/d3-format/tree/v1.4.5#d3-format.
         operation
             Sets the constraint operation. "=" keeps regions equal
             to `value` "<" and "<=" keep regions less than `value`
@@ -401,9 +401,9 @@ class Contours(_BaseTraceHierarchyType):
             default family and size come from `layout.font`.
         labelformat
             Sets the contour label formatting rule using d3
-            formatting mini-language which is very similar to
-            Python, see: https://github.com/d3/d3-3.x-api-
-            reference/blob/master/Formatting.md#d3_format
+            formatting mini-languages which are very similar to
+            those in Python. For numbers, see:
+            https://github.com/d3/d3-format/tree/v1.4.5#d3-format.
         operation
             Sets the constraint operation. "=" keeps regions equal
             to `value` "<" and "<=" keep regions less than `value`
