@@ -370,16 +370,17 @@ class Marker(_BaseTraceHierarchyType):
                 tickformat
                     Sets the tick label formatting rule using d3
                     formatting mini-languages which are very
-                    similar to those in Python. For numbers, see:
-                    https://github.com/d3/d3-3.x-api-
-                    reference/blob/master/Formatting.md#d3_format
-                    And for dates see:
+                    similar to those in Python. For numbers, see: h
+                    ttps://github.com/d3/d3-format/tree/v1.4.5#d3-f
+                    ormat. And for dates see:
                     https://github.com/d3/d3-time-
-                    format#locale_format We add one item to d3's
-                    date formatter: "%{n}f" for fractional seconds
-                    with n digits. For example, *2016-10-13
-                    09:15:23.456* with tickformat "%H~%M~%S.%2f"
-                    would display "09~15~23.46"
+                    format/tree/v2.2.3#locale_format. We add two
+                    items to d3's date formatter: "%h" for half of
+                    the year as a decimal number as well as "%{n}f"
+                    for fractional seconds with n digits. For
+                    example, *2016-10-13 09:15:23.456* with
+                    tickformat "%H~%M~%S.%2f" would display
+                    "09~15~23.46"
                 tickformatstops
                     A tuple of :class:`plotly.graph_objects.funnel.
                     marker.colorbar.Tickformatstop` instances or
@@ -390,6 +391,12 @@ class Marker(_BaseTraceHierarchyType):
                     ), sets the default property values to use for
                     elements of
                     funnel.marker.colorbar.tickformatstops
+                ticklabeloverflow
+                    Determines how we handle tick labels that would
+                    overflow either the graph div or the domain of
+                    the axis. The default value for inside tick
+                    labels is *hide past domain*. In other cases
+                    the default is *hide past div*.
                 ticklabelposition
                     Determines where tick labels are drawn.
                 ticklen
@@ -421,14 +428,14 @@ class Marker(_BaseTraceHierarchyType):
                     `tickvals`.
                 ticktextsrc
                     Sets the source reference on Chart Studio Cloud
-                    for  ticktext .
+                    for `ticktext`.
                 tickvals
                     Sets the values at which ticks on this axis
                     appear. Only has an effect if `tickmode` is set
                     to "array". Used with `ticktext`.
                 tickvalssrc
                     Sets the source reference on Chart Studio Cloud
-                    for  tickvals .
+                    for `tickvals`.
                 tickwidth
                     Sets the tick width (in px).
                 title
@@ -493,9 +500,9 @@ class Marker(_BaseTraceHierarchyType):
         example, `[[0, 'rgb(0,0,255)'], [1, 'rgb(255,0,0)']]`. To
         control the bounds of the colorscale in color space,
         use`marker.cmin` and `marker.cmax`. Alternatively, `colorscale`
-        may be a palette name string of the following list: Greys,YlGnB
-        u,Greens,YlOrRd,Bluered,RdBu,Reds,Blues,Picnic,Rainbow,Portland
-        ,Jet,Hot,Blackbody,Earth,Electric,Viridis,Cividis.
+        may be a palette name string of the following list: Blackbody,B
+        luered,Blues,Cividis,Earth,Electric,Greens,Greys,Hot,Jet,Picnic
+        ,Portland,Rainbow,RdBu,Reds,Viridis,YlGnBu,YlOrRd.
     
         The 'colorscale' property is a colorscale and may be
         specified as:
@@ -539,7 +546,7 @@ class Marker(_BaseTraceHierarchyType):
     @property
     def colorsrc(self):
         """
-        Sets the source reference on Chart Studio Cloud for  color .
+        Sets the source reference on Chart Studio Cloud for `color`.
     
         The 'colorsrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -636,12 +643,12 @@ class Marker(_BaseTraceHierarchyType):
                     color space, use`marker.line.cmin` and
                     `marker.line.cmax`. Alternatively, `colorscale`
                     may be a palette name string of the following
-                    list: Greys,YlGnBu,Greens,YlOrRd,Bluered,RdBu,R
-                    eds,Blues,Picnic,Rainbow,Portland,Jet,Hot,Black
-                    body,Earth,Electric,Viridis,Cividis.
+                    list: Blackbody,Bluered,Blues,Cividis,Earth,Ele
+                    ctric,Greens,Greys,Hot,Jet,Picnic,Portland,Rain
+                    bow,RdBu,Reds,Viridis,YlGnBu,YlOrRd.
                 colorsrc
                     Sets the source reference on Chart Studio Cloud
-                    for  color .
+                    for `color`.
                 reversescale
                     Reverses the color mapping if true. Has an
                     effect only if in `marker.line.color`is set to
@@ -654,7 +661,7 @@ class Marker(_BaseTraceHierarchyType):
                     the marker points.
                 widthsrc
                     Sets the source reference on Chart Studio Cloud
-                    for  width .
+                    for `width`.
 
         Returns
         -------
@@ -692,7 +699,7 @@ class Marker(_BaseTraceHierarchyType):
     @property
     def opacitysrc(self):
         """
-        Sets the source reference on Chart Studio Cloud for  opacity .
+        Sets the source reference on Chart Studio Cloud for `opacity`.
     
         The 'opacitysrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -817,12 +824,12 @@ class Marker(_BaseTraceHierarchyType):
             To control the bounds of the colorscale in color space,
             use`marker.cmin` and `marker.cmax`. Alternatively,
             `colorscale` may be a palette name string of the
-            following list: Greys,YlGnBu,Greens,YlOrRd,Bluered,RdBu
-            ,Reds,Blues,Picnic,Rainbow,Portland,Jet,Hot,Blackbody,E
-            arth,Electric,Viridis,Cividis.
+            following list: Blackbody,Bluered,Blues,Cividis,Earth,E
+            lectric,Greens,Greys,Hot,Jet,Picnic,Portland,Rainbow,Rd
+            Bu,Reds,Viridis,YlGnBu,YlOrRd.
         colorsrc
             Sets the source reference on Chart Studio Cloud for
-            color .
+            `color`.
         line
             :class:`plotly.graph_objects.funnel.marker.Line`
             instance or dict with compatible properties
@@ -830,7 +837,7 @@ class Marker(_BaseTraceHierarchyType):
             Sets the opacity of the bars.
         opacitysrc
             Sets the source reference on Chart Studio Cloud for
-            opacity .
+            `opacity`.
         reversescale
             Reverses the color mapping if true. Has an effect only
             if in `marker.color`is set to a numerical array. If
@@ -931,12 +938,12 @@ class Marker(_BaseTraceHierarchyType):
             To control the bounds of the colorscale in color space,
             use`marker.cmin` and `marker.cmax`. Alternatively,
             `colorscale` may be a palette name string of the
-            following list: Greys,YlGnBu,Greens,YlOrRd,Bluered,RdBu
-            ,Reds,Blues,Picnic,Rainbow,Portland,Jet,Hot,Blackbody,E
-            arth,Electric,Viridis,Cividis.
+            following list: Blackbody,Bluered,Blues,Cividis,Earth,E
+            lectric,Greens,Greys,Hot,Jet,Picnic,Portland,Rainbow,Rd
+            Bu,Reds,Viridis,YlGnBu,YlOrRd.
         colorsrc
             Sets the source reference on Chart Studio Cloud for
-            color .
+            `color`.
         line
             :class:`plotly.graph_objects.funnel.marker.Line`
             instance or dict with compatible properties
@@ -944,7 +951,7 @@ class Marker(_BaseTraceHierarchyType):
             Sets the opacity of the bars.
         opacitysrc
             Sets the source reference on Chart Studio Cloud for
-            opacity .
+            `opacity`.
         reversescale
             Reverses the color mapping if true. Has an effect only
             if in `marker.color`is set to a numerical array. If
