@@ -4,6 +4,7 @@ if sys.version_info < (3, 7):
     from ._colorbar import ColorBar
     from ._contours import Contours
     from ._hoverlabel import Hoverlabel
+    from ._legendgrouptitle import Legendgrouptitle
     from ._line import Line
     from ._marker import Marker
     from ._stream import Stream
@@ -12,16 +13,18 @@ if sys.version_info < (3, 7):
     from . import colorbar
     from . import contours
     from . import hoverlabel
+    from . import legendgrouptitle
 else:
     from _plotly_utils.importers import relative_import
 
     __all__, __getattr__, __dir__ = relative_import(
         __name__,
-        [".colorbar", ".contours", ".hoverlabel"],
+        [".colorbar", ".contours", ".hoverlabel", ".legendgrouptitle"],
         [
             "._colorbar.ColorBar",
             "._contours.Contours",
             "._hoverlabel.Hoverlabel",
+            "._legendgrouptitle.Legendgrouptitle",
             "._line.Line",
             "._marker.Marker",
             "._stream.Stream",
