@@ -73,7 +73,7 @@ class Font(_BaseTraceHierarchyType):
     @property
     def colorsrc(self):
         """
-        Sets the source reference on Chart Studio Cloud for  color .
+        Sets the source reference on Chart Studio Cloud for `color`.
     
         The 'colorsrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -125,7 +125,7 @@ class Font(_BaseTraceHierarchyType):
     @property
     def familysrc(self):
         """
-        Sets the source reference on Chart Studio Cloud for  family .
+        Sets the source reference on Chart Studio Cloud for `family`.
     
         The 'familysrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -164,7 +164,7 @@ class Font(_BaseTraceHierarchyType):
     @property
     def sizesrc(self):
         """
-        Sets the source reference on Chart Studio Cloud for  size .
+        Sets the source reference on Chart Studio Cloud for `size`.
     
         The 'sizesrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -188,7 +188,7 @@ class Font(_BaseTraceHierarchyType):
 
         colorsrc
             Sets the source reference on Chart Studio Cloud for
-            color .
+            `color`.
         family
             HTML font family - the typeface that will be applied by
             the web browser. The web browser will only be able to
@@ -205,12 +205,12 @@ class Font(_BaseTraceHierarchyType):
             Sans Narrow", "Raleway", "Times New Roman".
         familysrc
             Sets the source reference on Chart Studio Cloud for
-            family .
+            `family`.
         size
 
         sizesrc
             Sets the source reference on Chart Studio Cloud for
-            size .
+            `size`.
         """
 
     def __init__(
@@ -239,7 +239,7 @@ class Font(_BaseTraceHierarchyType):
 
         colorsrc
             Sets the source reference on Chart Studio Cloud for
-            color .
+            `color`.
         family
             HTML font family - the typeface that will be applied by
             the web browser. The web browser will only be able to
@@ -256,12 +256,12 @@ class Font(_BaseTraceHierarchyType):
             Sans Narrow", "Raleway", "Times New Roman".
         familysrc
             Sets the source reference on Chart Studio Cloud for
-            family .
+            `family`.
         size
 
         sizesrc
             Sets the source reference on Chart Studio Cloud for
-            size .
+            `size`.
 
         Returns
         -------
