@@ -189,8 +189,8 @@ class Delta(_BaseTraceHierarchyType):
         """
         Sets the value formatting rule using d3 formatting mini-
         languages which are very similar to those in Python. For
-        numbers, see: https://github.com/d3/d3-3.x-api-
-        reference/blob/master/Formatting.md#d3_format.
+        numbers, see:
+        https://github.com/d3/d3-format/tree/v1.4.5#d3-format.
     
         The 'valueformat' property is a string and must be specified as:
           - A string
@@ -230,8 +230,7 @@ class Delta(_BaseTraceHierarchyType):
             Sets the value formatting rule using d3 formatting
             mini-languages which are very similar to those in
             Python. For numbers, see:
-            https://github.com/d3/d3-3.x-api-
-            reference/blob/master/Formatting.md#d3_format.
+            https://github.com/d3/d3-format/tree/v1.4.5#d3-format.
         """
 
     def __init__(
@@ -274,8 +273,7 @@ class Delta(_BaseTraceHierarchyType):
             Sets the value formatting rule using d3 formatting
             mini-languages which are very similar to those in
             Python. For numbers, see:
-            https://github.com/d3/d3-3.x-api-
-            reference/blob/master/Formatting.md#d3_format.
+            https://github.com/d3/d3-format/tree/v1.4.5#d3-format.
 
         Returns
         -------
