@@ -105,8 +105,8 @@ class Number(_BaseTraceHierarchyType):
         """
         Sets the value formatting rule using d3 formatting mini-
         languages which are very similar to those in Python. For
-        numbers, see: https://github.com/d3/d3-3.x-api-
-        reference/blob/master/Formatting.md#d3_format.
+        numbers, see:
+        https://github.com/d3/d3-format/tree/v1.4.5#d3-format.
     
         The 'valueformat' property is a string and must be specified as:
           - A string
@@ -137,8 +137,7 @@ class Number(_BaseTraceHierarchyType):
             Sets the value formatting rule using d3 formatting
             mini-languages which are very similar to those in
             Python. For numbers, see:
-            https://github.com/d3/d3-3.x-api-
-            reference/blob/master/Formatting.md#d3_format.
+            https://github.com/d3/d3-format/tree/v1.4.5#d3-format.
         """
 
     def __init__(
@@ -163,8 +162,7 @@ class Number(_BaseTraceHierarchyType):
             Sets the value formatting rule using d3 formatting
             mini-languages which are very similar to those in
             Python. For numbers, see:
-            https://github.com/d3/d3-3.x-api-
-            reference/blob/master/Formatting.md#d3_format.
+            https://github.com/d3/d3-format/tree/v1.4.5#d3-format.
 
         Returns
         -------
