@@ -37,7 +37,7 @@ class Slices(_BaseTraceHierarchyType):
                     start and end.
                 locationssrc
                     Sets the source reference on Chart Studio Cloud
-                    for  locations .
+                    for `locations`.
                 show
                     Determines whether or not slice planes about
                     the x dimension are drawn.
@@ -79,7 +79,7 @@ class Slices(_BaseTraceHierarchyType):
                     start and end.
                 locationssrc
                     Sets the source reference on Chart Studio Cloud
-                    for  locations .
+                    for `locations`.
                 show
                     Determines whether or not slice planes about
                     the y dimension are drawn.
@@ -121,7 +121,7 @@ class Slices(_BaseTraceHierarchyType):
                     start and end.
                 locationssrc
                     Sets the source reference on Chart Studio Cloud
-                    for  locations .
+                    for `locations`.
                 show
                     Determines whether or not slice planes about
                     the z dimension are drawn.
