@@ -24,7 +24,7 @@ class Colorscale(_BaseLayoutHierarchyType):
             Many predefined colorscale lists are included in the sequential, diverging,
             and cyclical modules in the plotly.colors package.
           - A list of 2-element lists where the first element is the
-            normalized color level value (starting at 0 and ending at 1), 
+            normalized color level value (starting at 0 and ending at 1),
             and the second item is a valid color string.
             (e.g. [[0, 'green'], [0.5, 'red'], [1.0, 'rgb(0, 0, 255)']])
           - One of the following named colorscales:
@@ -35,13 +35,14 @@ class Colorscale(_BaseLayoutHierarchyType):
                  'emrld', 'fall', 'geyser', 'gnbu', 'gray', 'greens', 'greys',
                  'haline', 'hot', 'hsv', 'ice', 'icefire', 'inferno', 'jet',
                  'magenta', 'magma', 'matter', 'mint', 'mrybm', 'mygbm', 'oranges',
-                 'orrd', 'oryel', 'peach', 'phase', 'picnic', 'pinkyl', 'piyg',
-                 'plasma', 'plotly3', 'portland', 'prgn', 'pubu', 'pubugn', 'puor',
-                 'purd', 'purp', 'purples', 'purpor', 'rainbow', 'rdbu', 'rdgy',
-                 'rdpu', 'rdylbu', 'rdylgn', 'redor', 'reds', 'solar', 'spectral',
-                 'speed', 'sunset', 'sunsetdark', 'teal', 'tealgrn', 'tealrose',
-                 'tempo', 'temps', 'thermal', 'tropic', 'turbid', 'twilight',
-                 'viridis', 'ylgn', 'ylgnbu', 'ylorbr', 'ylorrd'].
+                 'orrd', 'oryel', 'oxy', 'peach', 'phase', 'picnic', 'pinkyl',
+                 'piyg', 'plasma', 'plotly3', 'portland', 'prgn', 'pubu', 'pubugn',
+                 'puor', 'purd', 'purp', 'purples', 'purpor', 'rainbow', 'rdbu',
+                 'rdgy', 'rdpu', 'rdylbu', 'rdylgn', 'redor', 'reds', 'solar',
+                 'spectral', 'speed', 'sunset', 'sunsetdark', 'teal', 'tealgrn',
+                 'tealrose', 'tempo', 'temps', 'thermal', 'tropic', 'turbid',
+                 'turbo', 'twilight', 'viridis', 'ylgn', 'ylgnbu', 'ylorbr',
+                 'ylorrd'].
             Appending '_r' to a named colorscale reverses it.
 
         Returns
@@ -69,7 +70,7 @@ class Colorscale(_BaseLayoutHierarchyType):
             Many predefined colorscale lists are included in the sequential, diverging,
             and cyclical modules in the plotly.colors package.
           - A list of 2-element lists where the first element is the
-            normalized color level value (starting at 0 and ending at 1), 
+            normalized color level value (starting at 0 and ending at 1),
             and the second item is a valid color string.
             (e.g. [[0, 'green'], [0.5, 'red'], [1.0, 'rgb(0, 0, 255)']])
           - One of the following named colorscales:
@@ -80,13 +81,14 @@ class Colorscale(_BaseLayoutHierarchyType):
                  'emrld', 'fall', 'geyser', 'gnbu', 'gray', 'greens', 'greys',
                  'haline', 'hot', 'hsv', 'ice', 'icefire', 'inferno', 'jet',
                  'magenta', 'magma', 'matter', 'mint', 'mrybm', 'mygbm', 'oranges',
-                 'orrd', 'oryel', 'peach', 'phase', 'picnic', 'pinkyl', 'piyg',
-                 'plasma', 'plotly3', 'portland', 'prgn', 'pubu', 'pubugn', 'puor',
-                 'purd', 'purp', 'purples', 'purpor', 'rainbow', 'rdbu', 'rdgy',
-                 'rdpu', 'rdylbu', 'rdylgn', 'redor', 'reds', 'solar', 'spectral',
-                 'speed', 'sunset', 'sunsetdark', 'teal', 'tealgrn', 'tealrose',
-                 'tempo', 'temps', 'thermal', 'tropic', 'turbid', 'twilight',
-                 'viridis', 'ylgn', 'ylgnbu', 'ylorbr', 'ylorrd'].
+                 'orrd', 'oryel', 'oxy', 'peach', 'phase', 'picnic', 'pinkyl',
+                 'piyg', 'plasma', 'plotly3', 'portland', 'prgn', 'pubu', 'pubugn',
+                 'puor', 'purd', 'purp', 'purples', 'purpor', 'rainbow', 'rdbu',
+                 'rdgy', 'rdpu', 'rdylbu', 'rdylgn', 'redor', 'reds', 'solar',
+                 'spectral', 'speed', 'sunset', 'sunsetdark', 'teal', 'tealgrn',
+                 'tealrose', 'tempo', 'temps', 'thermal', 'tropic', 'turbid',
+                 'turbo', 'twilight', 'viridis', 'ylgn', 'ylgnbu', 'ylorbr',
+                 'ylorrd'].
             Appending '_r' to a named colorscale reverses it.
 
         Returns
@@ -114,7 +116,7 @@ class Colorscale(_BaseLayoutHierarchyType):
             Many predefined colorscale lists are included in the sequential, diverging,
             and cyclical modules in the plotly.colors package.
           - A list of 2-element lists where the first element is the
-            normalized color level value (starting at 0 and ending at 1), 
+            normalized color level value (starting at 0 and ending at 1),
             and the second item is a valid color string.
             (e.g. [[0, 'green'], [0.5, 'red'], [1.0, 'rgb(0, 0, 255)']])
           - One of the following named colorscales:
@@ -125,13 +127,14 @@ class Colorscale(_BaseLayoutHierarchyType):
                  'emrld', 'fall', 'geyser', 'gnbu', 'gray', 'greens', 'greys',
                  'haline', 'hot', 'hsv', 'ice', 'icefire', 'inferno', 'jet',
                  'magenta', 'magma', 'matter', 'mint', 'mrybm', 'mygbm', 'oranges',
-                 'orrd', 'oryel', 'peach', 'phase', 'picnic', 'pinkyl', 'piyg',
-                 'plasma', 'plotly3', 'portland', 'prgn', 'pubu', 'pubugn', 'puor',
-                 'purd', 'purp', 'purples', 'purpor', 'rainbow', 'rdbu', 'rdgy',
-                 'rdpu', 'rdylbu', 'rdylgn', 'redor', 'reds', 'solar', 'spectral',
-                 'speed', 'sunset', 'sunsetdark', 'teal', 'tealgrn', 'tealrose',
-                 'tempo', 'temps', 'thermal', 'tropic', 'turbid', 'twilight',
-                 'viridis', 'ylgn', 'ylgnbu', 'ylorbr', 'ylorrd'].
+                 'orrd', 'oryel', 'oxy', 'peach', 'phase', 'picnic', 'pinkyl',
+                 'piyg', 'plasma', 'plotly3', 'portland', 'prgn', 'pubu', 'pubugn',
+                 'puor', 'purd', 'purp', 'purples', 'purpor', 'rainbow', 'rdbu',
+                 'rdgy', 'rdpu', 'rdylbu', 'rdylgn', 'redor', 'reds', 'solar',
+                 'spectral', 'speed', 'sunset', 'sunsetdark', 'teal', 'tealgrn',
+                 'tealrose', 'tempo', 'temps', 'thermal', 'tropic', 'turbid',
+                 'turbo', 'twilight', 'viridis', 'ylgn', 'ylgnbu', 'ylorbr',
+                 'ylorrd'].
             Appending '_r' to a named colorscale reverses it.
 
         Returns
