@@ -204,7 +204,7 @@ class Grid(_BaseLayoutHierarchyType):
           - One of the following enumeration values:
                 ['']
           - A string that matches one of the following regular expressions:
-                ['^x([2-9]|[1-9][0-9]+)?$']
+                ['^x([2-9]|[1-9][0-9]+)?( domain)?$']
 
         Returns
         -------
@@ -279,7 +279,7 @@ class Grid(_BaseLayoutHierarchyType):
           - One of the following enumeration values:
                 ['']
           - A string that matches one of the following regular expressions:
-                ['^y([2-9]|[1-9][0-9]+)?$']
+                ['^y([2-9]|[1-9][0-9]+)?( domain)?$']
 
         Returns
         -------
