@@ -336,12 +336,12 @@ class Mapbox(_BaseLayoutHierarchyType):
         attribute or in the `mapboxAccessToken` config option.  Mapbox
         Style objects are of the form described in the Mapbox GL JS
         documentation available at https://docs.mapbox.com/mapbox-gl-
-        js/style-spec  The built-in plotly.js styles objects are: open-
-        street-map, white-bg, carto-positron, carto-darkmatter, stamen-
-        terrain, stamen-toner, stamen-watercolor  The built-in Mapbox
-        styles are: basic, streets, outdoors, light, dark, satellite,
-        satellite-streets  Mapbox style URLs are of the form:
-        mapbox://mapbox.mapbox-<name>-<version>
+        js/style-spec  The built-in plotly.js styles objects are:
+        carto-darkmatter, carto-positron, open-street-map, stamen-
+        terrain, stamen-toner, stamen-watercolor, white-bg  The built-
+        in Mapbox styles are: basic, streets, outdoors, light, dark,
+        satellite, satellite-streets  Mapbox style URLs are of the
+        form: mapbox://mapbox.mapbox-<name>-<version>
     
         The 'style' property accepts values of any type
 
@@ -449,12 +449,12 @@ class Mapbox(_BaseLayoutHierarchyType):
             objects are of the form described in the Mapbox GL JS
             documentation available at
             https://docs.mapbox.com/mapbox-gl-js/style-spec  The
-            built-in plotly.js styles objects are: open-street-map,
-            white-bg, carto-positron, carto-darkmatter, stamen-
-            terrain, stamen-toner, stamen-watercolor  The built-in
-            Mapbox styles are: basic, streets, outdoors, light,
-            dark, satellite, satellite-streets  Mapbox style URLs
-            are of the form:
+            built-in plotly.js styles objects are: carto-
+            darkmatter, carto-positron, open-street-map, stamen-
+            terrain, stamen-toner, stamen-watercolor, white-bg  The
+            built-in Mapbox styles are: basic, streets, outdoors,
+            light, dark, satellite, satellite-streets  Mapbox style
+            URLs are of the form:
             mapbox://mapbox.mapbox-<name>-<version>
         uirevision
             Controls persistence of user-driven changes in the
@@ -535,12 +535,12 @@ class Mapbox(_BaseLayoutHierarchyType):
             objects are of the form described in the Mapbox GL JS
             documentation available at
             https://docs.mapbox.com/mapbox-gl-js/style-spec  The
-            built-in plotly.js styles objects are: open-street-map,
-            white-bg, carto-positron, carto-darkmatter, stamen-
-            terrain, stamen-toner, stamen-watercolor  The built-in
-            Mapbox styles are: basic, streets, outdoors, light,
-            dark, satellite, satellite-streets  Mapbox style URLs
-            are of the form:
+            built-in plotly.js styles objects are: carto-
+            darkmatter, carto-positron, open-street-map, stamen-
+            terrain, stamen-toner, stamen-watercolor, white-bg  The
+            built-in Mapbox styles are: basic, streets, outdoors,
+            light, dark, satellite, satellite-streets  Mapbox style
+            URLs are of the form:
             mapbox://mapbox.mapbox-<name>-<version>
         uirevision
             Controls persistence of user-driven changes in the
