@@ -160,6 +160,10 @@ class Template(_BaseLayoutHierarchyType):
                     A tuple of
                     :class:`plotly.graph_objects.Scatter` instances
                     or dicts with compatible properties
+                scattersmith
+                    A tuple of
+                    :class:`plotly.graph_objects.Scattersmith`
+                    instances or dicts with compatible properties
                 scatterternary
                     A tuple of
                     :class:`plotly.graph_objects.Scatterternary`
