@@ -214,7 +214,7 @@ class Layer(_BaseLayoutHierarchyType):
                     effect only when `type` is set to "line".
                 dashsrc
                     Sets the source reference on Chart Studio Cloud
-                    for  dash .
+                    for `dash`.
                 width
                     Sets the line width (mapbox.layer.paint.line-
                     width). Has an effect only when `type` is set
