@@ -1,8 +1,52 @@
-from plotly.basedatatypes import BaseLayoutHierarchyType
-import copy
+from plotly.basedatatypes import BaseLayoutHierarchyType as _BaseLayoutHierarchyType
+import copy as _copy
 
 
-class Annotation(BaseLayoutHierarchyType):
+class Annotation(_BaseLayoutHierarchyType):
+
+    # class properties
+    # --------------------
+    _parent_path_str = "layout.scene"
+    _path_str = "layout.scene.annotation"
+    _valid_props = {
+        "align",
+        "arrowcolor",
+        "arrowhead",
+        "arrowside",
+        "arrowsize",
+        "arrowwidth",
+        "ax",
+        "ay",
+        "bgcolor",
+        "bordercolor",
+        "borderpad",
+        "borderwidth",
+        "captureevents",
+        "font",
+        "height",
+        "hoverlabel",
+        "hovertext",
+        "name",
+        "opacity",
+        "showarrow",
+        "standoff",
+        "startarrowhead",
+        "startarrowsize",
+        "startstandoff",
+        "templateitemname",
+        "text",
+        "textangle",
+        "valign",
+        "visible",
+        "width",
+        "x",
+        "xanchor",
+        "xshift",
+        "y",
+        "yanchor",
+        "yshift",
+        "z",
+    }
 
     # align
     # -----
@@ -10,9 +54,9 @@ class Annotation(BaseLayoutHierarchyType):
     def align(self):
         """
         Sets the horizontal alignment of the `text` within the box. Has
-        an effect only if `text` spans more two or more lines (i.e.
-        `text` contains one or more <br> HTML tags) or if an explicit
-        width is set to override the text width.
+        an effect only if `text` spans two or more lines (i.e. `text`
+        contains one or more <br> HTML tags) or if an explicit width is
+        set to override the text width.
     
         The 'align' property is an enumeration that may be specified as:
           - One of the following enumeration values:
@@ -22,11 +66,11 @@ class Annotation(BaseLayoutHierarchyType):
         -------
         Any
         """
-        return self['align']
+        return self["align"]
 
     @align.setter
     def align(self, val):
-        self['align'] = val
+        self["align"] = val
 
     # arrowcolor
     # ----------
@@ -70,22 +114,22 @@ class Annotation(BaseLayoutHierarchyType):
                 orchid, palegoldenrod, palegreen, paleturquoise,
                 palevioletred, papayawhip, peachpuff, peru, pink,
                 plum, powderblue, purple, red, rosybrown,
-                royalblue, saddlebrown, salmon, sandybrown,
-                seagreen, seashell, sienna, silver, skyblue,
-                slateblue, slategray, slategrey, snow, springgreen,
-                steelblue, tan, teal, thistle, tomato, turquoise,
-                violet, wheat, white, whitesmoke, yellow,
-                yellowgreen
+                royalblue, rebeccapurple, saddlebrown, salmon,
+                sandybrown, seagreen, seashell, sienna, silver,
+                skyblue, slateblue, slategray, slategrey, snow,
+                springgreen, steelblue, tan, teal, thistle, tomato,
+                turquoise, violet, wheat, white, whitesmoke,
+                yellow, yellowgreen
 
         Returns
         -------
         str
         """
-        return self['arrowcolor']
+        return self["arrowcolor"]
 
     @arrowcolor.setter
     def arrowcolor(self, val):
-        self['arrowcolor'] = val
+        self["arrowcolor"] = val
 
     # arrowhead
     # ---------
@@ -102,11 +146,11 @@ class Annotation(BaseLayoutHierarchyType):
         -------
         int
         """
-        return self['arrowhead']
+        return self["arrowhead"]
 
     @arrowhead.setter
     def arrowhead(self, val):
-        self['arrowhead'] = val
+        self["arrowhead"] = val
 
     # arrowside
     # ---------
@@ -125,11 +169,11 @@ class Annotation(BaseLayoutHierarchyType):
         -------
         Any
         """
-        return self['arrowside']
+        return self["arrowside"]
 
     @arrowside.setter
     def arrowside(self, val):
-        self['arrowside'] = val
+        self["arrowside"] = val
 
     # arrowsize
     # ---------
@@ -147,11 +191,11 @@ class Annotation(BaseLayoutHierarchyType):
         -------
         int|float
         """
-        return self['arrowsize']
+        return self["arrowsize"]
 
     @arrowsize.setter
     def arrowsize(self, val):
-        self['arrowsize'] = val
+        self["arrowsize"] = val
 
     # arrowwidth
     # ----------
@@ -167,11 +211,11 @@ class Annotation(BaseLayoutHierarchyType):
         -------
         int|float
         """
-        return self['arrowwidth']
+        return self["arrowwidth"]
 
     @arrowwidth.setter
     def arrowwidth(self, val):
-        self['arrowwidth'] = val
+        self["arrowwidth"] = val
 
     # ax
     # --
@@ -188,11 +232,11 @@ class Annotation(BaseLayoutHierarchyType):
         -------
         int|float
         """
-        return self['ax']
+        return self["ax"]
 
     @ax.setter
     def ax(self, val):
-        self['ax'] = val
+        self["ax"] = val
 
     # ay
     # --
@@ -209,11 +253,11 @@ class Annotation(BaseLayoutHierarchyType):
         -------
         int|float
         """
-        return self['ay']
+        return self["ay"]
 
     @ay.setter
     def ay(self, val):
-        self['ay'] = val
+        self["ay"] = val
 
     # bgcolor
     # -------
@@ -257,22 +301,22 @@ class Annotation(BaseLayoutHierarchyType):
                 orchid, palegoldenrod, palegreen, paleturquoise,
                 palevioletred, papayawhip, peachpuff, peru, pink,
                 plum, powderblue, purple, red, rosybrown,
-                royalblue, saddlebrown, salmon, sandybrown,
-                seagreen, seashell, sienna, silver, skyblue,
-                slateblue, slategray, slategrey, snow, springgreen,
-                steelblue, tan, teal, thistle, tomato, turquoise,
-                violet, wheat, white, whitesmoke, yellow,
-                yellowgreen
+                royalblue, rebeccapurple, saddlebrown, salmon,
+                sandybrown, seagreen, seashell, sienna, silver,
+                skyblue, slateblue, slategray, slategrey, snow,
+                springgreen, steelblue, tan, teal, thistle, tomato,
+                turquoise, violet, wheat, white, whitesmoke,
+                yellow, yellowgreen
 
         Returns
         -------
         str
         """
-        return self['bgcolor']
+        return self["bgcolor"]
 
     @bgcolor.setter
     def bgcolor(self, val):
-        self['bgcolor'] = val
+        self["bgcolor"] = val
 
     # bordercolor
     # -----------
@@ -316,22 +360,22 @@ class Annotation(BaseLayoutHierarchyType):
                 orchid, palegoldenrod, palegreen, paleturquoise,
                 palevioletred, papayawhip, peachpuff, peru, pink,
                 plum, powderblue, purple, red, rosybrown,
-                royalblue, saddlebrown, salmon, sandybrown,
-                seagreen, seashell, sienna, silver, skyblue,
-                slateblue, slategray, slategrey, snow, springgreen,
-                steelblue, tan, teal, thistle, tomato, turquoise,
-                violet, wheat, white, whitesmoke, yellow,
-                yellowgreen
+                royalblue, rebeccapurple, saddlebrown, salmon,
+                sandybrown, seagreen, seashell, sienna, silver,
+                skyblue, slateblue, slategray, slategrey, snow,
+                springgreen, steelblue, tan, teal, thistle, tomato,
+                turquoise, violet, wheat, white, whitesmoke,
+                yellow, yellowgreen
 
         Returns
         -------
         str
         """
-        return self['bordercolor']
+        return self["bordercolor"]
 
     @bordercolor.setter
     def bordercolor(self, val):
-        self['bordercolor'] = val
+        self["bordercolor"] = val
 
     # borderpad
     # ---------
@@ -348,11 +392,11 @@ class Annotation(BaseLayoutHierarchyType):
         -------
         int|float
         """
-        return self['borderpad']
+        return self["borderpad"]
 
     @borderpad.setter
     def borderpad(self, val):
-        self['borderpad'] = val
+        self["borderpad"] = val
 
     # borderwidth
     # -----------
@@ -369,11 +413,11 @@ class Annotation(BaseLayoutHierarchyType):
         -------
         int|float
         """
-        return self['borderwidth']
+        return self["borderwidth"]
 
     @borderwidth.setter
     def borderwidth(self, val):
-        self['borderwidth'] = val
+        self["borderwidth"] = val
 
     # captureevents
     # -------------
@@ -394,11 +438,11 @@ class Annotation(BaseLayoutHierarchyType):
         -------
         bool
         """
-        return self['captureevents']
+        return self["captureevents"]
 
     @captureevents.setter
     def captureevents(self, val):
-        self['captureevents'] = val
+        self["captureevents"] = val
 
     # font
     # ----
@@ -409,7 +453,7 @@ class Annotation(BaseLayoutHierarchyType):
     
         The 'font' property is an instance of Font
         that may be specified as:
-          - An instance of plotly.graph_objs.layout.scene.annotation.Font
+          - An instance of :class:`plotly.graph_objs.layout.scene.annotation.Font`
           - A dict of string/value properties that will be passed
             to the Font constructor
     
@@ -425,12 +469,13 @@ class Annotation(BaseLayoutHierarchyType):
                     Provide multiple font families, separated by
                     commas, to indicate the preference in which to
                     apply fonts if they aren't available on the
-                    system. The plotly service (at https://plot.ly
-                    or on-premise) generates images on a server,
-                    where only a select number of fonts are
-                    installed and supported. These include "Arial",
-                    "Balto", "Courier New", "Droid Sans",, "Droid
-                    Serif", "Droid Sans Mono", "Gravitas One", "Old
+                    system. The Chart Studio Cloud (at
+                    https://chart-studio.plotly.com or on-premise)
+                    generates images on a server, where only a
+                    select number of fonts are installed and
+                    supported. These include "Arial", "Balto",
+                    "Courier New", "Droid Sans",, "Droid Serif",
+                    "Droid Sans Mono", "Gravitas One", "Old
                     Standard TT", "Open Sans", "Overpass", "PT Sans
                     Narrow", "Raleway", "Times New Roman".
                 size
@@ -439,11 +484,11 @@ class Annotation(BaseLayoutHierarchyType):
         -------
         plotly.graph_objs.layout.scene.annotation.Font
         """
-        return self['font']
+        return self["font"]
 
     @font.setter
     def font(self, val):
-        self['font'] = val
+        self["font"] = val
 
     # height
     # ------
@@ -460,11 +505,11 @@ class Annotation(BaseLayoutHierarchyType):
         -------
         int|float
         """
-        return self['height']
+        return self["height"]
 
     @height.setter
     def height(self, val):
-        self['height'] = val
+        self["height"] = val
 
     # hoverlabel
     # ----------
@@ -473,7 +518,7 @@ class Annotation(BaseLayoutHierarchyType):
         """
         The 'hoverlabel' property is an instance of Hoverlabel
         that may be specified as:
-          - An instance of plotly.graph_objs.layout.scene.annotation.Hoverlabel
+          - An instance of :class:`plotly.graph_objs.layout.scene.annotation.Hoverlabel`
           - A dict of string/value properties that will be passed
             to the Hoverlabel constructor
     
@@ -496,11 +541,11 @@ class Annotation(BaseLayoutHierarchyType):
         -------
         plotly.graph_objs.layout.scene.annotation.Hoverlabel
         """
-        return self['hoverlabel']
+        return self["hoverlabel"]
 
     @hoverlabel.setter
     def hoverlabel(self, val):
-        self['hoverlabel'] = val
+        self["hoverlabel"] = val
 
     # hovertext
     # ---------
@@ -518,11 +563,11 @@ class Annotation(BaseLayoutHierarchyType):
         -------
         str
         """
-        return self['hovertext']
+        return self["hovertext"]
 
     @hovertext.setter
     def hovertext(self, val):
-        self['hovertext'] = val
+        self["hovertext"] = val
 
     # name
     # ----
@@ -545,11 +590,11 @@ class Annotation(BaseLayoutHierarchyType):
         -------
         str
         """
-        return self['name']
+        return self["name"]
 
     @name.setter
     def name(self, val):
-        self['name'] = val
+        self["name"] = val
 
     # opacity
     # -------
@@ -565,11 +610,11 @@ class Annotation(BaseLayoutHierarchyType):
         -------
         int|float
         """
-        return self['opacity']
+        return self["opacity"]
 
     @opacity.setter
     def opacity(self, val):
-        self['opacity'] = val
+        self["opacity"] = val
 
     # showarrow
     # ---------
@@ -587,11 +632,11 @@ class Annotation(BaseLayoutHierarchyType):
         -------
         bool
         """
-        return self['showarrow']
+        return self["showarrow"]
 
     @showarrow.setter
     def showarrow(self, val):
-        self['showarrow'] = val
+        self["showarrow"] = val
 
     # standoff
     # --------
@@ -611,11 +656,11 @@ class Annotation(BaseLayoutHierarchyType):
         -------
         int|float
         """
-        return self['standoff']
+        return self["standoff"]
 
     @standoff.setter
     def standoff(self, val):
-        self['standoff'] = val
+        self["standoff"] = val
 
     # startarrowhead
     # --------------
@@ -632,11 +677,11 @@ class Annotation(BaseLayoutHierarchyType):
         -------
         int
         """
-        return self['startarrowhead']
+        return self["startarrowhead"]
 
     @startarrowhead.setter
     def startarrowhead(self, val):
-        self['startarrowhead'] = val
+        self["startarrowhead"] = val
 
     # startarrowsize
     # --------------
@@ -654,11 +699,11 @@ class Annotation(BaseLayoutHierarchyType):
         -------
         int|float
         """
-        return self['startarrowsize']
+        return self["startarrowsize"]
 
     @startarrowsize.setter
     def startarrowsize(self, val):
-        self['startarrowsize'] = val
+        self["startarrowsize"] = val
 
     # startstandoff
     # -------------
@@ -678,11 +723,11 @@ class Annotation(BaseLayoutHierarchyType):
         -------
         int|float
         """
-        return self['startstandoff']
+        return self["startstandoff"]
 
     @startstandoff.setter
     def startstandoff(self, val):
-        self['startstandoff'] = val
+        self["startstandoff"] = val
 
     # templateitemname
     # ----------------
@@ -706,11 +751,11 @@ class Annotation(BaseLayoutHierarchyType):
         -------
         str
         """
-        return self['templateitemname']
+        return self["templateitemname"]
 
     @templateitemname.setter
     def templateitemname(self, val):
-        self['templateitemname'] = val
+        self["templateitemname"] = val
 
     # text
     # ----
@@ -730,11 +775,11 @@ class Annotation(BaseLayoutHierarchyType):
         -------
         str
         """
-        return self['text']
+        return self["text"]
 
     @text.setter
     def text(self, val):
-        self['text'] = val
+        self["text"] = val
 
     # textangle
     # ---------
@@ -753,11 +798,11 @@ class Annotation(BaseLayoutHierarchyType):
         -------
         int|float
         """
-        return self['textangle']
+        return self["textangle"]
 
     @textangle.setter
     def textangle(self, val):
-        self['textangle'] = val
+        self["textangle"] = val
 
     # valign
     # ------
@@ -776,11 +821,11 @@ class Annotation(BaseLayoutHierarchyType):
         -------
         Any
         """
-        return self['valign']
+        return self["valign"]
 
     @valign.setter
     def valign(self, val):
-        self['valign'] = val
+        self["valign"] = val
 
     # visible
     # -------
@@ -796,11 +841,11 @@ class Annotation(BaseLayoutHierarchyType):
         -------
         bool
         """
-        return self['visible']
+        return self["visible"]
 
     @visible.setter
     def visible(self, val):
-        self['visible'] = val
+        self["visible"] = val
 
     # width
     # -----
@@ -818,11 +863,11 @@ class Annotation(BaseLayoutHierarchyType):
         -------
         int|float
         """
-        return self['width']
+        return self["width"]
 
     @width.setter
     def width(self, val):
-        self['width'] = val
+        self["width"] = val
 
     # x
     # -
@@ -837,11 +882,11 @@ class Annotation(BaseLayoutHierarchyType):
         -------
         Any
         """
-        return self['x']
+        return self["x"]
 
     @x.setter
     def x(self, val):
-        self['x'] = val
+        self["x"] = val
 
     # xanchor
     # -------
@@ -866,11 +911,11 @@ class Annotation(BaseLayoutHierarchyType):
         -------
         Any
         """
-        return self['xanchor']
+        return self["xanchor"]
 
     @xanchor.setter
     def xanchor(self, val):
-        self['xanchor'] = val
+        self["xanchor"] = val
 
     # xshift
     # ------
@@ -887,11 +932,11 @@ class Annotation(BaseLayoutHierarchyType):
         -------
         int|float
         """
-        return self['xshift']
+        return self["xshift"]
 
     @xshift.setter
     def xshift(self, val):
-        self['xshift'] = val
+        self["xshift"] = val
 
     # y
     # -
@@ -906,11 +951,11 @@ class Annotation(BaseLayoutHierarchyType):
         -------
         Any
         """
-        return self['y']
+        return self["y"]
 
     @y.setter
     def y(self, val):
-        self['y'] = val
+        self["y"] = val
 
     # yanchor
     # -------
@@ -935,11 +980,11 @@ class Annotation(BaseLayoutHierarchyType):
         -------
         Any
         """
-        return self['yanchor']
+        return self["yanchor"]
 
     @yanchor.setter
     def yanchor(self, val):
-        self['yanchor'] = val
+        self["yanchor"] = val
 
     # yshift
     # ------
@@ -956,11 +1001,11 @@ class Annotation(BaseLayoutHierarchyType):
         -------
         int|float
         """
-        return self['yshift']
+        return self["yshift"]
 
     @yshift.setter
     def yshift(self, val):
-        self['yshift'] = val
+        self["yshift"] = val
 
     # z
     # -
@@ -975,17 +1020,11 @@ class Annotation(BaseLayoutHierarchyType):
         -------
         Any
         """
-        return self['z']
+        return self["z"]
 
     @z.setter
     def z(self, val):
-        self['z'] = val
-
-    # property parent name
-    # --------------------
-    @property
-    def _parent_path_str(self):
-        return 'layout.scene'
+        self["z"] = val
 
     # Self properties description
     # ---------------------------
@@ -994,10 +1033,10 @@ class Annotation(BaseLayoutHierarchyType):
         return """\
         align
             Sets the horizontal alignment of the `text` within the
-            box. Has an effect only if `text` spans more two or
-            more lines (i.e. `text` contains one or more <br> HTML
-            tags) or if an explicit width is set to override the
-            text width.
+            box. Has an effect only if `text` spans two or more
+            lines (i.e. `text` contains one or more <br> HTML tags)
+            or if an explicit width is set to override the text
+            width.
         arrowcolor
             Sets the color of the annotation arrow.
         arrowhead
@@ -1042,8 +1081,8 @@ class Annotation(BaseLayoutHierarchyType):
             (default) lets the text set the box height. Taller text
             will be clipped.
         hoverlabel
-            plotly.graph_objs.layout.scene.annotation.Hoverlabel
-            instance or dict with compatible properties
+            :class:`plotly.graph_objects.layout.scene.annotation.Ho
+            verlabel` instance or dict with compatible properties
         hovertext
             Sets text to appear when hovering over this annotation.
             If omitted or blank, no hover label will appear.
@@ -1200,13 +1239,13 @@ class Annotation(BaseLayoutHierarchyType):
         arg
             dict of properties compatible with this constructor or
             an instance of
-            plotly.graph_objs.layout.scene.Annotation
+            :class:`plotly.graph_objs.layout.scene.Annotation`
         align
             Sets the horizontal alignment of the `text` within the
-            box. Has an effect only if `text` spans more two or
-            more lines (i.e. `text` contains one or more <br> HTML
-            tags) or if an explicit width is set to override the
-            text width.
+            box. Has an effect only if `text` spans two or more
+            lines (i.e. `text` contains one or more <br> HTML tags)
+            or if an explicit width is set to override the text
+            width.
         arrowcolor
             Sets the color of the annotation arrow.
         arrowhead
@@ -1251,8 +1290,8 @@ class Annotation(BaseLayoutHierarchyType):
             (default) lets the text set the box height. Taller text
             will be clipped.
         hoverlabel
-            plotly.graph_objs.layout.scene.annotation.Hoverlabel
-            instance or dict with compatible properties
+            :class:`plotly.graph_objects.layout.scene.annotation.Ho
+            verlabel` instance or dict with compatible properties
         hovertext
             Sets text to appear when hovering over this annotation.
             If omitted or blank, no hover label will appear.
@@ -1362,7 +1401,11 @@ class Annotation(BaseLayoutHierarchyType):
         -------
         Annotation
         """
-        super(Annotation, self).__init__('annotations')
+        super(Annotation, self).__init__("annotations")
+
+        if "_parent" in kwargs:
+            self._parent = kwargs["_parent"]
+            return
 
         # Validate arg
         # ------------
@@ -1371,149 +1414,170 @@ class Annotation(BaseLayoutHierarchyType):
         elif isinstance(arg, self.__class__):
             arg = arg.to_plotly_json()
         elif isinstance(arg, dict):
-            arg = copy.copy(arg)
+            arg = _copy.copy(arg)
         else:
             raise ValueError(
                 """\
 The first argument to the plotly.graph_objs.layout.scene.Annotation 
 constructor must be a dict or 
-an instance of plotly.graph_objs.layout.scene.Annotation"""
+an instance of :class:`plotly.graph_objs.layout.scene.Annotation`"""
             )
 
         # Handle skip_invalid
         # -------------------
-        self._skip_invalid = kwargs.pop('skip_invalid', False)
-
-        # Import validators
-        # -----------------
-        from plotly.validators.layout.scene import (annotation as v_annotation)
-
-        # Initialize validators
-        # ---------------------
-        self._validators['align'] = v_annotation.AlignValidator()
-        self._validators['arrowcolor'] = v_annotation.ArrowcolorValidator()
-        self._validators['arrowhead'] = v_annotation.ArrowheadValidator()
-        self._validators['arrowside'] = v_annotation.ArrowsideValidator()
-        self._validators['arrowsize'] = v_annotation.ArrowsizeValidator()
-        self._validators['arrowwidth'] = v_annotation.ArrowwidthValidator()
-        self._validators['ax'] = v_annotation.AxValidator()
-        self._validators['ay'] = v_annotation.AyValidator()
-        self._validators['bgcolor'] = v_annotation.BgcolorValidator()
-        self._validators['bordercolor'] = v_annotation.BordercolorValidator()
-        self._validators['borderpad'] = v_annotation.BorderpadValidator()
-        self._validators['borderwidth'] = v_annotation.BorderwidthValidator()
-        self._validators['captureevents'
-                        ] = v_annotation.CaptureeventsValidator()
-        self._validators['font'] = v_annotation.FontValidator()
-        self._validators['height'] = v_annotation.HeightValidator()
-        self._validators['hoverlabel'] = v_annotation.HoverlabelValidator()
-        self._validators['hovertext'] = v_annotation.HovertextValidator()
-        self._validators['name'] = v_annotation.NameValidator()
-        self._validators['opacity'] = v_annotation.OpacityValidator()
-        self._validators['showarrow'] = v_annotation.ShowarrowValidator()
-        self._validators['standoff'] = v_annotation.StandoffValidator()
-        self._validators['startarrowhead'
-                        ] = v_annotation.StartarrowheadValidator()
-        self._validators['startarrowsize'
-                        ] = v_annotation.StartarrowsizeValidator()
-        self._validators['startstandoff'
-                        ] = v_annotation.StartstandoffValidator()
-        self._validators['templateitemname'
-                        ] = v_annotation.TemplateitemnameValidator()
-        self._validators['text'] = v_annotation.TextValidator()
-        self._validators['textangle'] = v_annotation.TextangleValidator()
-        self._validators['valign'] = v_annotation.ValignValidator()
-        self._validators['visible'] = v_annotation.VisibleValidator()
-        self._validators['width'] = v_annotation.WidthValidator()
-        self._validators['x'] = v_annotation.XValidator()
-        self._validators['xanchor'] = v_annotation.XanchorValidator()
-        self._validators['xshift'] = v_annotation.XshiftValidator()
-        self._validators['y'] = v_annotation.YValidator()
-        self._validators['yanchor'] = v_annotation.YanchorValidator()
-        self._validators['yshift'] = v_annotation.YshiftValidator()
-        self._validators['z'] = v_annotation.ZValidator()
+        self._skip_invalid = kwargs.pop("skip_invalid", False)
+        self._validate = kwargs.pop("_validate", True)
 
         # Populate data dict with properties
         # ----------------------------------
-        _v = arg.pop('align', None)
-        self['align'] = align if align is not None else _v
-        _v = arg.pop('arrowcolor', None)
-        self['arrowcolor'] = arrowcolor if arrowcolor is not None else _v
-        _v = arg.pop('arrowhead', None)
-        self['arrowhead'] = arrowhead if arrowhead is not None else _v
-        _v = arg.pop('arrowside', None)
-        self['arrowside'] = arrowside if arrowside is not None else _v
-        _v = arg.pop('arrowsize', None)
-        self['arrowsize'] = arrowsize if arrowsize is not None else _v
-        _v = arg.pop('arrowwidth', None)
-        self['arrowwidth'] = arrowwidth if arrowwidth is not None else _v
-        _v = arg.pop('ax', None)
-        self['ax'] = ax if ax is not None else _v
-        _v = arg.pop('ay', None)
-        self['ay'] = ay if ay is not None else _v
-        _v = arg.pop('bgcolor', None)
-        self['bgcolor'] = bgcolor if bgcolor is not None else _v
-        _v = arg.pop('bordercolor', None)
-        self['bordercolor'] = bordercolor if bordercolor is not None else _v
-        _v = arg.pop('borderpad', None)
-        self['borderpad'] = borderpad if borderpad is not None else _v
-        _v = arg.pop('borderwidth', None)
-        self['borderwidth'] = borderwidth if borderwidth is not None else _v
-        _v = arg.pop('captureevents', None)
-        self['captureevents'
-            ] = captureevents if captureevents is not None else _v
-        _v = arg.pop('font', None)
-        self['font'] = font if font is not None else _v
-        _v = arg.pop('height', None)
-        self['height'] = height if height is not None else _v
-        _v = arg.pop('hoverlabel', None)
-        self['hoverlabel'] = hoverlabel if hoverlabel is not None else _v
-        _v = arg.pop('hovertext', None)
-        self['hovertext'] = hovertext if hovertext is not None else _v
-        _v = arg.pop('name', None)
-        self['name'] = name if name is not None else _v
-        _v = arg.pop('opacity', None)
-        self['opacity'] = opacity if opacity is not None else _v
-        _v = arg.pop('showarrow', None)
-        self['showarrow'] = showarrow if showarrow is not None else _v
-        _v = arg.pop('standoff', None)
-        self['standoff'] = standoff if standoff is not None else _v
-        _v = arg.pop('startarrowhead', None)
-        self['startarrowhead'
-            ] = startarrowhead if startarrowhead is not None else _v
-        _v = arg.pop('startarrowsize', None)
-        self['startarrowsize'
-            ] = startarrowsize if startarrowsize is not None else _v
-        _v = arg.pop('startstandoff', None)
-        self['startstandoff'
-            ] = startstandoff if startstandoff is not None else _v
-        _v = arg.pop('templateitemname', None)
-        self['templateitemname'
-            ] = templateitemname if templateitemname is not None else _v
-        _v = arg.pop('text', None)
-        self['text'] = text if text is not None else _v
-        _v = arg.pop('textangle', None)
-        self['textangle'] = textangle if textangle is not None else _v
-        _v = arg.pop('valign', None)
-        self['valign'] = valign if valign is not None else _v
-        _v = arg.pop('visible', None)
-        self['visible'] = visible if visible is not None else _v
-        _v = arg.pop('width', None)
-        self['width'] = width if width is not None else _v
-        _v = arg.pop('x', None)
-        self['x'] = x if x is not None else _v
-        _v = arg.pop('xanchor', None)
-        self['xanchor'] = xanchor if xanchor is not None else _v
-        _v = arg.pop('xshift', None)
-        self['xshift'] = xshift if xshift is not None else _v
-        _v = arg.pop('y', None)
-        self['y'] = y if y is not None else _v
-        _v = arg.pop('yanchor', None)
-        self['yanchor'] = yanchor if yanchor is not None else _v
-        _v = arg.pop('yshift', None)
-        self['yshift'] = yshift if yshift is not None else _v
-        _v = arg.pop('z', None)
-        self['z'] = z if z is not None else _v
+        _v = arg.pop("align", None)
+        _v = align if align is not None else _v
+        if _v is not None:
+            self["align"] = _v
+        _v = arg.pop("arrowcolor", None)
+        _v = arrowcolor if arrowcolor is not None else _v
+        if _v is not None:
+            self["arrowcolor"] = _v
+        _v = arg.pop("arrowhead", None)
+        _v = arrowhead if arrowhead is not None else _v
+        if _v is not None:
+            self["arrowhead"] = _v
+        _v = arg.pop("arrowside", None)
+        _v = arrowside if arrowside is not None else _v
+        if _v is not None:
+            self["arrowside"] = _v
+        _v = arg.pop("arrowsize", None)
+        _v = arrowsize if arrowsize is not None else _v
+        if _v is not None:
+            self["arrowsize"] = _v
+        _v = arg.pop("arrowwidth", None)
+        _v = arrowwidth if arrowwidth is not None else _v
+        if _v is not None:
+            self["arrowwidth"] = _v
+        _v = arg.pop("ax", None)
+        _v = ax if ax is not None else _v
+        if _v is not None:
+            self["ax"] = _v
+        _v = arg.pop("ay", None)
+        _v = ay if ay is not None else _v
+        if _v is not None:
+            self["ay"] = _v
+        _v = arg.pop("bgcolor", None)
+        _v = bgcolor if bgcolor is not None else _v
+        if _v is not None:
+            self["bgcolor"] = _v
+        _v = arg.pop("bordercolor", None)
+        _v = bordercolor if bordercolor is not None else _v
+        if _v is not None:
+            self["bordercolor"] = _v
+        _v = arg.pop("borderpad", None)
+        _v = borderpad if borderpad is not None else _v
+        if _v is not None:
+            self["borderpad"] = _v
+        _v = arg.pop("borderwidth", None)
+        _v = borderwidth if borderwidth is not None else _v
+        if _v is not None:
+            self["borderwidth"] = _v
+        _v = arg.pop("captureevents", None)
+        _v = captureevents if captureevents is not None else _v
+        if _v is not None:
+            self["captureevents"] = _v
+        _v = arg.pop("font", None)
+        _v = font if font is not None else _v
+        if _v is not None:
+            self["font"] = _v
+        _v = arg.pop("height", None)
+        _v = height if height is not None else _v
+        if _v is not None:
+            self["height"] = _v
+        _v = arg.pop("hoverlabel", None)
+        _v = hoverlabel if hoverlabel is not None else _v
+        if _v is not None:
+            self["hoverlabel"] = _v
+        _v = arg.pop("hovertext", None)
+        _v = hovertext if hovertext is not None else _v
+        if _v is not None:
+            self["hovertext"] = _v
+        _v = arg.pop("name", None)
+        _v = name if name is not None else _v
+        if _v is not None:
+            self["name"] = _v
+        _v = arg.pop("opacity", None)
+        _v = opacity if opacity is not None else _v
+        if _v is not None:
+            self["opacity"] = _v
+        _v = arg.pop("showarrow", None)
+        _v = showarrow if showarrow is not None else _v
+        if _v is not None:
+            self["showarrow"] = _v
+        _v = arg.pop("standoff", None)
+        _v = standoff if standoff is not None else _v
+        if _v is not None:
+            self["standoff"] = _v
+        _v = arg.pop("startarrowhead", None)
+        _v = startarrowhead if startarrowhead is not None else _v
+        if _v is not None:
+            self["startarrowhead"] = _v
+        _v = arg.pop("startarrowsize", None)
+        _v = startarrowsize if startarrowsize is not None else _v
+        if _v is not None:
+            self["startarrowsize"] = _v
+        _v = arg.pop("startstandoff", None)
+        _v = startstandoff if startstandoff is not None else _v
+        if _v is not None:
+            self["startstandoff"] = _v
+        _v = arg.pop("templateitemname", None)
+        _v = templateitemname if templateitemname is not None else _v
+        if _v is not None:
+            self["templateitemname"] = _v
+        _v = arg.pop("text", None)
+        _v = text if text is not None else _v
+        if _v is not None:
+            self["text"] = _v
+        _v = arg.pop("textangle", None)
+        _v = textangle if textangle is not None else _v
+        if _v is not None:
+            self["textangle"] = _v
+        _v = arg.pop("valign", None)
+        _v = valign if valign is not None else _v
+        if _v is not None:
+            self["valign"] = _v
+        _v = arg.pop("visible", None)
+        _v = visible if visible is not None else _v
+        if _v is not None:
+            self["visible"] = _v
+        _v = arg.pop("width", None)
+        _v = width if width is not None else _v
+        if _v is not None:
+            self["width"] = _v
+        _v = arg.pop("x", None)
+        _v = x if x is not None else _v
+        if _v is not None:
+            self["x"] = _v
+        _v = arg.pop("xanchor", None)
+        _v = xanchor if xanchor is not None else _v
+        if _v is not None:
+            self["xanchor"] = _v
+        _v = arg.pop("xshift", None)
+        _v = xshift if xshift is not None else _v
+        if _v is not None:
+            self["xshift"] = _v
+        _v = arg.pop("y", None)
+        _v = y if y is not None else _v
+        if _v is not None:
+            self["y"] = _v
+        _v = arg.pop("yanchor", None)
+        _v = yanchor if yanchor is not None else _v
+        if _v is not None:
+            self["yanchor"] = _v
+        _v = arg.pop("yshift", None)
+        _v = yshift if yshift is not None else _v
+        if _v is not None:
+            self["yshift"] = _v
+        _v = arg.pop("z", None)
+        _v = z if z is not None else _v
+        if _v is not None:
+            self["z"] = _v
 
         # Process unknown kwargs
         # ----------------------
