@@ -38,6 +38,7 @@ if sys.version_info < (3, 7):
     from ._scattermapbox import Scattermapbox
     from ._scatterpolar import Scatterpolar
     from ._scatterpolargl import Scatterpolargl
+    from ._scattersmith import Scattersmith
     from ._scatterternary import Scatterternary
     from ._splom import Splom
     from ._streamtube import Streamtube
@@ -92,6 +93,7 @@ else:
             "._scattermapbox.Scattermapbox",
             "._scatterpolar.Scatterpolar",
             "._scatterpolargl.Scatterpolargl",
+            "._scattersmith.Scattersmith",
             "._scatterternary.Scatterternary",
             "._splom.Splom",
             "._streamtube.Streamtube",
