@@ -1,8 +1,27 @@
-from plotly.basedatatypes import BaseLayoutHierarchyType
-import copy
+from plotly.basedatatypes import BaseLayoutHierarchyType as _BaseLayoutHierarchyType
+import copy as _copy
 
 
-class Rangeselector(BaseLayoutHierarchyType):
+class Rangeselector(_BaseLayoutHierarchyType):
+
+    # class properties
+    # --------------------
+    _parent_path_str = "layout.xaxis"
+    _path_str = "layout.xaxis.rangeselector"
+    _valid_props = {
+        "activecolor",
+        "bgcolor",
+        "bordercolor",
+        "borderwidth",
+        "buttondefaults",
+        "buttons",
+        "font",
+        "visible",
+        "x",
+        "xanchor",
+        "y",
+        "yanchor",
+    }
 
     # activecolor
     # -----------
@@ -46,22 +65,22 @@ class Rangeselector(BaseLayoutHierarchyType):
                 orchid, palegoldenrod, palegreen, paleturquoise,
                 palevioletred, papayawhip, peachpuff, peru, pink,
                 plum, powderblue, purple, red, rosybrown,
-                royalblue, saddlebrown, salmon, sandybrown,
-                seagreen, seashell, sienna, silver, skyblue,
-                slateblue, slategray, slategrey, snow, springgreen,
-                steelblue, tan, teal, thistle, tomato, turquoise,
-                violet, wheat, white, whitesmoke, yellow,
-                yellowgreen
+                royalblue, rebeccapurple, saddlebrown, salmon,
+                sandybrown, seagreen, seashell, sienna, silver,
+                skyblue, slateblue, slategray, slategrey, snow,
+                springgreen, steelblue, tan, teal, thistle, tomato,
+                turquoise, violet, wheat, white, whitesmoke,
+                yellow, yellowgreen
 
         Returns
         -------
         str
         """
-        return self['activecolor']
+        return self["activecolor"]
 
     @activecolor.setter
     def activecolor(self, val):
-        self['activecolor'] = val
+        self["activecolor"] = val
 
     # bgcolor
     # -------
@@ -105,22 +124,22 @@ class Rangeselector(BaseLayoutHierarchyType):
                 orchid, palegoldenrod, palegreen, paleturquoise,
                 palevioletred, papayawhip, peachpuff, peru, pink,
                 plum, powderblue, purple, red, rosybrown,
-                royalblue, saddlebrown, salmon, sandybrown,
-                seagreen, seashell, sienna, silver, skyblue,
-                slateblue, slategray, slategrey, snow, springgreen,
-                steelblue, tan, teal, thistle, tomato, turquoise,
-                violet, wheat, white, whitesmoke, yellow,
-                yellowgreen
+                royalblue, rebeccapurple, saddlebrown, salmon,
+                sandybrown, seagreen, seashell, sienna, silver,
+                skyblue, slateblue, slategray, slategrey, snow,
+                springgreen, steelblue, tan, teal, thistle, tomato,
+                turquoise, violet, wheat, white, whitesmoke,
+                yellow, yellowgreen
 
         Returns
         -------
         str
         """
-        return self['bgcolor']
+        return self["bgcolor"]
 
     @bgcolor.setter
     def bgcolor(self, val):
-        self['bgcolor'] = val
+        self["bgcolor"] = val
 
     # bordercolor
     # -----------
@@ -164,22 +183,22 @@ class Rangeselector(BaseLayoutHierarchyType):
                 orchid, palegoldenrod, palegreen, paleturquoise,
                 palevioletred, papayawhip, peachpuff, peru, pink,
                 plum, powderblue, purple, red, rosybrown,
-                royalblue, saddlebrown, salmon, sandybrown,
-                seagreen, seashell, sienna, silver, skyblue,
-                slateblue, slategray, slategrey, snow, springgreen,
-                steelblue, tan, teal, thistle, tomato, turquoise,
-                violet, wheat, white, whitesmoke, yellow,
-                yellowgreen
+                royalblue, rebeccapurple, saddlebrown, salmon,
+                sandybrown, seagreen, seashell, sienna, silver,
+                skyblue, slateblue, slategray, slategrey, snow,
+                springgreen, steelblue, tan, teal, thistle, tomato,
+                turquoise, violet, wheat, white, whitesmoke,
+                yellow, yellowgreen
 
         Returns
         -------
         str
         """
-        return self['bordercolor']
+        return self["bordercolor"]
 
     @bordercolor.setter
     def bordercolor(self, val):
-        self['bordercolor'] = val
+        self["bordercolor"] = val
 
     # borderwidth
     # -----------
@@ -196,11 +215,11 @@ class Rangeselector(BaseLayoutHierarchyType):
         -------
         int|float
         """
-        return self['borderwidth']
+        return self["borderwidth"]
 
     @borderwidth.setter
     def borderwidth(self, val):
-        self['borderwidth'] = val
+        self["borderwidth"] = val
 
     # buttons
     # -------
@@ -268,11 +287,11 @@ class Rangeselector(BaseLayoutHierarchyType):
         -------
         tuple[plotly.graph_objs.layout.xaxis.rangeselector.Button]
         """
-        return self['buttons']
+        return self["buttons"]
 
     @buttons.setter
     def buttons(self, val):
-        self['buttons'] = val
+        self["buttons"] = val
 
     # buttondefaults
     # --------------
@@ -286,7 +305,7 @@ class Rangeselector(BaseLayoutHierarchyType):
     
         The 'buttondefaults' property is an instance of Button
         that may be specified as:
-          - An instance of plotly.graph_objs.layout.xaxis.rangeselector.Button
+          - An instance of :class:`plotly.graph_objs.layout.xaxis.rangeselector.Button`
           - A dict of string/value properties that will be passed
             to the Button constructor
     
@@ -296,11 +315,11 @@ class Rangeselector(BaseLayoutHierarchyType):
         -------
         plotly.graph_objs.layout.xaxis.rangeselector.Button
         """
-        return self['buttondefaults']
+        return self["buttondefaults"]
 
     @buttondefaults.setter
     def buttondefaults(self, val):
-        self['buttondefaults'] = val
+        self["buttondefaults"] = val
 
     # font
     # ----
@@ -311,7 +330,7 @@ class Rangeselector(BaseLayoutHierarchyType):
     
         The 'font' property is an instance of Font
         that may be specified as:
-          - An instance of plotly.graph_objs.layout.xaxis.rangeselector.Font
+          - An instance of :class:`plotly.graph_objs.layout.xaxis.rangeselector.Font`
           - A dict of string/value properties that will be passed
             to the Font constructor
     
@@ -327,12 +346,13 @@ class Rangeselector(BaseLayoutHierarchyType):
                     Provide multiple font families, separated by
                     commas, to indicate the preference in which to
                     apply fonts if they aren't available on the
-                    system. The plotly service (at https://plot.ly
-                    or on-premise) generates images on a server,
-                    where only a select number of fonts are
-                    installed and supported. These include "Arial",
-                    "Balto", "Courier New", "Droid Sans",, "Droid
-                    Serif", "Droid Sans Mono", "Gravitas One", "Old
+                    system. The Chart Studio Cloud (at
+                    https://chart-studio.plotly.com or on-premise)
+                    generates images on a server, where only a
+                    select number of fonts are installed and
+                    supported. These include "Arial", "Balto",
+                    "Courier New", "Droid Sans",, "Droid Serif",
+                    "Droid Sans Mono", "Gravitas One", "Old
                     Standard TT", "Open Sans", "Overpass", "PT Sans
                     Narrow", "Raleway", "Times New Roman".
                 size
@@ -341,11 +361,11 @@ class Rangeselector(BaseLayoutHierarchyType):
         -------
         plotly.graph_objs.layout.xaxis.rangeselector.Font
         """
-        return self['font']
+        return self["font"]
 
     @font.setter
     def font(self, val):
-        self['font'] = val
+        self["font"] = val
 
     # visible
     # -------
@@ -363,11 +383,11 @@ class Rangeselector(BaseLayoutHierarchyType):
         -------
         bool
         """
-        return self['visible']
+        return self["visible"]
 
     @visible.setter
     def visible(self, val):
-        self['visible'] = val
+        self["visible"] = val
 
     # x
     # -
@@ -384,11 +404,11 @@ class Rangeselector(BaseLayoutHierarchyType):
         -------
         int|float
         """
-        return self['x']
+        return self["x"]
 
     @x.setter
     def x(self, val):
-        self['x'] = val
+        self["x"] = val
 
     # xanchor
     # -------
@@ -407,11 +427,11 @@ class Rangeselector(BaseLayoutHierarchyType):
         -------
         Any
         """
-        return self['xanchor']
+        return self["xanchor"]
 
     @xanchor.setter
     def xanchor(self, val):
-        self['xanchor'] = val
+        self["xanchor"] = val
 
     # y
     # -
@@ -428,11 +448,11 @@ class Rangeselector(BaseLayoutHierarchyType):
         -------
         int|float
         """
-        return self['y']
+        return self["y"]
 
     @y.setter
     def y(self, val):
-        self['y'] = val
+        self["y"] = val
 
     # yanchor
     # -------
@@ -451,17 +471,11 @@ class Rangeselector(BaseLayoutHierarchyType):
         -------
         Any
         """
-        return self['yanchor']
+        return self["yanchor"]
 
     @yanchor.setter
     def yanchor(self, val):
-        self['yanchor'] = val
-
-    # property parent name
-    # --------------------
-    @property
-    def _parent_path_str(self):
-        return 'layout.xaxis'
+        self["yanchor"] = val
 
     # Self properties description
     # ---------------------------
@@ -535,7 +549,7 @@ class Rangeselector(BaseLayoutHierarchyType):
         arg
             dict of properties compatible with this constructor or
             an instance of
-            plotly.graph_objs.layout.xaxis.Rangeselector
+            :class:`plotly.graph_objs.layout.xaxis.Rangeselector`
         activecolor
             Sets the background color of the active range selector
             button.
@@ -581,7 +595,11 @@ class Rangeselector(BaseLayoutHierarchyType):
         -------
         Rangeselector
         """
-        super(Rangeselector, self).__init__('rangeselector')
+        super(Rangeselector, self).__init__("rangeselector")
+
+        if "_parent" in kwargs:
+            self._parent = kwargs["_parent"]
+            return
 
         # Validate arg
         # ------------
@@ -590,70 +608,70 @@ class Rangeselector(BaseLayoutHierarchyType):
         elif isinstance(arg, self.__class__):
             arg = arg.to_plotly_json()
         elif isinstance(arg, dict):
-            arg = copy.copy(arg)
+            arg = _copy.copy(arg)
         else:
             raise ValueError(
                 """\
 The first argument to the plotly.graph_objs.layout.xaxis.Rangeselector 
 constructor must be a dict or 
-an instance of plotly.graph_objs.layout.xaxis.Rangeselector"""
+an instance of :class:`plotly.graph_objs.layout.xaxis.Rangeselector`"""
             )
 
         # Handle skip_invalid
         # -------------------
-        self._skip_invalid = kwargs.pop('skip_invalid', False)
-
-        # Import validators
-        # -----------------
-        from plotly.validators.layout.xaxis import (
-            rangeselector as v_rangeselector
-        )
-
-        # Initialize validators
-        # ---------------------
-        self._validators['activecolor'] = v_rangeselector.ActivecolorValidator(
-        )
-        self._validators['bgcolor'] = v_rangeselector.BgcolorValidator()
-        self._validators['bordercolor'] = v_rangeselector.BordercolorValidator(
-        )
-        self._validators['borderwidth'] = v_rangeselector.BorderwidthValidator(
-        )
-        self._validators['buttons'] = v_rangeselector.ButtonsValidator()
-        self._validators['buttondefaults'] = v_rangeselector.ButtonValidator()
-        self._validators['font'] = v_rangeselector.FontValidator()
-        self._validators['visible'] = v_rangeselector.VisibleValidator()
-        self._validators['x'] = v_rangeselector.XValidator()
-        self._validators['xanchor'] = v_rangeselector.XanchorValidator()
-        self._validators['y'] = v_rangeselector.YValidator()
-        self._validators['yanchor'] = v_rangeselector.YanchorValidator()
+        self._skip_invalid = kwargs.pop("skip_invalid", False)
+        self._validate = kwargs.pop("_validate", True)
 
         # Populate data dict with properties
         # ----------------------------------
-        _v = arg.pop('activecolor', None)
-        self['activecolor'] = activecolor if activecolor is not None else _v
-        _v = arg.pop('bgcolor', None)
-        self['bgcolor'] = bgcolor if bgcolor is not None else _v
-        _v = arg.pop('bordercolor', None)
-        self['bordercolor'] = bordercolor if bordercolor is not None else _v
-        _v = arg.pop('borderwidth', None)
-        self['borderwidth'] = borderwidth if borderwidth is not None else _v
-        _v = arg.pop('buttons', None)
-        self['buttons'] = buttons if buttons is not None else _v
-        _v = arg.pop('buttondefaults', None)
-        self['buttondefaults'
-            ] = buttondefaults if buttondefaults is not None else _v
-        _v = arg.pop('font', None)
-        self['font'] = font if font is not None else _v
-        _v = arg.pop('visible', None)
-        self['visible'] = visible if visible is not None else _v
-        _v = arg.pop('x', None)
-        self['x'] = x if x is not None else _v
-        _v = arg.pop('xanchor', None)
-        self['xanchor'] = xanchor if xanchor is not None else _v
-        _v = arg.pop('y', None)
-        self['y'] = y if y is not None else _v
-        _v = arg.pop('yanchor', None)
-        self['yanchor'] = yanchor if yanchor is not None else _v
+        _v = arg.pop("activecolor", None)
+        _v = activecolor if activecolor is not None else _v
+        if _v is not None:
+            self["activecolor"] = _v
+        _v = arg.pop("bgcolor", None)
+        _v = bgcolor if bgcolor is not None else _v
+        if _v is not None:
+            self["bgcolor"] = _v
+        _v = arg.pop("bordercolor", None)
+        _v = bordercolor if bordercolor is not None else _v
+        if _v is not None:
+            self["bordercolor"] = _v
+        _v = arg.pop("borderwidth", None)
+        _v = borderwidth if borderwidth is not None else _v
+        if _v is not None:
+            self["borderwidth"] = _v
+        _v = arg.pop("buttons", None)
+        _v = buttons if buttons is not None else _v
+        if _v is not None:
+            self["buttons"] = _v
+        _v = arg.pop("buttondefaults", None)
+        _v = buttondefaults if buttondefaults is not None else _v
+        if _v is not None:
+            self["buttondefaults"] = _v
+        _v = arg.pop("font", None)
+        _v = font if font is not None else _v
+        if _v is not None:
+            self["font"] = _v
+        _v = arg.pop("visible", None)
+        _v = visible if visible is not None else _v
+        if _v is not None:
+            self["visible"] = _v
+        _v = arg.pop("x", None)
+        _v = x if x is not None else _v
+        if _v is not None:
+            self["x"] = _v
+        _v = arg.pop("xanchor", None)
+        _v = xanchor if xanchor is not None else _v
+        if _v is not None:
+            self["xanchor"] = _v
+        _v = arg.pop("y", None)
+        _v = y if y is not None else _v
+        if _v is not None:
+            self["y"] = _v
+        _v = arg.pop("yanchor", None)
+        _v = yanchor if yanchor is not None else _v
+        if _v is not None:
+            self["yanchor"] = _v
 
         # Process unknown kwargs
         # ----------------------
