@@ -4,12 +4,14 @@ if sys.version_info < (3, 7):
     from ._domain import Domain
     from ._hoverlabel import Hoverlabel
     from ._insidetextfont import Insidetextfont
+    from ._legendgrouptitle import Legendgrouptitle
     from ._marker import Marker
     from ._outsidetextfont import Outsidetextfont
     from ._stream import Stream
     from ._textfont import Textfont
     from ._title import Title
     from . import hoverlabel
+    from . import legendgrouptitle
     from . import marker
     from . import title
 else:
@@ -17,11 +19,12 @@ else:
 
     __all__, __getattr__, __dir__ = relative_import(
         __name__,
-        [".hoverlabel", ".marker", ".title"],
+        [".hoverlabel", ".legendgrouptitle", ".marker", ".title"],
         [
             "._domain.Domain",
             "._hoverlabel.Hoverlabel",
             "._insidetextfont.Insidetextfont",
+            "._legendgrouptitle.Legendgrouptitle",
             "._marker.Marker",
             "._outsidetextfont.Outsidetextfont",
             "._stream.Stream",
