@@ -368,17 +368,17 @@ class Line(_BaseTraceHierarchyType):
                 tickformat
                     Sets the tick label formatting rule using d3
                     formatting mini-languages which are very
-                    similar to those in Python. For numbers, see:
-                    https://github.com/d3/d3-3.x-api-
-                    reference/blob/master/Formatting.md#d3_format.
-                    And for dates see:
+                    similar to those in Python. For numbers, see: h
+                    ttps://github.com/d3/d3-format/tree/v1.4.5#d3-f
+                    ormat. And for dates see:
                     https://github.com/d3/d3-time-
-                    format#locale_format. We add two items to d3's
-                    date formatter: "%h" for half of the year as a
-                    decimal number as well as "%{n}f" for
-                    fractional seconds with n digits. For example,
-                    *2016-10-13 09:15:23.456* with tickformat
-                    "%H~%M~%S.%2f" would display "09~15~23.46"
+                    format/tree/v2.2.3#locale_format. We add two
+                    items to d3's date formatter: "%h" for half of
+                    the year as a decimal number as well as "%{n}f"
+                    for fractional seconds with n digits. For
+                    example, *2016-10-13 09:15:23.456* with
+                    tickformat "%H~%M~%S.%2f" would display
+                    "09~15~23.46"
                 tickformatstops
                     A tuple of :class:`plotly.graph_objects.scatter
                     3d.line.colorbar.Tickformatstop` instances or
@@ -426,14 +426,14 @@ class Line(_BaseTraceHierarchyType):
                     `tickvals`.
                 ticktextsrc
                     Sets the source reference on Chart Studio Cloud
-                    for  ticktext .
+                    for `ticktext`.
                 tickvals
                     Sets the values at which ticks on this axis
                     appear. Only has an effect if `tickmode` is set
                     to "array". Used with `ticktext`.
                 tickvalssrc
                     Sets the source reference on Chart Studio Cloud
-                    for  tickvals .
+                    for `tickvals`.
                 tickwidth
                     Sets the tick width (in px).
                 title
@@ -498,9 +498,9 @@ class Line(_BaseTraceHierarchyType):
         example, `[[0, 'rgb(0,0,255)'], [1, 'rgb(255,0,0)']]`. To
         control the bounds of the colorscale in color space,
         use`line.cmin` and `line.cmax`. Alternatively, `colorscale` may
-        be a palette name string of the following list: Greys,YlGnBu,Gr
-        eens,YlOrRd,Bluered,RdBu,Reds,Blues,Picnic,Rainbow,Portland,Jet
-        ,Hot,Blackbody,Earth,Electric,Viridis,Cividis.
+        be a palette name string of the following list: Blackbody,Bluer
+        ed,Blues,Cividis,Earth,Electric,Greens,Greys,Hot,Jet,Picnic,Por
+        tland,Rainbow,RdBu,Reds,Viridis,YlGnBu,YlOrRd.
     
         The 'colorscale' property is a colorscale and may be
         specified as:
@@ -544,7 +544,7 @@ class Line(_BaseTraceHierarchyType):
     @property
     def colorsrc(self):
         """
-        Sets the source reference on Chart Studio Cloud for  color .
+        Sets the source reference on Chart Studio Cloud for `color`.
     
         The 'colorsrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -568,8 +568,8 @@ class Line(_BaseTraceHierarchyType):
     
         The 'dash' property is an enumeration that may be specified as:
           - One of the following enumeration values:
-                ['solid', 'dot', 'dash', 'longdash', 'dashdot',
-                'longdashdot']
+                ['dash', 'dashdot', 'dot', 'longdash', 'longdashdot',
+                'solid']
 
         Returns
         -------
@@ -710,13 +710,13 @@ class Line(_BaseTraceHierarchyType):
             'rgb(0,0,255)'], [1, 'rgb(255,0,0)']]`. To control the
             bounds of the colorscale in color space, use`line.cmin`
             and `line.cmax`. Alternatively, `colorscale` may be a
-            palette name string of the following list: Greys,YlGnBu
-            ,Greens,YlOrRd,Bluered,RdBu,Reds,Blues,Picnic,Rainbow,P
-            ortland,Jet,Hot,Blackbody,Earth,Electric,Viridis,Cividi
-            s.
+            palette name string of the following list: Blackbody,Bl
+            uered,Blues,Cividis,Earth,Electric,Greens,Greys,Hot,Jet
+            ,Picnic,Portland,Rainbow,RdBu,Reds,Viridis,YlGnBu,YlOrR
+            d.
         colorsrc
             Sets the source reference on Chart Studio Cloud for
-            color .
+            `color`.
         dash
             Sets the dash style of the lines.
         reversescale
@@ -820,13 +820,13 @@ class Line(_BaseTraceHierarchyType):
             'rgb(0,0,255)'], [1, 'rgb(255,0,0)']]`. To control the
             bounds of the colorscale in color space, use`line.cmin`
             and `line.cmax`. Alternatively, `colorscale` may be a
-            palette name string of the following list: Greys,YlGnBu
-            ,Greens,YlOrRd,Bluered,RdBu,Reds,Blues,Picnic,Rainbow,P
-            ortland,Jet,Hot,Blackbody,Earth,Electric,Viridis,Cividi
-            s.
+            palette name string of the following list: Blackbody,Bl
+            uered,Blues,Cividis,Earth,Electric,Greens,Greys,Hot,Jet
+            ,Picnic,Portland,Rainbow,RdBu,Reds,Viridis,YlGnBu,YlOrR
+            d.
         colorsrc
             Sets the source reference on Chart Studio Cloud for
-            color .
+            `color`.
         dash
             Sets the dash style of the lines.
         reversescale
