@@ -436,14 +436,14 @@ class Marker(_BaseTraceHierarchyType):
                     `tickvals`.
                 ticktextsrc
                     Sets the source reference on Chart Studio Cloud
-                    for  ticktext .
+                    for `ticktext`.
                 tickvals
                     Sets the values at which ticks on this axis
                     appear. Only has an effect if `tickmode` is set
                     to "array". Used with `ticktext`.
                 tickvalssrc
                     Sets the source reference on Chart Studio Cloud
-                    for  tickvals .
+                    for `tickvals`.
                 tickwidth
                     Sets the tick width (in px).
                 title
@@ -554,7 +554,7 @@ class Marker(_BaseTraceHierarchyType):
     @property
     def colorsrc(self):
         """
-        Sets the source reference on Chart Studio Cloud for  color .
+        Sets the source reference on Chart Studio Cloud for `color`.
     
         The 'colorsrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -588,13 +588,13 @@ class Marker(_BaseTraceHierarchyType):
                     horizontal, or the bottom for vertical.
                 colorsrc
                     Sets the source reference on Chart Studio Cloud
-                    for  color .
+                    for `color`.
                 type
                     Sets the type of gradient used to fill the
                     markers
                 typesrc
                     Sets the source reference on Chart Studio Cloud
-                    for  type .
+                    for `type`.
 
         Returns
         -------
@@ -693,7 +693,7 @@ class Marker(_BaseTraceHierarchyType):
                     bow,RdBu,Reds,Viridis,YlGnBu,YlOrRd.
                 colorsrc
                     Sets the source reference on Chart Studio Cloud
-                    for  color .
+                    for `color`.
                 reversescale
                     Reverses the color mapping if true. Has an
                     effect only if in `marker.line.color`is set to
@@ -706,7 +706,7 @@ class Marker(_BaseTraceHierarchyType):
                     the marker points.
                 widthsrc
                     Sets the source reference on Chart Studio Cloud
-                    for  width .
+                    for `width`.
 
         Returns
         -------
@@ -744,7 +744,7 @@ class Marker(_BaseTraceHierarchyType):
     @property
     def opacitysrc(self):
         """
-        Sets the source reference on Chart Studio Cloud for  opacity .
+        Sets the source reference on Chart Studio Cloud for `opacity`.
     
         The 'opacitysrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -897,7 +897,7 @@ class Marker(_BaseTraceHierarchyType):
     @property
     def sizesrc(self):
         """
-        Sets the source reference on Chart Studio Cloud for  size .
+        Sets the source reference on Chart Studio Cloud for `size`.
     
         The 'sizesrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -1028,7 +1028,7 @@ class Marker(_BaseTraceHierarchyType):
     @property
     def symbolsrc(self):
         """
-        Sets the source reference on Chart Studio Cloud for  symbol .
+        Sets the source reference on Chart Studio Cloud for `symbol`.
     
         The 'symbolsrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -1113,7 +1113,7 @@ class Marker(_BaseTraceHierarchyType):
             Bu,Reds,Viridis,YlGnBu,YlOrRd.
         colorsrc
             Sets the source reference on Chart Studio Cloud for
-            color .
+            `color`.
         gradient
             :class:`plotly.graph_objects.scattergeo.marker.Gradient
             ` instance or dict with compatible properties
@@ -1124,7 +1124,7 @@ class Marker(_BaseTraceHierarchyType):
             Sets the marker opacity.
         opacitysrc
             Sets the source reference on Chart Studio Cloud for
-            opacity .
+            `opacity`.
         reversescale
             Reverses the color mapping if true. Has an effect only
             if in `marker.color`is set to a numerical array. If
@@ -1152,7 +1152,7 @@ class Marker(_BaseTraceHierarchyType):
             `sizemin` and `sizemode`.
         sizesrc
             Sets the source reference on Chart Studio Cloud for
-            size .
+            `size`.
         symbol
             Sets the marker symbol type. Adding 100 is equivalent
             to appending "-open" to a symbol name. Adding 200 is
@@ -1161,7 +1161,7 @@ class Marker(_BaseTraceHierarchyType):
             open" to a symbol name.
         symbolsrc
             Sets the source reference on Chart Studio Cloud for
-            symbol .
+            `symbol`.
         """
 
     def __init__(
@@ -1266,7 +1266,7 @@ class Marker(_BaseTraceHierarchyType):
             Bu,Reds,Viridis,YlGnBu,YlOrRd.
         colorsrc
             Sets the source reference on Chart Studio Cloud for
-            color .
+            `color`.
         gradient
             :class:`plotly.graph_objects.scattergeo.marker.Gradient
             ` instance or dict with compatible properties
@@ -1277,7 +1277,7 @@ class Marker(_BaseTraceHierarchyType):
             Sets the marker opacity.
         opacitysrc
             Sets the source reference on Chart Studio Cloud for
-            opacity .
+            `opacity`.
         reversescale
             Reverses the color mapping if true. Has an effect only
             if in `marker.color`is set to a numerical array. If
@@ -1305,7 +1305,7 @@ class Marker(_BaseTraceHierarchyType):
             `sizemin` and `sizemode`.
         sizesrc
             Sets the source reference on Chart Studio Cloud for
-            size .
+            `size`.
         symbol
             Sets the marker symbol type. Adding 100 is equivalent
             to appending "-open" to a symbol name. Adding 200 is
@@ -1314,7 +1314,7 @@ class Marker(_BaseTraceHierarchyType):
             open" to a symbol name.
         symbolsrc
             Sets the source reference on Chart Studio Cloud for
-            symbol .
+            `symbol`.
 
         Returns
         -------
