@@ -34,6 +34,7 @@ class ColorBar(_BaseTraceHierarchyType):
         "tickformat",
         "tickformatstopdefaults",
         "tickformatstops",
+        "ticklabeloverflow",
         "ticklabelposition",
         "ticklen",
         "tickmode",
@@ -742,12 +743,14 @@ class ColorBar(_BaseTraceHierarchyType):
         """
         Sets the tick label formatting rule using d3 formatting mini-
         languages which are very similar to those in Python. For
-        numbers, see: https://github.com/d3/d3-3.x-api-
-        reference/blob/master/Formatting.md#d3_format And for dates
-        see: https://github.com/d3/d3-time-format#locale_format We add
-        one item to d3's date formatter: "%{n}f" for fractional seconds
-        with n digits. For example, *2016-10-13 09:15:23.456* with
-        tickformat "%H~%M~%S.%2f" would display "09~15~23.46"
+        numbers, see:
+        https://github.com/d3/d3-format/tree/v1.4.5#d3-format. And for
+        dates see: https://github.com/d3/d3-time-
+        format/tree/v2.2.3#locale_format. We add two items to d3's date
+        formatter: "%h" for half of the year as a decimal number as
+        well as "%{n}f" for fractional seconds with n digits. For
+        example, *2016-10-13 09:15:23.456* with tickformat
+        "%H~%M~%S.%2f" would display "09~15~23.46"
     
         The 'tickformat' property is a string and must be specified as:
           - A string
@@ -848,6 +851,30 @@ class ColorBar(_BaseTraceHierarchyType):
     def tickformatstopdefaults(self, val):
         self["tickformatstopdefaults"] = val
 
+    # ticklabeloverflow
+    # -----------------
+    @property
+    def ticklabeloverflow(self):
+        """
+        Determines how we handle tick labels that would overflow either
+        the graph div or the domain of the axis. The default value for
+        inside tick labels is *hide past domain*. In other cases the
+        default is *hide past div*.
+    
+        The 'ticklabeloverflow' property is an enumeration that may be specified as:
+          - One of the following enumeration values:
+                ['allow', 'hide past div', 'hide past domain']
+
+        Returns
+        -------
+        Any
+        """
+        return self["ticklabeloverflow"]
+
+    @ticklabeloverflow.setter
+    def ticklabeloverflow(self, val):
+        self["ticklabeloverflow"] = val
+
     # ticklabelposition
     # -----------------
     @property
@@ -1009,7 +1036,7 @@ class ColorBar(_BaseTraceHierarchyType):
     @property
     def ticktextsrc(self):
         """
-        Sets the source reference on Chart Studio Cloud for  ticktext .
+        Sets the source reference on Chart Studio Cloud for `ticktext`.
     
         The 'ticktextsrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -1050,7 +1077,7 @@ class ColorBar(_BaseTraceHierarchyType):
     @property
     def tickvalssrc(self):
         """
-        Sets the source reference on Chart Studio Cloud for  tickvals .
+        Sets the source reference on Chart Studio Cloud for `tickvals`.
     
         The 'tickvalssrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -1435,13 +1462,14 @@ class ColorBar(_BaseTraceHierarchyType):
             Sets the tick label formatting rule using d3 formatting
             mini-languages which are very similar to those in
             Python. For numbers, see:
-            https://github.com/d3/d3-3.x-api-
-            reference/blob/master/Formatting.md#d3_format And for
-            dates see: https://github.com/d3/d3-time-
-            format#locale_format We add one item to d3's date
-            formatter: "%{n}f" for fractional seconds with n
-            digits. For example, *2016-10-13 09:15:23.456* with
-            tickformat "%H~%M~%S.%2f" would display "09~15~23.46"
+            https://github.com/d3/d3-format/tree/v1.4.5#d3-format.
+            And for dates see: https://github.com/d3/d3-time-
+            format/tree/v2.2.3#locale_format. We add two items to
+            d3's date formatter: "%h" for half of the year as a
+            decimal number as well as "%{n}f" for fractional
+            seconds with n digits. For example, *2016-10-13
+            09:15:23.456* with tickformat "%H~%M~%S.%2f" would
+            display "09~15~23.46"
         tickformatstops
             A tuple of :class:`plotly.graph_objects.scattergeo.mark
             er.colorbar.Tickformatstop` instances or dicts with
@@ -1451,6 +1479,12 @@ class ColorBar(_BaseTraceHierarchyType):
             rgeo.marker.colorbar.tickformatstopdefaults), sets the
             default property values to use for elements of
             scattergeo.marker.colorbar.tickformatstops
+        ticklabeloverflow
+            Determines how we handle tick labels that would
+            overflow either the graph div or the domain of the
+            axis. The default value for inside tick labels is *hide
+            past domain*. In other cases the default is *hide past
+            div*.
         ticklabelposition
             Determines where tick labels are drawn.
         ticklen
@@ -1478,14 +1512,14 @@ class ColorBar(_BaseTraceHierarchyType):
             "array". Used with `tickvals`.
         ticktextsrc
             Sets the source reference on Chart Studio Cloud for
-            ticktext .
+            `ticktext`.
         tickvals
             Sets the values at which ticks on this axis appear.
             Only has an effect if `tickmode` is set to "array".
             Used with `ticktext`.
         tickvalssrc
             Sets the source reference on Chart Studio Cloud for
-            tickvals .
+            `tickvals`.
         tickwidth
             Sets the tick width (in px).
         title
@@ -1559,6 +1593,7 @@ class ColorBar(_BaseTraceHierarchyType):
         tickformat=None,
         tickformatstops=None,
         tickformatstopdefaults=None,
+        ticklabeloverflow=None,
         ticklabelposition=None,
         ticklen=None,
         tickmode=None,
@@ -1697,13 +1732,14 @@ class ColorBar(_BaseTraceHierarchyType):
             Sets the tick label formatting rule using d3 formatting
             mini-languages which are very similar to those in
             Python. For numbers, see:
-            https://github.com/d3/d3-3.x-api-
-            reference/blob/master/Formatting.md#d3_format And for
-            dates see: https://github.com/d3/d3-time-
-            format#locale_format We add one item to d3's date
-            formatter: "%{n}f" for fractional seconds with n
-            digits. For example, *2016-10-13 09:15:23.456* with
-            tickformat "%H~%M~%S.%2f" would display "09~15~23.46"
+            https://github.com/d3/d3-format/tree/v1.4.5#d3-format.
+            And for dates see: https://github.com/d3/d3-time-
+            format/tree/v2.2.3#locale_format. We add two items to
+            d3's date formatter: "%h" for half of the year as a
+            decimal number as well as "%{n}f" for fractional
+            seconds with n digits. For example, *2016-10-13
+            09:15:23.456* with tickformat "%H~%M~%S.%2f" would
+            display "09~15~23.46"
         tickformatstops
             A tuple of :class:`plotly.graph_objects.scattergeo.mark
             er.colorbar.Tickformatstop` instances or dicts with
@@ -1713,6 +1749,12 @@ class ColorBar(_BaseTraceHierarchyType):
             rgeo.marker.colorbar.tickformatstopdefaults), sets the
             default property values to use for elements of
             scattergeo.marker.colorbar.tickformatstops
+        ticklabeloverflow
+            Determines how we handle tick labels that would
+            overflow either the graph div or the domain of the
+            axis. The default value for inside tick labels is *hide
+            past domain*. In other cases the default is *hide past
+            div*.
         ticklabelposition
             Determines where tick labels are drawn.
         ticklen
@@ -1740,14 +1782,14 @@ class ColorBar(_BaseTraceHierarchyType):
             "array". Used with `tickvals`.
         ticktextsrc
             Sets the source reference on Chart Studio Cloud for
-            ticktext .
+            `ticktext`.
         tickvals
             Sets the values at which ticks on this axis appear.
             Only has an effect if `tickmode` is set to "array".
             Used with `ticktext`.
         tickvalssrc
             Sets the source reference on Chart Studio Cloud for
-            tickvals .
+            `tickvals`.
         tickwidth
             Sets the tick width (in px).
         title
@@ -1920,6 +1962,10 @@ an instance of :class:`plotly.graph_objs.scattergeo.marker.ColorBar`"""
         _v = tickformatstopdefaults if tickformatstopdefaults is not None else _v
         if _v is not None:
             self["tickformatstopdefaults"] = _v
+        _v = arg.pop("ticklabeloverflow", None)
+        _v = ticklabeloverflow if ticklabeloverflow is not None else _v
+        if _v is not None:
+            self["ticklabeloverflow"] = _v
         _v = arg.pop("ticklabelposition", None)
         _v = ticklabelposition if ticklabelposition is not None else _v
         if _v is not None:
