@@ -74,8 +74,8 @@ class ErrorX(_BaseTraceHierarchyType):
     @property
     def arrayminussrc(self):
         """
-        Sets the source reference on Chart Studio Cloud for  arrayminus
-        .
+        Sets the source reference on Chart Studio Cloud for
+        `arrayminus`.
     
         The 'arrayminussrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -95,7 +95,7 @@ class ErrorX(_BaseTraceHierarchyType):
     @property
     def arraysrc(self):
         """
-        Sets the source reference on Chart Studio Cloud for  array .
+        Sets the source reference on Chart Studio Cloud for `array`.
     
         The 'arraysrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -396,10 +396,10 @@ class ErrorX(_BaseTraceHierarchyType):
             underlying data.
         arrayminussrc
             Sets the source reference on Chart Studio Cloud for
-            arrayminus .
+            `arrayminus`.
         arraysrc
             Sets the source reference on Chart Studio Cloud for
-            array .
+            `array`.
         color
             Sets the stoke color of the error bars.
         copy_ystyle
@@ -482,10 +482,10 @@ class ErrorX(_BaseTraceHierarchyType):
             underlying data.
         arrayminussrc
             Sets the source reference on Chart Studio Cloud for
-            arrayminus .
+            `arrayminus`.
         arraysrc
             Sets the source reference on Chart Studio Cloud for
-            array .
+            `array`.
         color
             Sets the stoke color of the error bars.
         copy_ystyle
