@@ -1,8 +1,14 @@
-from plotly.basedatatypes import BaseTraceHierarchyType
-import copy
+from plotly.basedatatypes import BaseTraceHierarchyType as _BaseTraceHierarchyType
+import copy as _copy
 
 
-class Textfont(BaseTraceHierarchyType):
+class Textfont(_BaseTraceHierarchyType):
+
+    # class properties
+    # --------------------
+    _parent_path_str = "scattergl"
+    _path_str = "scattergl.textfont"
+    _valid_props = {"color", "colorsrc", "family", "familysrc", "size", "sizesrc"}
 
     # color
     # -----
@@ -44,30 +50,30 @@ class Textfont(BaseTraceHierarchyType):
                 orchid, palegoldenrod, palegreen, paleturquoise,
                 palevioletred, papayawhip, peachpuff, peru, pink,
                 plum, powderblue, purple, red, rosybrown,
-                royalblue, saddlebrown, salmon, sandybrown,
-                seagreen, seashell, sienna, silver, skyblue,
-                slateblue, slategray, slategrey, snow, springgreen,
-                steelblue, tan, teal, thistle, tomato, turquoise,
-                violet, wheat, white, whitesmoke, yellow,
-                yellowgreen
+                royalblue, rebeccapurple, saddlebrown, salmon,
+                sandybrown, seagreen, seashell, sienna, silver,
+                skyblue, slateblue, slategray, slategrey, snow,
+                springgreen, steelblue, tan, teal, thistle, tomato,
+                turquoise, violet, wheat, white, whitesmoke,
+                yellow, yellowgreen
           - A list or array of any of the above
 
         Returns
         -------
         str|numpy.ndarray
         """
-        return self['color']
+        return self["color"]
 
     @color.setter
     def color(self, val):
-        self['color'] = val
+        self["color"] = val
 
     # colorsrc
     # --------
     @property
     def colorsrc(self):
         """
-        Sets the source reference on plot.ly for  color .
+        Sets the source reference on Chart Studio Cloud for `color`.
     
         The 'colorsrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -76,11 +82,11 @@ class Textfont(BaseTraceHierarchyType):
         -------
         str
         """
-        return self['colorsrc']
+        return self["colorsrc"]
 
     @colorsrc.setter
     def colorsrc(self, val):
-        self['colorsrc'] = val
+        self["colorsrc"] = val
 
     # family
     # ------
@@ -92,13 +98,13 @@ class Textfont(BaseTraceHierarchyType):
         it is available on the system which it operates. Provide
         multiple font families, separated by commas, to indicate the
         preference in which to apply fonts if they aren't available on
-        the system. The plotly service (at https://plot.ly or on-
-        premise) generates images on a server, where only a select
-        number of fonts are installed and supported. These include
-        "Arial", "Balto", "Courier New", "Droid Sans",, "Droid Serif",
-        "Droid Sans Mono", "Gravitas One", "Old Standard TT", "Open
-        Sans", "Overpass", "PT Sans Narrow", "Raleway", "Times New
-        Roman".
+        the system. The Chart Studio Cloud (at https://chart-
+        studio.plotly.com or on-premise) generates images on a server,
+        where only a select number of fonts are installed and
+        supported. These include "Arial", "Balto", "Courier New",
+        "Droid Sans",, "Droid Serif", "Droid Sans Mono", "Gravitas
+        One", "Old Standard TT", "Open Sans", "Overpass", "PT Sans
+        Narrow", "Raleway", "Times New Roman".
     
         The 'family' property is a string and must be specified as:
           - A non-empty string
@@ -108,18 +114,18 @@ class Textfont(BaseTraceHierarchyType):
         -------
         str|numpy.ndarray
         """
-        return self['family']
+        return self["family"]
 
     @family.setter
     def family(self, val):
-        self['family'] = val
+        self["family"] = val
 
     # familysrc
     # ---------
     @property
     def familysrc(self):
         """
-        Sets the source reference on plot.ly for  family .
+        Sets the source reference on Chart Studio Cloud for `family`.
     
         The 'familysrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -128,11 +134,11 @@ class Textfont(BaseTraceHierarchyType):
         -------
         str
         """
-        return self['familysrc']
+        return self["familysrc"]
 
     @familysrc.setter
     def familysrc(self, val):
-        self['familysrc'] = val
+        self["familysrc"] = val
 
     # size
     # ----
@@ -147,18 +153,18 @@ class Textfont(BaseTraceHierarchyType):
         -------
         int|float|numpy.ndarray
         """
-        return self['size']
+        return self["size"]
 
     @size.setter
     def size(self, val):
-        self['size'] = val
+        self["size"] = val
 
     # sizesrc
     # -------
     @property
     def sizesrc(self):
         """
-        Sets the source reference on plot.ly for  size .
+        Sets the source reference on Chart Studio Cloud for `size`.
     
         The 'sizesrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -167,17 +173,11 @@ class Textfont(BaseTraceHierarchyType):
         -------
         str
         """
-        return self['sizesrc']
+        return self["sizesrc"]
 
     @sizesrc.setter
     def sizesrc(self, val):
-        self['sizesrc'] = val
-
-    # property parent name
-    # --------------------
-    @property
-    def _parent_path_str(self):
-        return 'scattergl'
+        self["sizesrc"] = val
 
     # Self properties description
     # ---------------------------
@@ -187,27 +187,30 @@ class Textfont(BaseTraceHierarchyType):
         color
 
         colorsrc
-            Sets the source reference on plot.ly for  color .
+            Sets the source reference on Chart Studio Cloud for
+            `color`.
         family
             HTML font family - the typeface that will be applied by
             the web browser. The web browser will only be able to
             apply a font if it is available on the system which it
             operates. Provide multiple font families, separated by
             commas, to indicate the preference in which to apply
-            fonts if they aren't available on the system. The
-            plotly service (at https://plot.ly or on-premise)
-            generates images on a server, where only a select
-            number of fonts are installed and supported. These
-            include "Arial", "Balto", "Courier New", "Droid Sans",,
-            "Droid Serif", "Droid Sans Mono", "Gravitas One", "Old
-            Standard TT", "Open Sans", "Overpass", "PT Sans
-            Narrow", "Raleway", "Times New Roman".
+            fonts if they aren't available on the system. The Chart
+            Studio Cloud (at https://chart-studio.plotly.com or on-
+            premise) generates images on a server, where only a
+            select number of fonts are installed and supported.
+            These include "Arial", "Balto", "Courier New", "Droid
+            Sans",, "Droid Serif", "Droid Sans Mono", "Gravitas
+            One", "Old Standard TT", "Open Sans", "Overpass", "PT
+            Sans Narrow", "Raleway", "Times New Roman".
         familysrc
-            Sets the source reference on plot.ly for  family .
+            Sets the source reference on Chart Studio Cloud for
+            `family`.
         size
 
         sizesrc
-            Sets the source reference on plot.ly for  size .
+            Sets the source reference on Chart Studio Cloud for
+            `size`.
         """
 
     def __init__(
@@ -230,37 +233,45 @@ class Textfont(BaseTraceHierarchyType):
         ----------
         arg
             dict of properties compatible with this constructor or
-            an instance of plotly.graph_objs.scattergl.Textfont
+            an instance of
+            :class:`plotly.graph_objs.scattergl.Textfont`
         color
 
         colorsrc
-            Sets the source reference on plot.ly for  color .
+            Sets the source reference on Chart Studio Cloud for
+            `color`.
         family
             HTML font family - the typeface that will be applied by
             the web browser. The web browser will only be able to
             apply a font if it is available on the system which it
             operates. Provide multiple font families, separated by
             commas, to indicate the preference in which to apply
-            fonts if they aren't available on the system. The
-            plotly service (at https://plot.ly or on-premise)
-            generates images on a server, where only a select
-            number of fonts are installed and supported. These
-            include "Arial", "Balto", "Courier New", "Droid Sans",,
-            "Droid Serif", "Droid Sans Mono", "Gravitas One", "Old
-            Standard TT", "Open Sans", "Overpass", "PT Sans
-            Narrow", "Raleway", "Times New Roman".
+            fonts if they aren't available on the system. The Chart
+            Studio Cloud (at https://chart-studio.plotly.com or on-
+            premise) generates images on a server, where only a
+            select number of fonts are installed and supported.
+            These include "Arial", "Balto", "Courier New", "Droid
+            Sans",, "Droid Serif", "Droid Sans Mono", "Gravitas
+            One", "Old Standard TT", "Open Sans", "Overpass", "PT
+            Sans Narrow", "Raleway", "Times New Roman".
         familysrc
-            Sets the source reference on plot.ly for  family .
+            Sets the source reference on Chart Studio Cloud for
+            `family`.
         size
 
         sizesrc
-            Sets the source reference on plot.ly for  size .
+            Sets the source reference on Chart Studio Cloud for
+            `size`.
 
         Returns
         -------
         Textfont
         """
-        super(Textfont, self).__init__('textfont')
+        super(Textfont, self).__init__("textfont")
+
+        if "_parent" in kwargs:
+            self._parent = kwargs["_parent"]
+            return
 
         # Validate arg
         # ------------
@@ -269,46 +280,46 @@ class Textfont(BaseTraceHierarchyType):
         elif isinstance(arg, self.__class__):
             arg = arg.to_plotly_json()
         elif isinstance(arg, dict):
-            arg = copy.copy(arg)
+            arg = _copy.copy(arg)
         else:
             raise ValueError(
                 """\
 The first argument to the plotly.graph_objs.scattergl.Textfont 
 constructor must be a dict or 
-an instance of plotly.graph_objs.scattergl.Textfont"""
+an instance of :class:`plotly.graph_objs.scattergl.Textfont`"""
             )
 
         # Handle skip_invalid
         # -------------------
-        self._skip_invalid = kwargs.pop('skip_invalid', False)
-
-        # Import validators
-        # -----------------
-        from plotly.validators.scattergl import (textfont as v_textfont)
-
-        # Initialize validators
-        # ---------------------
-        self._validators['color'] = v_textfont.ColorValidator()
-        self._validators['colorsrc'] = v_textfont.ColorsrcValidator()
-        self._validators['family'] = v_textfont.FamilyValidator()
-        self._validators['familysrc'] = v_textfont.FamilysrcValidator()
-        self._validators['size'] = v_textfont.SizeValidator()
-        self._validators['sizesrc'] = v_textfont.SizesrcValidator()
+        self._skip_invalid = kwargs.pop("skip_invalid", False)
+        self._validate = kwargs.pop("_validate", True)
 
         # Populate data dict with properties
         # ----------------------------------
-        _v = arg.pop('color', None)
-        self['color'] = color if color is not None else _v
-        _v = arg.pop('colorsrc', None)
-        self['colorsrc'] = colorsrc if colorsrc is not None else _v
-        _v = arg.pop('family', None)
-        self['family'] = family if family is not None else _v
-        _v = arg.pop('familysrc', None)
-        self['familysrc'] = familysrc if familysrc is not None else _v
-        _v = arg.pop('size', None)
-        self['size'] = size if size is not None else _v
-        _v = arg.pop('sizesrc', None)
-        self['sizesrc'] = sizesrc if sizesrc is not None else _v
+        _v = arg.pop("color", None)
+        _v = color if color is not None else _v
+        if _v is not None:
+            self["color"] = _v
+        _v = arg.pop("colorsrc", None)
+        _v = colorsrc if colorsrc is not None else _v
+        if _v is not None:
+            self["colorsrc"] = _v
+        _v = arg.pop("family", None)
+        _v = family if family is not None else _v
+        if _v is not None:
+            self["family"] = _v
+        _v = arg.pop("familysrc", None)
+        _v = familysrc if familysrc is not None else _v
+        if _v is not None:
+            self["familysrc"] = _v
+        _v = arg.pop("size", None)
+        _v = size if size is not None else _v
+        if _v is not None:
+            self["size"] = _v
+        _v = arg.pop("sizesrc", None)
+        _v = sizesrc if sizesrc is not None else _v
+        if _v is not None:
+            self["sizesrc"] = _v
 
         # Process unknown kwargs
         # ----------------------
