@@ -379,16 +379,17 @@ class Marker(_BaseTraceHierarchyType):
                 tickformat
                     Sets the tick label formatting rule using d3
                     formatting mini-languages which are very
-                    similar to those in Python. For numbers, see:
-                    https://github.com/d3/d3-3.x-api-
-                    reference/blob/master/Formatting.md#d3_format
-                    And for dates see:
+                    similar to those in Python. For numbers, see: h
+                    ttps://github.com/d3/d3-format/tree/v1.4.5#d3-f
+                    ormat. And for dates see:
                     https://github.com/d3/d3-time-
-                    format#locale_format We add one item to d3's
-                    date formatter: "%{n}f" for fractional seconds
-                    with n digits. For example, *2016-10-13
-                    09:15:23.456* with tickformat "%H~%M~%S.%2f"
-                    would display "09~15~23.46"
+                    format/tree/v2.2.3#locale_format. We add two
+                    items to d3's date formatter: "%h" for half of
+                    the year as a decimal number as well as "%{n}f"
+                    for fractional seconds with n digits. For
+                    example, *2016-10-13 09:15:23.456* with
+                    tickformat "%H~%M~%S.%2f" would display
+                    "09~15~23.46"
                 tickformatstops
                     A tuple of :class:`plotly.graph_objects.scatter
                     ternary.marker.colorbar.Tickformatstop`
@@ -399,6 +400,12 @@ class Marker(_BaseTraceHierarchyType):
                     defaults), sets the default property values to
                     use for elements of
                     scatterternary.marker.colorbar.tickformatstops
+                ticklabeloverflow
+                    Determines how we handle tick labels that would
+                    overflow either the graph div or the domain of
+                    the axis. The default value for inside tick
+                    labels is *hide past domain*. In other cases
+                    the default is *hide past div*.
                 ticklabelposition
                     Determines where tick labels are drawn.
                 ticklen
@@ -430,14 +437,14 @@ class Marker(_BaseTraceHierarchyType):
                     `tickvals`.
                 ticktextsrc
                     Sets the source reference on Chart Studio Cloud
-                    for  ticktext .
+                    for `ticktext`.
                 tickvals
                     Sets the values at which ticks on this axis
                     appear. Only has an effect if `tickmode` is set
                     to "array". Used with `ticktext`.
                 tickvalssrc
                     Sets the source reference on Chart Studio Cloud
-                    for  tickvals .
+                    for `tickvals`.
                 tickwidth
                     Sets the tick width (in px).
                 title
@@ -502,9 +509,9 @@ class Marker(_BaseTraceHierarchyType):
         example, `[[0, 'rgb(0,0,255)'], [1, 'rgb(255,0,0)']]`. To
         control the bounds of the colorscale in color space,
         use`marker.cmin` and `marker.cmax`. Alternatively, `colorscale`
-        may be a palette name string of the following list: Greys,YlGnB
-        u,Greens,YlOrRd,Bluered,RdBu,Reds,Blues,Picnic,Rainbow,Portland
-        ,Jet,Hot,Blackbody,Earth,Electric,Viridis,Cividis.
+        may be a palette name string of the following list: Blackbody,B
+        luered,Blues,Cividis,Earth,Electric,Greens,Greys,Hot,Jet,Picnic
+        ,Portland,Rainbow,RdBu,Reds,Viridis,YlGnBu,YlOrRd.
     
         The 'colorscale' property is a colorscale and may be
         specified as:
@@ -548,7 +555,7 @@ class Marker(_BaseTraceHierarchyType):
     @property
     def colorsrc(self):
         """
-        Sets the source reference on Chart Studio Cloud for  color .
+        Sets the source reference on Chart Studio Cloud for `color`.
     
         The 'colorsrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -582,13 +589,13 @@ class Marker(_BaseTraceHierarchyType):
                     horizontal, or the bottom for vertical.
                 colorsrc
                     Sets the source reference on Chart Studio Cloud
-                    for  color .
+                    for `color`.
                 type
                     Sets the type of gradient used to fill the
                     markers
                 typesrc
                     Sets the source reference on Chart Studio Cloud
-                    for  type .
+                    for `type`.
 
         Returns
         -------
@@ -682,12 +689,12 @@ class Marker(_BaseTraceHierarchyType):
                     color space, use`marker.line.cmin` and
                     `marker.line.cmax`. Alternatively, `colorscale`
                     may be a palette name string of the following
-                    list: Greys,YlGnBu,Greens,YlOrRd,Bluered,RdBu,R
-                    eds,Blues,Picnic,Rainbow,Portland,Jet,Hot,Black
-                    body,Earth,Electric,Viridis,Cividis.
+                    list: Blackbody,Bluered,Blues,Cividis,Earth,Ele
+                    ctric,Greens,Greys,Hot,Jet,Picnic,Portland,Rain
+                    bow,RdBu,Reds,Viridis,YlGnBu,YlOrRd.
                 colorsrc
                     Sets the source reference on Chart Studio Cloud
-                    for  color .
+                    for `color`.
                 reversescale
                     Reverses the color mapping if true. Has an
                     effect only if in `marker.line.color`is set to
@@ -700,7 +707,7 @@ class Marker(_BaseTraceHierarchyType):
                     the marker points.
                 widthsrc
                     Sets the source reference on Chart Studio Cloud
-                    for  width .
+                    for `width`.
 
         Returns
         -------
@@ -759,7 +766,7 @@ class Marker(_BaseTraceHierarchyType):
     @property
     def opacitysrc(self):
         """
-        Sets the source reference on Chart Studio Cloud for  opacity .
+        Sets the source reference on Chart Studio Cloud for `opacity`.
     
         The 'opacitysrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -912,7 +919,7 @@ class Marker(_BaseTraceHierarchyType):
     @property
     def sizesrc(self):
         """
-        Sets the source reference on Chart Studio Cloud for  size .
+        Sets the source reference on Chart Studio Cloud for `size`.
     
         The 'sizesrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -1043,7 +1050,7 @@ class Marker(_BaseTraceHierarchyType):
     @property
     def symbolsrc(self):
         """
-        Sets the source reference on Chart Studio Cloud for  symbol .
+        Sets the source reference on Chart Studio Cloud for `symbol`.
     
         The 'symbolsrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -1123,12 +1130,12 @@ class Marker(_BaseTraceHierarchyType):
             To control the bounds of the colorscale in color space,
             use`marker.cmin` and `marker.cmax`. Alternatively,
             `colorscale` may be a palette name string of the
-            following list: Greys,YlGnBu,Greens,YlOrRd,Bluered,RdBu
-            ,Reds,Blues,Picnic,Rainbow,Portland,Jet,Hot,Blackbody,E
-            arth,Electric,Viridis,Cividis.
+            following list: Blackbody,Bluered,Blues,Cividis,Earth,E
+            lectric,Greens,Greys,Hot,Jet,Picnic,Portland,Rainbow,Rd
+            Bu,Reds,Viridis,YlGnBu,YlOrRd.
         colorsrc
             Sets the source reference on Chart Studio Cloud for
-            color .
+            `color`.
         gradient
             :class:`plotly.graph_objects.scatterternary.marker.Grad
             ient` instance or dict with compatible properties
@@ -1142,7 +1149,7 @@ class Marker(_BaseTraceHierarchyType):
             Sets the marker opacity.
         opacitysrc
             Sets the source reference on Chart Studio Cloud for
-            opacity .
+            `opacity`.
         reversescale
             Reverses the color mapping if true. Has an effect only
             if in `marker.color`is set to a numerical array. If
@@ -1170,7 +1177,7 @@ class Marker(_BaseTraceHierarchyType):
             `sizemin` and `sizemode`.
         sizesrc
             Sets the source reference on Chart Studio Cloud for
-            size .
+            `size`.
         symbol
             Sets the marker symbol type. Adding 100 is equivalent
             to appending "-open" to a symbol name. Adding 200 is
@@ -1179,7 +1186,7 @@ class Marker(_BaseTraceHierarchyType):
             open" to a symbol name.
         symbolsrc
             Sets the source reference on Chart Studio Cloud for
-            symbol .
+            `symbol`.
         """
 
     def __init__(
@@ -1280,12 +1287,12 @@ class Marker(_BaseTraceHierarchyType):
             To control the bounds of the colorscale in color space,
             use`marker.cmin` and `marker.cmax`. Alternatively,
             `colorscale` may be a palette name string of the
-            following list: Greys,YlGnBu,Greens,YlOrRd,Bluered,RdBu
-            ,Reds,Blues,Picnic,Rainbow,Portland,Jet,Hot,Blackbody,E
-            arth,Electric,Viridis,Cividis.
+            following list: Blackbody,Bluered,Blues,Cividis,Earth,E
+            lectric,Greens,Greys,Hot,Jet,Picnic,Portland,Rainbow,Rd
+            Bu,Reds,Viridis,YlGnBu,YlOrRd.
         colorsrc
             Sets the source reference on Chart Studio Cloud for
-            color .
+            `color`.
         gradient
             :class:`plotly.graph_objects.scatterternary.marker.Grad
             ient` instance or dict with compatible properties
@@ -1299,7 +1306,7 @@ class Marker(_BaseTraceHierarchyType):
             Sets the marker opacity.
         opacitysrc
             Sets the source reference on Chart Studio Cloud for
-            opacity .
+            `opacity`.
         reversescale
             Reverses the color mapping if true. Has an effect only
             if in `marker.color`is set to a numerical array. If
@@ -1327,7 +1334,7 @@ class Marker(_BaseTraceHierarchyType):
             `sizemin` and `sizemode`.
         sizesrc
             Sets the source reference on Chart Studio Cloud for
-            size .
+            `size`.
         symbol
             Sets the marker symbol type. Adding 100 is equivalent
             to appending "-open" to a symbol name. Adding 200 is
@@ -1336,7 +1343,7 @@ class Marker(_BaseTraceHierarchyType):
             open" to a symbol name.
         symbolsrc
             Sets the source reference on Chart Studio Cloud for
-            symbol .
+            `symbol`.
 
         Returns
         -------
