@@ -4,6 +4,7 @@ if sys.version_info < (3, 7):
     from ._domain import Domain
     from ._hoverlabel import Hoverlabel
     from ._insidetextfont import Insidetextfont
+    from ._legendgrouptitle import Legendgrouptitle
     from ._marker import Marker
     from ._outsidetextfont import Outsidetextfont
     from ._pathbar import Pathbar
@@ -12,6 +13,7 @@ if sys.version_info < (3, 7):
     from ._textfont import Textfont
     from ._tiling import Tiling
     from . import hoverlabel
+    from . import legendgrouptitle
     from . import marker
     from . import pathbar
 else:
@@ -19,11 +21,12 @@ else:
 
     __all__, __getattr__, __dir__ = relative_import(
         __name__,
-        [".hoverlabel", ".marker", ".pathbar"],
+        [".hoverlabel", ".legendgrouptitle", ".marker", ".pathbar"],
         [
             "._domain.Domain",
             "._hoverlabel.Hoverlabel",
             "._insidetextfont.Insidetextfont",
+            "._legendgrouptitle.Legendgrouptitle",
             "._marker.Marker",
             "._outsidetextfont.Outsidetextfont",
             "._pathbar.Pathbar",
