@@ -6,6 +6,7 @@ if sys.version_info < (3, 7):
     from ._hoverlabel import Hoverlabel
     from ._increasing import Increasing
     from ._insidetextfont import Insidetextfont
+    from ._legendgrouptitle import Legendgrouptitle
     from ._outsidetextfont import Outsidetextfont
     from ._stream import Stream
     from ._textfont import Textfont
@@ -14,19 +15,28 @@ if sys.version_info < (3, 7):
     from . import decreasing
     from . import hoverlabel
     from . import increasing
+    from . import legendgrouptitle
     from . import totals
 else:
     from _plotly_utils.importers import relative_import
 
     __all__, __getattr__, __dir__ = relative_import(
         __name__,
-        [".connector", ".decreasing", ".hoverlabel", ".increasing", ".totals"],
+        [
+            ".connector",
+            ".decreasing",
+            ".hoverlabel",
+            ".increasing",
+            ".legendgrouptitle",
+            ".totals",
+        ],
         [
             "._connector.Connector",
             "._decreasing.Decreasing",
             "._hoverlabel.Hoverlabel",
             "._increasing.Increasing",
             "._insidetextfont.Insidetextfont",
+            "._legendgrouptitle.Legendgrouptitle",
             "._outsidetextfont.Outsidetextfont",
             "._stream.Stream",
             "._textfont.Textfont",
