@@ -44,7 +44,7 @@ class BoxValidator(_plotly_utils.basevalidators.CompoundValidator):
                 DOM elements
             customdatasrc
                 Sets the source reference on Chart Studio Cloud
-                for  customdata .
+                for `customdata`.
             dx
                 Sets the x coordinate step for multi-box traces
                 set using q1/median/q3.
@@ -64,7 +64,7 @@ class BoxValidator(_plotly_utils.basevalidators.CompoundValidator):
                 fired.
             hoverinfosrc
                 Sets the source reference on Chart Studio Cloud
-                for  hoverinfo .
+                for `hoverinfo`.
             hoverlabel
                 :class:`plotly.graph_objects.box.Hoverlabel`
                 instance or dict with compatible properties
@@ -106,12 +106,12 @@ class BoxValidator(_plotly_utils.basevalidators.CompoundValidator):
                 `<extra></extra>`.
             hovertemplatesrc
                 Sets the source reference on Chart Studio Cloud
-                for  hovertemplate .
+                for `hovertemplate`.
             hovertext
                 Same as `text`.
             hovertextsrc
                 Sets the source reference on Chart Studio Cloud
-                for  hovertext .
+                for `hovertext`.
             ids
                 Assigns id labels to each datum. These ids for
                 object constancy of data points during
@@ -119,7 +119,7 @@ class BoxValidator(_plotly_utils.basevalidators.CompoundValidator):
                 numbers or any other type.
             idssrc
                 Sets the source reference on Chart Studio Cloud
-                for  ids .
+                for `ids`.
             jitter
                 Sets the amount of jitter in the sample points
                 drawn. If 0, the sample points align along the
@@ -156,7 +156,7 @@ class BoxValidator(_plotly_utils.basevalidators.CompoundValidator):
                 below 1.5 times the IQR.
             lowerfencesrc
                 Sets the source reference on Chart Studio Cloud
-                for  lowerfence .
+                for `lowerfence`.
             marker
                 :class:`plotly.graph_objects.box.Marker`
                 instance or dict with compatible properties
@@ -170,13 +170,13 @@ class BoxValidator(_plotly_utils.basevalidators.CompoundValidator):
                 sample values.
             meansrc
                 Sets the source reference on Chart Studio Cloud
-                for  mean .
+                for `mean`.
             median
                 Sets the median values. There should be as many
                 items as the number of boxes desired.
             mediansrc
                 Sets the source reference on Chart Studio Cloud
-                for  median .
+                for `median`.
             meta
                 Assigns extra meta information associated with
                 this trace that can be used in various text
@@ -193,7 +193,7 @@ class BoxValidator(_plotly_utils.basevalidators.CompoundValidator):
                 key of the `meta` and `n` is the trace index.
             metasrc
                 Sets the source reference on Chart Studio Cloud
-                for  meta .
+                for `meta`.
             name
                 Sets the trace name. The trace name appear as
                 the legend item and on hover. For box traces,
@@ -223,7 +223,7 @@ class BoxValidator(_plotly_utils.basevalidators.CompoundValidator):
                 / sqrt(N), where N is the sample size.
             notchspansrc
                 Sets the source reference on Chart Studio Cloud
-                for  notchspan .
+                for `notchspan`.
             notchwidth
                 Sets the width of the notches relative to the
                 box' width. For example, with 0, the notches
@@ -251,13 +251,13 @@ class BoxValidator(_plotly_utils.basevalidators.CompoundValidator):
                 many items as the number of boxes desired.
             q1src
                 Sets the source reference on Chart Studio Cloud
-                for  q1 .
+                for `q1`.
             q3
                 Sets the Quartile 3 values. There should be as
                 many items as the number of boxes desired.
             q3src
                 Sets the source reference on Chart Studio Cloud
-                for  q3 .
+                for `q3`.
             quartilemethod
                 Sets the method used to compute the sample's Q1
                 and Q3 quartiles. The "linear" method uses the
@@ -285,7 +285,7 @@ class BoxValidator(_plotly_utils.basevalidators.CompoundValidator):
                 using the sample values.
             sdsrc
                 Sets the source reference on Chart Studio Cloud
-                for  sd .
+                for `sd`.
             selected
                 :class:`plotly.graph_objects.box.Selected`
                 instance or dict with compatible properties
@@ -314,7 +314,7 @@ class BoxValidator(_plotly_utils.basevalidators.CompoundValidator):
                 flag.
             textsrc
                 Sets the source reference on Chart Studio Cloud
-                for  text .
+                for `text`.
             uid
                 Assign an id to this trace, Use this to provide
                 object constancy between traces during
@@ -354,7 +354,7 @@ class BoxValidator(_plotly_utils.basevalidators.CompoundValidator):
                 above 1.5 times the IQR.
             upperfencesrc
                 Sets the source reference on Chart Studio Cloud
-                for  upperfence .
+                for `upperfence`.
             visible
                 Determines whether or not this trace is
                 visible. If "legendonly", the trace is not
@@ -422,7 +422,7 @@ class BoxValidator(_plotly_utils.basevalidators.CompoundValidator):
                 axis.
             xsrc
                 Sets the source reference on Chart Studio Cloud
-                for  x .
+                for `x`.
             y
                 Sets the y sample data or coordinates. See
                 overview for more info.
@@ -476,7 +476,7 @@ class BoxValidator(_plotly_utils.basevalidators.CompoundValidator):
                 axis.
             ysrc
                 Sets the source reference on Chart Studio Cloud
-                for  y .
+                for `y`.
 """,
             ),
             **kwargs
