@@ -77,7 +77,7 @@ class ConeValidator(_plotly_utils.basevalidators.CompoundValidator):
                 DOM elements
             customdatasrc
                 Sets the source reference on Chart Studio Cloud
-                for  customdata .
+                for `customdata`.
             hoverinfo
                 Determines which trace information appear on
                 hover. If `none` or `skip` are set, no
@@ -86,7 +86,7 @@ class ConeValidator(_plotly_utils.basevalidators.CompoundValidator):
                 fired.
             hoverinfosrc
                 Sets the source reference on Chart Studio Cloud
-                for  hoverinfo .
+                for `hoverinfo`.
             hoverlabel
                 :class:`plotly.graph_objects.cone.Hoverlabel`
                 instance or dict with compatible properties
@@ -125,12 +125,12 @@ class ConeValidator(_plotly_utils.basevalidators.CompoundValidator):
                 empty tag `<extra></extra>`.
             hovertemplatesrc
                 Sets the source reference on Chart Studio Cloud
-                for  hovertemplate .
+                for `hovertemplate`.
             hovertext
                 Same as `text`.
             hovertextsrc
                 Sets the source reference on Chart Studio Cloud
-                for  hovertext .
+                for `hovertext`.
             ids
                 Assigns id labels to each datum. These ids for
                 object constancy of data points during
@@ -138,7 +138,7 @@ class ConeValidator(_plotly_utils.basevalidators.CompoundValidator):
                 numbers or any other type.
             idssrc
                 Sets the source reference on Chart Studio Cloud
-                for  ids .
+                for `ids`.
             legendgroup
                 Sets the legend group for this trace. Traces
                 part of the same legend group hide/show at the
@@ -179,7 +179,7 @@ class ConeValidator(_plotly_utils.basevalidators.CompoundValidator):
                 key of the `meta` and `n` is the trace index.
             metasrc
                 Sets the source reference on Chart Studio Cloud
-                for  meta .
+                for `meta`.
             name
                 Sets the trace name. The trace name appear as
                 the legend item and on hover.
@@ -241,7 +241,7 @@ class ConeValidator(_plotly_utils.basevalidators.CompoundValidator):
                 will be seen in the hover labels.
             textsrc
                 Sets the source reference on Chart Studio Cloud
-                for  text .
+                for `text`.
             u
                 Sets the x components of the vector field.
             uhoverformat
@@ -279,7 +279,7 @@ class ConeValidator(_plotly_utils.basevalidators.CompoundValidator):
                 that stays with it as it moves.
             usrc
                 Sets the source reference on Chart Studio Cloud
-                for  u .
+                for `u`.
             v
                 Sets the y components of the vector field.
             vhoverformat
@@ -296,7 +296,7 @@ class ConeValidator(_plotly_utils.basevalidators.CompoundValidator):
                 (provided that the legend itself is visible).
             vsrc
                 Sets the source reference on Chart Studio Cloud
-                for  v .
+                for `v`.
             w
                 Sets the z components of the vector field.
             whoverformat
@@ -308,7 +308,7 @@ class ConeValidator(_plotly_utils.basevalidators.CompoundValidator):
                 using generic number format.
             wsrc
                 Sets the source reference on Chart Studio Cloud
-                for  w .
+                for `w`.
             x
                 Sets the x coordinates of the vector field and
                 of the displayed cones.
@@ -329,7 +329,7 @@ class ConeValidator(_plotly_utils.basevalidators.CompoundValidator):
                 formatted using `xaxis.hoverformat`.
             xsrc
                 Sets the source reference on Chart Studio Cloud
-                for  x .
+                for `x`.
             y
                 Sets the y coordinates of the vector field and
                 of the displayed cones.
@@ -350,7 +350,7 @@ class ConeValidator(_plotly_utils.basevalidators.CompoundValidator):
                 formatted using `yaxis.hoverformat`.
             ysrc
                 Sets the source reference on Chart Studio Cloud
-                for  y .
+                for `y`.
             z
                 Sets the z coordinates of the vector field and
                 of the displayed cones.
@@ -371,7 +371,7 @@ class ConeValidator(_plotly_utils.basevalidators.CompoundValidator):
                 formatted using `zaxis.hoverformat`.
             zsrc
                 Sets the source reference on Chart Studio Cloud
-                for  z .
+                for `z`.
 """,
             ),
             **kwargs
