@@ -18,7 +18,7 @@ class ContourcarpetValidator(_plotly_utils.basevalidators.CompoundValidator):
                 starting coordinate and `dx` the step.
             asrc
                 Sets the source reference on Chart Studio Cloud
-                for  a .
+                for `a`.
             atype
                 If "array", the heatmap's x coordinates are
                 given by "x" (the default behavior when `x` is
@@ -47,7 +47,7 @@ class ContourcarpetValidator(_plotly_utils.basevalidators.CompoundValidator):
                 starting coordinate and `dy` the step.
             bsrc
                 Sets the source reference on Chart Studio Cloud
-                for  b .
+                for `b`.
             btype
                 If "array", the heatmap's y coordinates are
                 given by "y" (the default behavior when `y` is
@@ -96,7 +96,7 @@ class ContourcarpetValidator(_plotly_utils.basevalidators.CompoundValidator):
                 DOM elements
             customdatasrc
                 Sets the source reference on Chart Studio Cloud
-                for  customdata .
+                for `customdata`.
             da
                 Sets the x coordinate step. See `x0` for more
                 info.
@@ -112,7 +112,7 @@ class ContourcarpetValidator(_plotly_utils.basevalidators.CompoundValidator):
                 Same as `text`.
             hovertextsrc
                 Sets the source reference on Chart Studio Cloud
-                for  hovertext .
+                for `hovertext`.
             ids
                 Assigns id labels to each datum. These ids for
                 object constancy of data points during
@@ -120,7 +120,7 @@ class ContourcarpetValidator(_plotly_utils.basevalidators.CompoundValidator):
                 numbers or any other type.
             idssrc
                 Sets the source reference on Chart Studio Cloud
-                for  ids .
+                for `ids`.
             legendgroup
                 Sets the legend group for this trace. Traces
                 part of the same legend group hide/show at the
@@ -158,7 +158,7 @@ class ContourcarpetValidator(_plotly_utils.basevalidators.CompoundValidator):
                 key of the `meta` and `n` is the trace index.
             metasrc
                 Sets the source reference on Chart Studio Cloud
-                for  meta .
+                for `meta`.
             name
                 Sets the trace name. The trace name appear as
                 the legend item and on hover.
@@ -190,7 +190,7 @@ class ContourcarpetValidator(_plotly_utils.basevalidators.CompoundValidator):
                 value.
             textsrc
                 Sets the source reference on Chart Studio Cloud
-                for  text .
+                for `text`.
             transpose
                 Transposes the z data.
             uid
@@ -260,7 +260,7 @@ class ContourcarpetValidator(_plotly_utils.basevalidators.CompoundValidator):
                 set, `zmax` must be set as well.
             zsrc
                 Sets the source reference on Chart Studio Cloud
-                for  z .
+                for `z`.
 """,
             ),
             **kwargs
