@@ -48,10 +48,10 @@ class DensitymapboxValidator(_plotly_utils.basevalidators.CompoundValidator):
                 'rgb(255,0,0)']]`. To control the bounds of the
                 colorscale in color space, use`zmin` and
                 `zmax`. Alternatively, `colorscale` may be a
-                palette name string of the following list: Grey
-                s,YlGnBu,Greens,YlOrRd,Bluered,RdBu,Reds,Blues,
-                Picnic,Rainbow,Portland,Jet,Hot,Blackbody,Earth
-                ,Electric,Viridis,Cividis.
+                palette name string of the following list: Blac
+                kbody,Bluered,Blues,Cividis,Earth,Electric,Gree
+                ns,Greys,Hot,Jet,Picnic,Portland,Rainbow,RdBu,R
+                eds,Viridis,YlGnBu,YlOrRd.
             customdata
                 Assigns extra data each datum. This may be
                 useful when listening to hover, click and
@@ -60,7 +60,7 @@ class DensitymapboxValidator(_plotly_utils.basevalidators.CompoundValidator):
                 DOM elements
             customdatasrc
                 Sets the source reference on Chart Studio Cloud
-                for  customdata .
+                for `customdata`.
             hoverinfo
                 Determines which trace information appear on
                 hover. If `none` or `skip` are set, no
@@ -69,7 +69,7 @@ class DensitymapboxValidator(_plotly_utils.basevalidators.CompoundValidator):
                 fired.
             hoverinfosrc
                 Sets the source reference on Chart Studio Cloud
-                for  hoverinfo .
+                for `hoverinfo`.
             hoverlabel
                 :class:`plotly.graph_objects.densitymapbox.Hove
                 rlabel` instance or dict with compatible
@@ -88,17 +88,16 @@ class DensitymapboxValidator(_plotly_utils.basevalidators.CompoundValidator):
                 only when this field is shown. Numbers are
                 formatted using d3-format's syntax
                 %{variable:d3-format}, for example "Price:
-                %{y:$.2f}". https://github.com/d3/d3-3.x-api-
-                reference/blob/master/Formatting.md#d3_format
-                for details on the formatting syntax. Dates are
-                formatted using d3-time-format's syntax
-                %{variable|d3-time-format}, for example "Day:
-                %{2019-01-01|%A}".
+                %{y:$.2f}". https://github.com/d3/d3-format/tre
+                e/v1.4.5#d3-format for details on the
+                formatting syntax. Dates are formatted using
+                d3-time-format's syntax %{variable|d3-time-
+                format}, for example "Day: %{2019-01-01|%A}".
                 https://github.com/d3/d3-time-
-                format#locale_format for details on the date
-                formatting syntax. The variables available in
-                `hovertemplate` are the ones emitted as event
-                data described at this link
+                format/tree/v2.2.3#locale_format for details on
+                the date formatting syntax. The variables
+                available in `hovertemplate` are the ones
+                emitted as event data described at this link
                 https://plotly.com/javascript/plotlyjs-
                 events/#event-data. Additionally, every
                 attributes that can be specified per-point (the
@@ -110,7 +109,7 @@ class DensitymapboxValidator(_plotly_utils.basevalidators.CompoundValidator):
                 `<extra></extra>`.
             hovertemplatesrc
                 Sets the source reference on Chart Studio Cloud
-                for  hovertemplate .
+                for `hovertemplate`.
             hovertext
                 Sets hover text elements associated with each
                 (lon,lat) pair If a single string, the same
@@ -121,7 +120,7 @@ class DensitymapboxValidator(_plotly_utils.basevalidators.CompoundValidator):
                 "text" flag.
             hovertextsrc
                 Sets the source reference on Chart Studio Cloud
-                for  hovertext .
+                for `hovertext`.
             ids
                 Assigns id labels to each datum. These ids for
                 object constancy of data points during
@@ -129,13 +128,13 @@ class DensitymapboxValidator(_plotly_utils.basevalidators.CompoundValidator):
                 numbers or any other type.
             idssrc
                 Sets the source reference on Chart Studio Cloud
-                for  ids .
+                for `ids`.
             lat
                 Sets the latitude coordinates (in degrees
                 North).
             latsrc
                 Sets the source reference on Chart Studio Cloud
-                for  lat .
+                for `lat`.
             legendgroup
                 Sets the legend group for this trace. Traces
                 part of the same legend group hide/show at the
@@ -159,7 +158,7 @@ class DensitymapboxValidator(_plotly_utils.basevalidators.CompoundValidator):
                 East).
             lonsrc
                 Sets the source reference on Chart Studio Cloud
-                for  lon .
+                for `lon`.
             meta
                 Assigns extra meta information associated with
                 this trace that can be used in various text
@@ -176,7 +175,7 @@ class DensitymapboxValidator(_plotly_utils.basevalidators.CompoundValidator):
                 key of the `meta` and `n` is the trace index.
             metasrc
                 Sets the source reference on Chart Studio Cloud
-                for  meta .
+                for `meta`.
             name
                 Sets the trace name. The trace name appear as
                 the legend item and on hover.
@@ -189,7 +188,7 @@ class DensitymapboxValidator(_plotly_utils.basevalidators.CompoundValidator):
                 less detailed.
             radiussrc
                 Sets the source reference on Chart Studio Cloud
-                for  radius .
+                for `radius`.
             reversescale
                 Reverses the color mapping if true. If true,
                 `zmin` will correspond to the last color in the
@@ -221,7 +220,7 @@ class DensitymapboxValidator(_plotly_utils.basevalidators.CompoundValidator):
                 seen in the hover labels.
             textsrc
                 Sets the source reference on Chart Studio Cloud
-                for  text .
+                for `text`.
             uid
                 Assign an id to this trace, Use this to provide
                 object constancy between traces during
@@ -279,7 +278,7 @@ class DensitymapboxValidator(_plotly_utils.basevalidators.CompoundValidator):
                 set, `zmax` must be set as well.
             zsrc
                 Sets the source reference on Chart Studio Cloud
-                for  z .
+                for `z`.
 """,
             ),
             **kwargs
