@@ -40,10 +40,10 @@ class HeatmapValidator(_plotly_utils.basevalidators.CompoundValidator):
                 'rgb(255,0,0)']]`. To control the bounds of the
                 colorscale in color space, use`zmin` and
                 `zmax`. Alternatively, `colorscale` may be a
-                palette name string of the following list: Grey
-                s,YlGnBu,Greens,YlOrRd,Bluered,RdBu,Reds,Blues,
-                Picnic,Rainbow,Portland,Jet,Hot,Blackbody,Earth
-                ,Electric,Viridis,Cividis.
+                palette name string of the following list: Blac
+                kbody,Bluered,Blues,Cividis,Earth,Electric,Gree
+                ns,Greys,Hot,Jet,Picnic,Portland,Rainbow,RdBu,R
+                eds,Viridis,YlGnBu,YlOrRd.
             connectgaps
                 Determines whether or not gaps (i.e. {nan} or
                 missing values) in the `z` data are filled in.
@@ -58,7 +58,7 @@ class HeatmapValidator(_plotly_utils.basevalidators.CompoundValidator):
                 DOM elements
             customdatasrc
                 Sets the source reference on Chart Studio Cloud
-                for  customdata .
+                for `customdata`.
             dx
                 Sets the x coordinate step. See `x0` for more
                 info.
@@ -73,7 +73,7 @@ class HeatmapValidator(_plotly_utils.basevalidators.CompoundValidator):
                 fired.
             hoverinfosrc
                 Sets the source reference on Chart Studio Cloud
-                for  hoverinfo .
+                for `hoverinfo`.
             hoverlabel
                 :class:`plotly.graph_objects.heatmap.Hoverlabel
                 ` instance or dict with compatible properties
@@ -95,17 +95,16 @@ class HeatmapValidator(_plotly_utils.basevalidators.CompoundValidator):
                 only when this field is shown. Numbers are
                 formatted using d3-format's syntax
                 %{variable:d3-format}, for example "Price:
-                %{y:$.2f}". https://github.com/d3/d3-3.x-api-
-                reference/blob/master/Formatting.md#d3_format
-                for details on the formatting syntax. Dates are
-                formatted using d3-time-format's syntax
-                %{variable|d3-time-format}, for example "Day:
-                %{2019-01-01|%A}".
+                %{y:$.2f}". https://github.com/d3/d3-format/tre
+                e/v1.4.5#d3-format for details on the
+                formatting syntax. Dates are formatted using
+                d3-time-format's syntax %{variable|d3-time-
+                format}, for example "Day: %{2019-01-01|%A}".
                 https://github.com/d3/d3-time-
-                format#locale_format for details on the date
-                formatting syntax. The variables available in
-                `hovertemplate` are the ones emitted as event
-                data described at this link
+                format/tree/v2.2.3#locale_format for details on
+                the date formatting syntax. The variables
+                available in `hovertemplate` are the ones
+                emitted as event data described at this link
                 https://plotly.com/javascript/plotlyjs-
                 events/#event-data. Additionally, every
                 attributes that can be specified per-point (the
@@ -117,12 +116,12 @@ class HeatmapValidator(_plotly_utils.basevalidators.CompoundValidator):
                 `<extra></extra>`.
             hovertemplatesrc
                 Sets the source reference on Chart Studio Cloud
-                for  hovertemplate .
+                for `hovertemplate`.
             hovertext
                 Same as `text`.
             hovertextsrc
                 Sets the source reference on Chart Studio Cloud
-                for  hovertext .
+                for `hovertext`.
             ids
                 Assigns id labels to each datum. These ids for
                 object constancy of data points during
@@ -130,7 +129,7 @@ class HeatmapValidator(_plotly_utils.basevalidators.CompoundValidator):
                 numbers or any other type.
             idssrc
                 Sets the source reference on Chart Studio Cloud
-                for  ids .
+                for `ids`.
             legendgroup
                 Sets the legend group for this trace. Traces
                 part of the same legend group hide/show at the
@@ -165,7 +164,7 @@ class HeatmapValidator(_plotly_utils.basevalidators.CompoundValidator):
                 key of the `meta` and `n` is the trace index.
             metasrc
                 Sets the source reference on Chart Studio Cloud
-                for  meta .
+                for `meta`.
             name
                 Sets the trace name. The trace name appear as
                 the legend item and on hover.
@@ -190,7 +189,7 @@ class HeatmapValidator(_plotly_utils.basevalidators.CompoundValidator):
                 value.
             textsrc
                 Sets the source reference on Chart Studio Cloud
-                for  text .
+                for `text`.
             transpose
                 Transposes the z data.
             uid
@@ -246,18 +245,17 @@ class HeatmapValidator(_plotly_utils.basevalidators.CompoundValidator):
                 Sets the hover text formatting rulefor `x`
                 using d3 formatting mini-languages which are
                 very similar to those in Python. For numbers,
-                see: https://github.com/d3/d3-3.x-api-
-                reference/blob/master/Formatting.md#d3_format.
-                And for dates see:
+                see: https://github.com/d3/d3-format/tree/v1.4.
+                5#d3-format. And for dates see:
                 https://github.com/d3/d3-time-
-                format#locale_format. We add two items to d3's
-                date formatter: "%h" for half of the year as a
-                decimal number as well as "%{n}f" for
-                fractional seconds with n digits. For example,
-                *2016-10-13 09:15:23.456* with tickformat
-                "%H~%M~%S.%2f" would display *09~15~23.46*By
-                default the values are formatted using
-                `xaxis.hoverformat`.
+                format/tree/v2.2.3#locale_format. We add two
+                items to d3's date formatter: "%h" for half of
+                the year as a decimal number as well as "%{n}f"
+                for fractional seconds with n digits. For
+                example, *2016-10-13 09:15:23.456* with
+                tickformat "%H~%M~%S.%2f" would display
+                *09~15~23.46*By default the values are
+                formatted using `xaxis.hoverformat`.
             xperiod
                 Only relevant when the axis `type` is "date".
                 Sets the period positioning in milliseconds or
@@ -279,7 +277,7 @@ class HeatmapValidator(_plotly_utils.basevalidators.CompoundValidator):
                 axis.
             xsrc
                 Sets the source reference on Chart Studio Cloud
-                for  x .
+                for `x`.
             xtype
                 If "array", the heatmap's x coordinates are
                 given by "x" (the default behavior when `x` is
@@ -308,18 +306,17 @@ class HeatmapValidator(_plotly_utils.basevalidators.CompoundValidator):
                 Sets the hover text formatting rulefor `y`
                 using d3 formatting mini-languages which are
                 very similar to those in Python. For numbers,
-                see: https://github.com/d3/d3-3.x-api-
-                reference/blob/master/Formatting.md#d3_format.
-                And for dates see:
+                see: https://github.com/d3/d3-format/tree/v1.4.
+                5#d3-format. And for dates see:
                 https://github.com/d3/d3-time-
-                format#locale_format. We add two items to d3's
-                date formatter: "%h" for half of the year as a
-                decimal number as well as "%{n}f" for
-                fractional seconds with n digits. For example,
-                *2016-10-13 09:15:23.456* with tickformat
-                "%H~%M~%S.%2f" would display *09~15~23.46*By
-                default the values are formatted using
-                `yaxis.hoverformat`.
+                format/tree/v2.2.3#locale_format. We add two
+                items to d3's date formatter: "%h" for half of
+                the year as a decimal number as well as "%{n}f"
+                for fractional seconds with n digits. For
+                example, *2016-10-13 09:15:23.456* with
+                tickformat "%H~%M~%S.%2f" would display
+                *09~15~23.46*By default the values are
+                formatted using `yaxis.hoverformat`.
             yperiod
                 Only relevant when the axis `type` is "date".
                 Sets the period positioning in milliseconds or
@@ -341,7 +338,7 @@ class HeatmapValidator(_plotly_utils.basevalidators.CompoundValidator):
                 axis.
             ysrc
                 Sets the source reference on Chart Studio Cloud
-                for  y .
+                for `y`.
             ytype
                 If "array", the heatmap's y coordinates are
                 given by "y" (the default behavior when `y` is
@@ -360,10 +357,9 @@ class HeatmapValidator(_plotly_utils.basevalidators.CompoundValidator):
                 Sets the hover text formatting rulefor `z`
                 using d3 formatting mini-languages which are
                 very similar to those in Python. For numbers,
-                see: https://github.com/d3/d3-3.x-api-reference
-                /blob/master/Formatting.md#d3_format.By default
-                the values are formatted using generic number
-                format.
+                see: https://github.com/d3/d3-format/tree/v1.4.
+                5#d3-format.By default the values are formatted
+                using generic number format.
             zmax
                 Sets the upper bound of the color domain. Value
                 should have the same units as in `z` and if
@@ -383,7 +379,7 @@ class HeatmapValidator(_plotly_utils.basevalidators.CompoundValidator):
                 data.
             zsrc
                 Sets the source reference on Chart Studio Cloud
-                for  z .
+                for `z`.
 """,
             ),
             **kwargs
