@@ -52,7 +52,7 @@ class HeatmapglValidator(_plotly_utils.basevalidators.CompoundValidator):
                 DOM elements
             customdatasrc
                 Sets the source reference on Chart Studio Cloud
-                for  customdata .
+                for `customdata`.
             dx
                 Sets the x coordinate step. See `x0` for more
                 info.
@@ -67,7 +67,7 @@ class HeatmapglValidator(_plotly_utils.basevalidators.CompoundValidator):
                 fired.
             hoverinfosrc
                 Sets the source reference on Chart Studio Cloud
-                for  hoverinfo .
+                for `hoverinfo`.
             hoverlabel
                 :class:`plotly.graph_objects.heatmapgl.Hoverlab
                 el` instance or dict with compatible properties
@@ -78,7 +78,7 @@ class HeatmapglValidator(_plotly_utils.basevalidators.CompoundValidator):
                 numbers or any other type.
             idssrc
                 Sets the source reference on Chart Studio Cloud
-                for  ids .
+                for `ids`.
             legendgrouptitle
                 :class:`plotly.graph_objects.heatmapgl.Legendgr
                 ouptitle` instance or dict with compatible
@@ -109,7 +109,7 @@ class HeatmapglValidator(_plotly_utils.basevalidators.CompoundValidator):
                 key of the `meta` and `n` is the trace index.
             metasrc
                 Sets the source reference on Chart Studio Cloud
-                for  meta .
+                for `meta`.
             name
                 Sets the trace name. The trace name appear as
                 the legend item and on hover.
@@ -131,7 +131,7 @@ class HeatmapglValidator(_plotly_utils.basevalidators.CompoundValidator):
                 value.
             textsrc
                 Sets the source reference on Chart Studio Cloud
-                for  text .
+                for `text`.
             transpose
                 Transposes the z data.
             uid
@@ -179,7 +179,7 @@ class HeatmapglValidator(_plotly_utils.basevalidators.CompoundValidator):
                 refer to `layout.xaxis2`, and so on.
             xsrc
                 Sets the source reference on Chart Studio Cloud
-                for  x .
+                for `x`.
             xtype
                 If "array", the heatmap's x coordinates are
                 given by "x" (the default behavior when `x` is
@@ -200,7 +200,7 @@ class HeatmapglValidator(_plotly_utils.basevalidators.CompoundValidator):
                 refer to `layout.yaxis2`, and so on.
             ysrc
                 Sets the source reference on Chart Studio Cloud
-                for  y .
+                for `y`.
             ytype
                 If "array", the heatmap's y coordinates are
                 given by "y" (the default behavior when `y` is
@@ -234,7 +234,7 @@ class HeatmapglValidator(_plotly_utils.basevalidators.CompoundValidator):
                 data.
             zsrc
                 Sets the source reference on Chart Studio Cloud
-                for  z .
+                for `z`.
 """,
             ),
             **kwargs
