@@ -64,10 +64,10 @@ class Histogram2DcontourValidator(_plotly_utils.basevalidators.CompoundValidator
                 'rgb(255,0,0)']]`. To control the bounds of the
                 colorscale in color space, use`zmin` and
                 `zmax`. Alternatively, `colorscale` may be a
-                palette name string of the following list: Grey
-                s,YlGnBu,Greens,YlOrRd,Bluered,RdBu,Reds,Blues,
-                Picnic,Rainbow,Portland,Jet,Hot,Blackbody,Earth
-                ,Electric,Viridis,Cividis.
+                palette name string of the following list: Blac
+                kbody,Bluered,Blues,Cividis,Earth,Electric,Gree
+                ns,Greys,Hot,Jet,Picnic,Portland,Rainbow,RdBu,R
+                eds,Viridis,YlGnBu,YlOrRd.
             contours
                 :class:`plotly.graph_objects.histogram2dcontour
                 .Contours` instance or dict with compatible
@@ -80,7 +80,7 @@ class Histogram2DcontourValidator(_plotly_utils.basevalidators.CompoundValidator
                 DOM elements
             customdatasrc
                 Sets the source reference on Chart Studio Cloud
-                for  customdata .
+                for `customdata`.
             histfunc
                 Specifies the binning function used for this
                 histogram trace. If "count", the histogram
@@ -116,7 +116,7 @@ class Histogram2DcontourValidator(_plotly_utils.basevalidators.CompoundValidator
                 fired.
             hoverinfosrc
                 Sets the source reference on Chart Studio Cloud
-                for  hoverinfo .
+                for `hoverinfo`.
             hoverlabel
                 :class:`plotly.graph_objects.histogram2dcontour
                 .Hoverlabel` instance or dict with compatible
@@ -135,17 +135,16 @@ class Histogram2DcontourValidator(_plotly_utils.basevalidators.CompoundValidator
                 only when this field is shown. Numbers are
                 formatted using d3-format's syntax
                 %{variable:d3-format}, for example "Price:
-                %{y:$.2f}". https://github.com/d3/d3-3.x-api-
-                reference/blob/master/Formatting.md#d3_format
-                for details on the formatting syntax. Dates are
-                formatted using d3-time-format's syntax
-                %{variable|d3-time-format}, for example "Day:
-                %{2019-01-01|%A}".
+                %{y:$.2f}". https://github.com/d3/d3-format/tre
+                e/v1.4.5#d3-format for details on the
+                formatting syntax. Dates are formatted using
+                d3-time-format's syntax %{variable|d3-time-
+                format}, for example "Day: %{2019-01-01|%A}".
                 https://github.com/d3/d3-time-
-                format#locale_format for details on the date
-                formatting syntax. The variables available in
-                `hovertemplate` are the ones emitted as event
-                data described at this link
+                format/tree/v2.2.3#locale_format for details on
+                the date formatting syntax. The variables
+                available in `hovertemplate` are the ones
+                emitted as event data described at this link
                 https://plotly.com/javascript/plotlyjs-
                 events/#event-data. Additionally, every
                 attributes that can be specified per-point (the
@@ -157,7 +156,7 @@ class Histogram2DcontourValidator(_plotly_utils.basevalidators.CompoundValidator
                 empty tag `<extra></extra>`.
             hovertemplatesrc
                 Sets the source reference on Chart Studio Cloud
-                for  hovertemplate .
+                for `hovertemplate`.
             ids
                 Assigns id labels to each datum. These ids for
                 object constancy of data points during
@@ -165,11 +164,15 @@ class Histogram2DcontourValidator(_plotly_utils.basevalidators.CompoundValidator
                 numbers or any other type.
             idssrc
                 Sets the source reference on Chart Studio Cloud
-                for  ids .
+                for `ids`.
             legendgroup
                 Sets the legend group for this trace. Traces
                 part of the same legend group hide/show at the
                 same time when toggling legend items.
+            legendgrouptitle
+                :class:`plotly.graph_objects.histogram2dcontour
+                .Legendgrouptitle` instance or dict with
+                compatible properties
             legendrank
                 Sets the legend rank for this trace. Items and
                 groups with smaller ranks are presented on
@@ -204,7 +207,7 @@ class Histogram2DcontourValidator(_plotly_utils.basevalidators.CompoundValidator
                 key of the `meta` and `n` is the trace index.
             metasrc
                 Sets the source reference on Chart Studio Cloud
-                for  meta .
+                for `meta`.
             name
                 Sets the trace name. The trace name appear as
                 the legend item and on hover.
@@ -300,18 +303,23 @@ class Histogram2DcontourValidator(_plotly_utils.basevalidators.CompoundValidator
                 Sets the calendar system to use with `x` date
                 data.
             xhoverformat
-                Sets the hover text formatting rule for `x`
+                Sets the hover text formatting rulefor `x`
                 using d3 formatting mini-languages which are
-                very similar to those in Python. See:
-                https://github.com/d3/d3-3.x-api-
-                reference/blob/master/Formatting.md#d3_format
-                And for dates see:
+                very similar to those in Python. For numbers,
+                see: https://github.com/d3/d3-format/tree/v1.4.
+                5#d3-format. And for dates see:
                 https://github.com/d3/d3-time-
-                format#locale_format By default the values are
+                format/tree/v2.2.3#locale_format. We add two
+                items to d3's date formatter: "%h" for half of
+                the year as a decimal number as well as "%{n}f"
+                for fractional seconds with n digits. For
+                example, *2016-10-13 09:15:23.456* with
+                tickformat "%H~%M~%S.%2f" would display
+                *09~15~23.46*By default the values are
                 formatted using `xaxis.hoverformat`.
             xsrc
                 Sets the source reference on Chart Studio Cloud
-                for  x .
+                for `x`.
             y
                 Sets the sample data to be binned on the y
                 axis.
@@ -337,18 +345,23 @@ class Histogram2DcontourValidator(_plotly_utils.basevalidators.CompoundValidator
                 Sets the calendar system to use with `y` date
                 data.
             yhoverformat
-                Sets the hover text formatting rule for `y`
+                Sets the hover text formatting rulefor `y`
                 using d3 formatting mini-languages which are
-                very similar to those in Python. See:
-                https://github.com/d3/d3-3.x-api-
-                reference/blob/master/Formatting.md#d3_format
-                And for dates see:
+                very similar to those in Python. For numbers,
+                see: https://github.com/d3/d3-format/tree/v1.4.
+                5#d3-format. And for dates see:
                 https://github.com/d3/d3-time-
-                format#locale_format By default the values are
+                format/tree/v2.2.3#locale_format. We add two
+                items to d3's date formatter: "%h" for half of
+                the year as a decimal number as well as "%{n}f"
+                for fractional seconds with n digits. For
+                example, *2016-10-13 09:15:23.456* with
+                tickformat "%H~%M~%S.%2f" would display
+                *09~15~23.46*By default the values are
                 formatted using `yaxis.hoverformat`.
             ysrc
                 Sets the source reference on Chart Studio Cloud
-                for  y .
+                for `y`.
             z
                 Sets the aggregation data.
             zauto
@@ -358,13 +371,12 @@ class Histogram2DcontourValidator(_plotly_utils.basevalidators.CompoundValidator
                 Defaults to `false` when `zmin` and `zmax` are
                 set by the user.
             zhoverformat
-                Sets the hover text formatting rule for `z`
+                Sets the hover text formatting rulefor `z`
                 using d3 formatting mini-languages which are
-                very similar to those in Python. See:
-                https://github.com/d3/d3-3.x-api-
-                reference/blob/master/Formatting.md#d3_format
-                By default the values are formatted using
-                generic number format.
+                very similar to those in Python. For numbers,
+                see: https://github.com/d3/d3-format/tree/v1.4.
+                5#d3-format.By default the values are formatted
+                using generic number format.
             zmax
                 Sets the upper bound of the color domain. Value
                 should have the same units as in `z` and if
@@ -381,7 +393,7 @@ class Histogram2DcontourValidator(_plotly_utils.basevalidators.CompoundValidator
                 set, `zmax` must be set as well.
             zsrc
                 Sets the source reference on Chart Studio Cloud
-                for  z .
+                for `z`.
 """,
             ),
             **kwargs
