@@ -21,7 +21,7 @@ class PieValidator(_plotly_utils.basevalidators.CompoundValidator):
                 DOM elements
             customdatasrc
                 Sets the source reference on Chart Studio Cloud
-                for  customdata .
+                for `customdata`.
             direction
                 Specifies the direction at which succeeding
                 sectors follow one another.
@@ -42,7 +42,7 @@ class PieValidator(_plotly_utils.basevalidators.CompoundValidator):
                 fired.
             hoverinfosrc
                 Sets the source reference on Chart Studio Cloud
-                for  hoverinfo .
+                for `hoverinfo`.
             hoverlabel
                 :class:`plotly.graph_objects.pie.Hoverlabel`
                 instance or dict with compatible properties
@@ -82,7 +82,7 @@ class PieValidator(_plotly_utils.basevalidators.CompoundValidator):
                 `<extra></extra>`.
             hovertemplatesrc
                 Sets the source reference on Chart Studio Cloud
-                for  hovertemplate .
+                for `hovertemplate`.
             hovertext
                 Sets hover text elements associated with each
                 sector. If a single string, the same string
@@ -92,7 +92,7 @@ class PieValidator(_plotly_utils.basevalidators.CompoundValidator):
                 must contain a "text" flag.
             hovertextsrc
                 Sets the source reference on Chart Studio Cloud
-                for  hovertext .
+                for `hovertext`.
             ids
                 Assigns id labels to each datum. These ids for
                 object constancy of data points during
@@ -100,7 +100,7 @@ class PieValidator(_plotly_utils.basevalidators.CompoundValidator):
                 numbers or any other type.
             idssrc
                 Sets the source reference on Chart Studio Cloud
-                for  ids .
+                for `ids`.
             insidetextfont
                 Sets the font used for `textinfo` lying inside
                 the sector.
@@ -128,7 +128,7 @@ class PieValidator(_plotly_utils.basevalidators.CompoundValidator):
                 all occurrences of the label.
             labelssrc
                 Sets the source reference on Chart Studio Cloud
-                for  labels .
+                for `labels`.
             legendgroup
                 Sets the legend group for this trace. Traces
                 part of the same legend group hide/show at the
@@ -165,7 +165,7 @@ class PieValidator(_plotly_utils.basevalidators.CompoundValidator):
                 key of the `meta` and `n` is the trace index.
             metasrc
                 Sets the source reference on Chart Studio Cloud
-                for  meta .
+                for `meta`.
             name
                 Sets the trace name. The trace name appear as
                 the legend item and on hover.
@@ -182,7 +182,7 @@ class PieValidator(_plotly_utils.basevalidators.CompoundValidator):
                 more slices.
             pullsrc
                 Sets the source reference on Chart Studio Cloud
-                for  pull .
+                for `pull`.
             rotation
                 Instead of the first slice starting at 12
                 o'clock, rotate to some other angle.
@@ -216,10 +216,10 @@ class PieValidator(_plotly_utils.basevalidators.CompoundValidator):
                 Specifies the location of the `textinfo`.
             textpositionsrc
                 Sets the source reference on Chart Studio Cloud
-                for  textposition .
+                for `textposition`.
             textsrc
                 Sets the source reference on Chart Studio Cloud
-                for  text .
+                for `text`.
             texttemplate
                 Template string used for rendering the
                 information text that appear on points. Note
@@ -241,7 +241,7 @@ class PieValidator(_plotly_utils.basevalidators.CompoundValidator):
                 `text`.
             texttemplatesrc
                 Sets the source reference on Chart Studio Cloud
-                for  texttemplate .
+                for `texttemplate`.
             title
                 :class:`plotly.graph_objects.pie.Title`
                 instance or dict with compatible properties
@@ -287,7 +287,7 @@ class PieValidator(_plotly_utils.basevalidators.CompoundValidator):
                 count occurrences of each label.
             valuessrc
                 Sets the source reference on Chart Studio Cloud
-                for  values .
+                for `values`.
             visible
                 Determines whether or not this trace is
                 visible. If "legendonly", the trace is not
