@@ -28,7 +28,7 @@ class ScatterValidator(_plotly_utils.basevalidators.CompoundValidator):
                 DOM elements
             customdatasrc
                 Sets the source reference on Chart Studio Cloud
-                for  customdata .
+                for `customdata`.
             dx
                 Sets the x coordinate step. See `x0` for more
                 info.
@@ -94,7 +94,7 @@ class ScatterValidator(_plotly_utils.basevalidators.CompoundValidator):
                 fired.
             hoverinfosrc
                 Sets the source reference on Chart Studio Cloud
-                for  hoverinfo .
+                for `hoverinfo`.
             hoverlabel
                 :class:`plotly.graph_objects.scatter.Hoverlabel
                 ` instance or dict with compatible properties
@@ -119,17 +119,16 @@ class ScatterValidator(_plotly_utils.basevalidators.CompoundValidator):
                 only when this field is shown. Numbers are
                 formatted using d3-format's syntax
                 %{variable:d3-format}, for example "Price:
-                %{y:$.2f}". https://github.com/d3/d3-3.x-api-
-                reference/blob/master/Formatting.md#d3_format
-                for details on the formatting syntax. Dates are
-                formatted using d3-time-format's syntax
-                %{variable|d3-time-format}, for example "Day:
-                %{2019-01-01|%A}".
+                %{y:$.2f}". https://github.com/d3/d3-format/tre
+                e/v1.4.5#d3-format for details on the
+                formatting syntax. Dates are formatted using
+                d3-time-format's syntax %{variable|d3-time-
+                format}, for example "Day: %{2019-01-01|%A}".
                 https://github.com/d3/d3-time-
-                format#locale_format for details on the date
-                formatting syntax. The variables available in
-                `hovertemplate` are the ones emitted as event
-                data described at this link
+                format/tree/v2.2.3#locale_format for details on
+                the date formatting syntax. The variables
+                available in `hovertemplate` are the ones
+                emitted as event data described at this link
                 https://plotly.com/javascript/plotlyjs-
                 events/#event-data. Additionally, every
                 attributes that can be specified per-point (the
@@ -141,7 +140,7 @@ class ScatterValidator(_plotly_utils.basevalidators.CompoundValidator):
                 `<extra></extra>`.
             hovertemplatesrc
                 Sets the source reference on Chart Studio Cloud
-                for  hovertemplate .
+                for `hovertemplate`.
             hovertext
                 Sets hover text elements associated with each
                 (x,y) pair. If a single string, the same string
@@ -151,7 +150,7 @@ class ScatterValidator(_plotly_utils.basevalidators.CompoundValidator):
                 trace `hoverinfo` must contain a "text" flag.
             hovertextsrc
                 Sets the source reference on Chart Studio Cloud
-                for  hovertext .
+                for `hovertext`.
             ids
                 Assigns id labels to each datum. These ids for
                 object constancy of data points during
@@ -159,7 +158,7 @@ class ScatterValidator(_plotly_utils.basevalidators.CompoundValidator):
                 numbers or any other type.
             idssrc
                 Sets the source reference on Chart Studio Cloud
-                for  ids .
+                for `ids`.
             legendgroup
                 Sets the legend group for this trace. Traces
                 part of the same legend group hide/show at the
@@ -200,7 +199,7 @@ class ScatterValidator(_plotly_utils.basevalidators.CompoundValidator):
                 key of the `meta` and `n` is the trace index.
             metasrc
                 Sets the source reference on Chart Studio Cloud
-                for  meta .
+                for `meta`.
             mode
                 Determines the drawing mode for this scatter
                 trace. If the provided `mode` includes "text"
@@ -286,10 +285,10 @@ class ScatterValidator(_plotly_utils.basevalidators.CompoundValidator):
                 respects to the (x,y) coordinates.
             textpositionsrc
                 Sets the source reference on Chart Studio Cloud
-                for  textposition .
+                for `textposition`.
             textsrc
                 Sets the source reference on Chart Studio Cloud
-                for  text .
+                for `text`.
             texttemplate
                 Template string used for rendering the
                 information text that appear on points. Note
@@ -297,21 +296,19 @@ class ScatterValidator(_plotly_utils.basevalidators.CompoundValidator):
                 are inserted using %{variable}, for example "y:
                 %{y}". Numbers are formatted using d3-format's
                 syntax %{variable:d3-format}, for example
-                "Price: %{y:$.2f}".
-                https://github.com/d3/d3-3.x-api-
-                reference/blob/master/Formatting.md#d3_format
-                for details on the formatting syntax. Dates are
-                formatted using d3-time-format's syntax
-                %{variable|d3-time-format}, for example "Day:
-                %{2019-01-01|%A}".
+                "Price: %{y:$.2f}". https://github.com/d3/d3-fo
+                rmat/tree/v1.4.5#d3-format for details on the
+                formatting syntax. Dates are formatted using
+                d3-time-format's syntax %{variable|d3-time-
+                format}, for example "Day: %{2019-01-01|%A}".
                 https://github.com/d3/d3-time-
-                format#locale_format for details on the date
-                formatting syntax. Every attributes that can be
-                specified per-point (the ones that are
-                `arrayOk: true`) are available.
+                format/tree/v2.2.3#locale_format for details on
+                the date formatting syntax. Every attributes
+                that can be specified per-point (the ones that
+                are `arrayOk: true`) are available.
             texttemplatesrc
                 Sets the source reference on Chart Studio Cloud
-                for  texttemplate .
+                for `texttemplate`.
             uid
                 Assign an id to this trace, Use this to provide
                 object constancy between traces during
@@ -365,18 +362,17 @@ class ScatterValidator(_plotly_utils.basevalidators.CompoundValidator):
                 Sets the hover text formatting rulefor `x`
                 using d3 formatting mini-languages which are
                 very similar to those in Python. For numbers,
-                see: https://github.com/d3/d3-3.x-api-
-                reference/blob/master/Formatting.md#d3_format.
-                And for dates see:
+                see: https://github.com/d3/d3-format/tree/v1.4.
+                5#d3-format. And for dates see:
                 https://github.com/d3/d3-time-
-                format#locale_format. We add two items to d3's
-                date formatter: "%h" for half of the year as a
-                decimal number as well as "%{n}f" for
-                fractional seconds with n digits. For example,
-                *2016-10-13 09:15:23.456* with tickformat
-                "%H~%M~%S.%2f" would display *09~15~23.46*By
-                default the values are formatted using
-                `xaxis.hoverformat`.
+                format/tree/v2.2.3#locale_format. We add two
+                items to d3's date formatter: "%h" for half of
+                the year as a decimal number as well as "%{n}f"
+                for fractional seconds with n digits. For
+                example, *2016-10-13 09:15:23.456* with
+                tickformat "%H~%M~%S.%2f" would display
+                *09~15~23.46*By default the values are
+                formatted using `xaxis.hoverformat`.
             xperiod
                 Only relevant when the axis `type` is "date".
                 Sets the period positioning in milliseconds or
@@ -398,7 +394,7 @@ class ScatterValidator(_plotly_utils.basevalidators.CompoundValidator):
                 axis.
             xsrc
                 Sets the source reference on Chart Studio Cloud
-                for  x .
+                for `x`.
             y
                 Sets the y coordinates.
             y0
@@ -418,18 +414,17 @@ class ScatterValidator(_plotly_utils.basevalidators.CompoundValidator):
                 Sets the hover text formatting rulefor `y`
                 using d3 formatting mini-languages which are
                 very similar to those in Python. For numbers,
-                see: https://github.com/d3/d3-3.x-api-
-                reference/blob/master/Formatting.md#d3_format.
-                And for dates see:
+                see: https://github.com/d3/d3-format/tree/v1.4.
+                5#d3-format. And for dates see:
                 https://github.com/d3/d3-time-
-                format#locale_format. We add two items to d3's
-                date formatter: "%h" for half of the year as a
-                decimal number as well as "%{n}f" for
-                fractional seconds with n digits. For example,
-                *2016-10-13 09:15:23.456* with tickformat
-                "%H~%M~%S.%2f" would display *09~15~23.46*By
-                default the values are formatted using
-                `yaxis.hoverformat`.
+                format/tree/v2.2.3#locale_format. We add two
+                items to d3's date formatter: "%h" for half of
+                the year as a decimal number as well as "%{n}f"
+                for fractional seconds with n digits. For
+                example, *2016-10-13 09:15:23.456* with
+                tickformat "%H~%M~%S.%2f" would display
+                *09~15~23.46*By default the values are
+                formatted using `yaxis.hoverformat`.
             yperiod
                 Only relevant when the axis `type` is "date".
                 Sets the period positioning in milliseconds or
@@ -451,7 +446,7 @@ class ScatterValidator(_plotly_utils.basevalidators.CompoundValidator):
                 axis.
             ysrc
                 Sets the source reference on Chart Studio Cloud
-                for  y .
+                for `y`.
 """,
             ),
             **kwargs
