@@ -19,7 +19,7 @@ class ScatterternaryValidator(_plotly_utils.basevalidators.CompoundValidator):
                 `ternary<i>.sum`.
             asrc
                 Sets the source reference on Chart Studio Cloud
-                for  a .
+                for `a`.
             b
                 Sets the quantity of component `a` in each data
                 point. If `a`, `b`, and `c` are all provided,
@@ -29,7 +29,7 @@ class ScatterternaryValidator(_plotly_utils.basevalidators.CompoundValidator):
                 `ternary<i>.sum`.
             bsrc
                 Sets the source reference on Chart Studio Cloud
-                for  b .
+                for `b`.
             c
                 Sets the quantity of component `a` in each data
                 point. If `a`, `b`, and `c` are all provided,
@@ -49,7 +49,7 @@ class ScatterternaryValidator(_plotly_utils.basevalidators.CompoundValidator):
                 connected.
             csrc
                 Sets the source reference on Chart Studio Cloud
-                for  c .
+                for `c`.
             customdata
                 Assigns extra data each datum. This may be
                 useful when listening to hover, click and
@@ -58,7 +58,7 @@ class ScatterternaryValidator(_plotly_utils.basevalidators.CompoundValidator):
                 DOM elements
             customdatasrc
                 Sets the source reference on Chart Studio Cloud
-                for  customdata .
+                for `customdata`.
             fill
                 Sets the area to fill with a solid color. Use
                 with `fillcolor` if not "none". scatterternary
@@ -84,7 +84,7 @@ class ScatterternaryValidator(_plotly_utils.basevalidators.CompoundValidator):
                 fired.
             hoverinfosrc
                 Sets the source reference on Chart Studio Cloud
-                for  hoverinfo .
+                for `hoverinfo`.
             hoverlabel
                 :class:`plotly.graph_objects.scatterternary.Hov
                 erlabel` instance or dict with compatible
@@ -131,7 +131,7 @@ class ScatterternaryValidator(_plotly_utils.basevalidators.CompoundValidator):
                 `<extra></extra>`.
             hovertemplatesrc
                 Sets the source reference on Chart Studio Cloud
-                for  hovertemplate .
+                for `hovertemplate`.
             hovertext
                 Sets hover text elements associated with each
                 (a,b,c) point. If a single string, the same
@@ -141,7 +141,7 @@ class ScatterternaryValidator(_plotly_utils.basevalidators.CompoundValidator):
                 trace `hoverinfo` must contain a "text" flag.
             hovertextsrc
                 Sets the source reference on Chart Studio Cloud
-                for  hovertext .
+                for `hovertext`.
             ids
                 Assigns id labels to each datum. These ids for
                 object constancy of data points during
@@ -149,7 +149,7 @@ class ScatterternaryValidator(_plotly_utils.basevalidators.CompoundValidator):
                 numbers or any other type.
             idssrc
                 Sets the source reference on Chart Studio Cloud
-                for  ids .
+                for `ids`.
             legendgroup
                 Sets the legend group for this trace. Traces
                 part of the same legend group hide/show at the
@@ -191,7 +191,7 @@ class ScatterternaryValidator(_plotly_utils.basevalidators.CompoundValidator):
                 key of the `meta` and `n` is the trace index.
             metasrc
                 Sets the source reference on Chart Studio Cloud
-                for  meta .
+                for `meta`.
             mode
                 Determines the drawing mode for this scatter
                 trace. If the provided `mode` includes "text"
@@ -254,10 +254,10 @@ class ScatterternaryValidator(_plotly_utils.basevalidators.CompoundValidator):
                 respects to the (x,y) coordinates.
             textpositionsrc
                 Sets the source reference on Chart Studio Cloud
-                for  textposition .
+                for `textposition`.
             textsrc
                 Sets the source reference on Chart Studio Cloud
-                for  text .
+                for `text`.
             texttemplate
                 Template string used for rendering the
                 information text that appear on points. Note
@@ -278,7 +278,7 @@ class ScatterternaryValidator(_plotly_utils.basevalidators.CompoundValidator):
                 `a`, `b`, `c` and `text`.
             texttemplatesrc
                 Sets the source reference on Chart Studio Cloud
-                for  texttemplate .
+                for `texttemplate`.
             uid
                 Assign an id to this trace, Use this to provide
                 object constancy between traces during
