@@ -30,7 +30,7 @@ class SunburstValidator(_plotly_utils.basevalidators.CompoundValidator):
                 DOM elements
             customdatasrc
                 Sets the source reference on Chart Studio Cloud
-                for  customdata .
+                for `customdata`.
             domain
                 :class:`plotly.graph_objects.sunburst.Domain`
                 instance or dict with compatible properties
@@ -42,7 +42,7 @@ class SunburstValidator(_plotly_utils.basevalidators.CompoundValidator):
                 fired.
             hoverinfosrc
                 Sets the source reference on Chart Studio Cloud
-                for  hoverinfo .
+                for `hoverinfo`.
             hoverlabel
                 :class:`plotly.graph_objects.sunburst.Hoverlabe
                 l` instance or dict with compatible properties
@@ -60,17 +60,16 @@ class SunburstValidator(_plotly_utils.basevalidators.CompoundValidator):
                 only when this field is shown. Numbers are
                 formatted using d3-format's syntax
                 %{variable:d3-format}, for example "Price:
-                %{y:$.2f}". https://github.com/d3/d3-3.x-api-
-                reference/blob/master/Formatting.md#d3_format
-                for details on the formatting syntax. Dates are
-                formatted using d3-time-format's syntax
-                %{variable|d3-time-format}, for example "Day:
-                %{2019-01-01|%A}".
+                %{y:$.2f}". https://github.com/d3/d3-format/tre
+                e/v1.4.5#d3-format for details on the
+                formatting syntax. Dates are formatted using
+                d3-time-format's syntax %{variable|d3-time-
+                format}, for example "Day: %{2019-01-01|%A}".
                 https://github.com/d3/d3-time-
-                format#locale_format for details on the date
-                formatting syntax. The variables available in
-                `hovertemplate` are the ones emitted as event
-                data described at this link
+                format/tree/v2.2.3#locale_format for details on
+                the date formatting syntax. The variables
+                available in `hovertemplate` are the ones
+                emitted as event data described at this link
                 https://plotly.com/javascript/plotlyjs-
                 events/#event-data. Additionally, every
                 attributes that can be specified per-point (the
@@ -84,7 +83,7 @@ class SunburstValidator(_plotly_utils.basevalidators.CompoundValidator):
                 empty tag `<extra></extra>`.
             hovertemplatesrc
                 Sets the source reference on Chart Studio Cloud
-                for  hovertemplate .
+                for `hovertemplate`.
             hovertext
                 Sets hover text elements associated with each
                 sector. If a single string, the same string
@@ -94,7 +93,7 @@ class SunburstValidator(_plotly_utils.basevalidators.CompoundValidator):
                 must contain a "text" flag.
             hovertextsrc
                 Sets the source reference on Chart Studio Cloud
-                for  hovertext .
+                for `hovertext`.
             ids
                 Assigns id labels to each datum. These ids for
                 object constancy of data points during
@@ -102,7 +101,7 @@ class SunburstValidator(_plotly_utils.basevalidators.CompoundValidator):
                 numbers or any other type.
             idssrc
                 Sets the source reference on Chart Studio Cloud
-                for  ids .
+                for `ids`.
             insidetextfont
                 Sets the font used for `textinfo` lying inside
                 the sector.
@@ -121,7 +120,7 @@ class SunburstValidator(_plotly_utils.basevalidators.CompoundValidator):
                 Sets the labels of each of the sectors.
             labelssrc
                 Sets the source reference on Chart Studio Cloud
-                for  labels .
+                for `labels`.
             leaf
                 :class:`plotly.graph_objects.sunburst.Leaf`
                 instance or dict with compatible properties
@@ -168,7 +167,7 @@ class SunburstValidator(_plotly_utils.basevalidators.CompoundValidator):
                 key of the `meta` and `n` is the trace index.
             metasrc
                 Sets the source reference on Chart Studio Cloud
-                for  meta .
+                for `meta`.
             name
                 Sets the trace name. The trace name appear as
                 the legend item and on hover.
@@ -191,7 +190,7 @@ class SunburstValidator(_plotly_utils.basevalidators.CompoundValidator):
                 `labels`, but beware they must be unique.
             parentssrc
                 Sets the source reference on Chart Studio Cloud
-                for  parents .
+                for `parents`.
             root
                 :class:`plotly.graph_objects.sunburst.Root`
                 instance or dict with compatible properties
@@ -219,7 +218,7 @@ class SunburstValidator(_plotly_utils.basevalidators.CompoundValidator):
                 the graph.
             textsrc
                 Sets the source reference on Chart Studio Cloud
-                for  text .
+                for `text`.
             texttemplate
                 Template string used for rendering the
                 information text that appear on points. Note
@@ -227,24 +226,22 @@ class SunburstValidator(_plotly_utils.basevalidators.CompoundValidator):
                 are inserted using %{variable}, for example "y:
                 %{y}". Numbers are formatted using d3-format's
                 syntax %{variable:d3-format}, for example
-                "Price: %{y:$.2f}".
-                https://github.com/d3/d3-3.x-api-
-                reference/blob/master/Formatting.md#d3_format
-                for details on the formatting syntax. Dates are
-                formatted using d3-time-format's syntax
-                %{variable|d3-time-format}, for example "Day:
-                %{2019-01-01|%A}".
+                "Price: %{y:$.2f}". https://github.com/d3/d3-fo
+                rmat/tree/v1.4.5#d3-format for details on the
+                formatting syntax. Dates are formatted using
+                d3-time-format's syntax %{variable|d3-time-
+                format}, for example "Day: %{2019-01-01|%A}".
                 https://github.com/d3/d3-time-
-                format#locale_format for details on the date
-                formatting syntax. Every attributes that can be
-                specified per-point (the ones that are
-                `arrayOk: true`) are available. variables
+                format/tree/v2.2.3#locale_format for details on
+                the date formatting syntax. Every attributes
+                that can be specified per-point (the ones that
+                are `arrayOk: true`) are available. variables
                 `currentPath`, `root`, `entry`, `percentRoot`,
                 `percentEntry`, `percentParent`, `label` and
                 `value`.
             texttemplatesrc
                 Sets the source reference on Chart Studio Cloud
-                for  texttemplate .
+                for `texttemplate`.
             uid
                 Assign an id to this trace, Use this to provide
                 object constancy between traces during
@@ -277,7 +274,7 @@ class SunburstValidator(_plotly_utils.basevalidators.CompoundValidator):
                 how the values are summed.
             valuessrc
                 Sets the source reference on Chart Studio Cloud
-                for  values .
+                for `values`.
             visible
                 Determines whether or not this trace is
                 visible. If "legendonly", the trace is not
