@@ -48,6 +48,7 @@ if sys.version_info < (3, 7):
     from ._meta import MetaValidator
     from ._marker import MarkerValidator
     from ._legendrank import LegendrankValidator
+    from ._legendgrouptitle import LegendgrouptitleValidator
     from ._legendgroup import LegendgroupValidator
     from ._insidetextfont import InsidetextfontValidator
     from ._insidetextanchor import InsidetextanchorValidator
@@ -125,6 +126,7 @@ else:
             "._meta.MetaValidator",
             "._marker.MarkerValidator",
             "._legendrank.LegendrankValidator",
+            "._legendgrouptitle.LegendgrouptitleValidator",
             "._legendgroup.LegendgroupValidator",
             "._insidetextfont.InsidetextfontValidator",
             "._insidetextanchor.InsidetextanchorValidator",
