@@ -14,7 +14,7 @@ class InsidetextfontValidator(_plotly_utils.basevalidators.CompoundValidator):
 
             colorsrc
                 Sets the source reference on Chart Studio Cloud
-                for  color .
+                for `color`.
             family
                 HTML font family - the typeface that will be
                 applied by the web browser. The web browser
@@ -34,12 +34,12 @@ class InsidetextfontValidator(_plotly_utils.basevalidators.CompoundValidator):
                 Narrow", "Raleway", "Times New Roman".
             familysrc
                 Sets the source reference on Chart Studio Cloud
-                for  family .
+                for `family`.
             size
 
             sizesrc
                 Sets the source reference on Chart Studio Cloud
-                for  size .
+                for `size`.
 """,
             ),
             **kwargs
