@@ -79,12 +79,12 @@ class MarkerValidator(_plotly_utils.basevalidators.CompoundValidator):
                 color space, use`marker.cmin` and
                 `marker.cmax`. Alternatively, `colorscale` may
                 be a palette name string of the following list:
-                Greys,YlGnBu,Greens,YlOrRd,Bluered,RdBu,Reds,Bl
-                ues,Picnic,Rainbow,Portland,Jet,Hot,Blackbody,E
-                arth,Electric,Viridis,Cividis.
+                Blackbody,Bluered,Blues,Cividis,Earth,Electric,
+                Greens,Greys,Hot,Jet,Picnic,Portland,Rainbow,Rd
+                Bu,Reds,Viridis,YlGnBu,YlOrRd.
             colorsrc
                 Sets the source reference on Chart Studio Cloud
-                for  color .
+                for `color`.
             line
                 :class:`plotly.graph_objects.bar.marker.Line`
                 instance or dict with compatible properties
@@ -92,7 +92,9 @@ class MarkerValidator(_plotly_utils.basevalidators.CompoundValidator):
                 Sets the opacity of the bars.
             opacitysrc
                 Sets the source reference on Chart Studio Cloud
-                for  opacity .
+                for `opacity`.
+            pattern
+                Sets the pattern within the marker.
             reversescale
                 Reverses the color mapping if true. Has an
                 effect only if in `marker.color`is set to a
