@@ -2,14 +2,10 @@ import _plotly_utils.basevalidators
 
 
 class ColorValidator(_plotly_utils.basevalidators.ColorValidator):
-
-    def __init__(
-        self, plotly_name='color', parent_name='bar.error_x', **kwargs
-    ):
+    def __init__(self, plotly_name="color", parent_name="bar.error_x", **kwargs):
         super(ColorValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type=kwargs.pop('edit_type', 'style'),
-            role=kwargs.pop('role', 'style'),
+            edit_type=kwargs.pop("edit_type", "style"),
             **kwargs
         )
