@@ -2,15 +2,11 @@ import _plotly_utils.basevalidators
 
 
 class ThicknessValidator(_plotly_utils.basevalidators.NumberValidator):
-
-    def __init__(
-        self, plotly_name='thickness', parent_name='bar.error_x', **kwargs
-    ):
+    def __init__(self, plotly_name="thickness", parent_name="bar.error_x", **kwargs):
         super(ThicknessValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type=kwargs.pop('edit_type', 'style'),
-            min=kwargs.pop('min', 0),
-            role=kwargs.pop('role', 'style'),
+            edit_type=kwargs.pop("edit_type", "style"),
+            min=kwargs.pop("min", 0),
             **kwargs
         )
