@@ -2,18 +2,13 @@ import _plotly_utils.basevalidators
 
 
 class XanchorValidator(_plotly_utils.basevalidators.EnumeratedValidator):
-
     def __init__(
-        self,
-        plotly_name='xanchor',
-        parent_name='bar.marker.colorbar',
-        **kwargs
+        self, plotly_name="xanchor", parent_name="bar.marker.colorbar", **kwargs
     ):
         super(XanchorValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type=kwargs.pop('edit_type', 'colorbars'),
-            role=kwargs.pop('role', 'style'),
-            values=kwargs.pop('values', ['left', 'center', 'right']),
+            edit_type=kwargs.pop("edit_type", "colorbars"),
+            values=kwargs.pop("values", ["left", "center", "right"]),
             **kwargs
         )
