@@ -2,15 +2,11 @@ import _plotly_utils.basevalidators
 
 
 class XpadValidator(_plotly_utils.basevalidators.NumberValidator):
-
-    def __init__(
-        self, plotly_name='xpad', parent_name='bar.marker.colorbar', **kwargs
-    ):
+    def __init__(self, plotly_name="xpad", parent_name="bar.marker.colorbar", **kwargs):
         super(XpadValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type=kwargs.pop('edit_type', 'colorbars'),
-            min=kwargs.pop('min', 0),
-            role=kwargs.pop('role', 'style'),
+            edit_type=kwargs.pop("edit_type", "colorbars"),
+            min=kwargs.pop("min", 0),
             **kwargs
         )
