@@ -15,10 +15,9 @@ class DtickrangeValidator(_plotly_utils.basevalidators.InfoArrayValidator):
             items=kwargs.pop(
                 "items",
                 [
-                    {"valType": "any", "editType": "colorbars"},
-                    {"valType": "any", "editType": "colorbars"},
+                    {"editType": "colorbars", "valType": "any"},
+                    {"editType": "colorbars", "valType": "any"},
                 ],
             ),
-            role=kwargs.pop("role", "info"),
             **kwargs
         )
