@@ -2,15 +2,13 @@ import _plotly_utils.basevalidators
 
 
 class ColorValidator(_plotly_utils.basevalidators.ColorValidator):
-
     def __init__(
-        self, plotly_name='color', parent_name='bar.outsidetextfont', **kwargs
+        self, plotly_name="color", parent_name="bar.outsidetextfont", **kwargs
     ):
         super(ColorValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            array_ok=kwargs.pop('array_ok', True),
-            edit_type=kwargs.pop('edit_type', 'style'),
-            role=kwargs.pop('role', 'style'),
+            array_ok=kwargs.pop("array_ok", True),
+            edit_type=kwargs.pop("edit_type", "style"),
             **kwargs
         )
