@@ -128,17 +128,17 @@ class ColorbarValidator(_plotly_utils.basevalidators.CompoundValidator):
             tickformat
                 Sets the tick label formatting rule using d3
                 formatting mini-languages which are very
-                similar to those in Python. For numbers, see:
-                https://github.com/d3/d3-3.x-api-
-                reference/blob/master/Formatting.md#d3_format.
-                And for dates see:
+                similar to those in Python. For numbers, see: h
+                ttps://github.com/d3/d3-format/tree/v1.4.5#d3-f
+                ormat. And for dates see:
                 https://github.com/d3/d3-time-
-                format#locale_format. We add two items to d3's
-                date formatter: "%h" for half of the year as a
-                decimal number as well as "%{n}f" for
-                fractional seconds with n digits. For example,
-                *2016-10-13 09:15:23.456* with tickformat
-                "%H~%M~%S.%2f" would display "09~15~23.46"
+                format/tree/v2.2.3#locale_format. We add two
+                items to d3's date formatter: "%h" for half of
+                the year as a decimal number as well as "%{n}f"
+                for fractional seconds with n digits. For
+                example, *2016-10-13 09:15:23.456* with
+                tickformat "%H~%M~%S.%2f" would display
+                "09~15~23.46"
             tickformatstops
                 A tuple of :class:`plotly.graph_objects.barpola
                 r.marker.colorbar.Tickformatstop` instances or
@@ -186,14 +186,14 @@ class ColorbarValidator(_plotly_utils.basevalidators.CompoundValidator):
                 `tickvals`.
             ticktextsrc
                 Sets the source reference on Chart Studio Cloud
-                for  ticktext .
+                for `ticktext`.
             tickvals
                 Sets the values at which ticks on this axis
                 appear. Only has an effect if `tickmode` is set
                 to "array". Used with `ticktext`.
             tickvalssrc
                 Sets the source reference on Chart Studio Cloud
-                for  tickvals .
+                for `tickvals`.
             tickwidth
                 Sets the tick width (in px).
             title
