@@ -2,17 +2,12 @@ import _plotly_utils.basevalidators
 
 
 class TickangleValidator(_plotly_utils.basevalidators.AngleValidator):
-
     def __init__(
-        self,
-        plotly_name='tickangle',
-        parent_name='barpolar.marker.colorbar',
-        **kwargs
+        self, plotly_name="tickangle", parent_name="barpolar.marker.colorbar", **kwargs
     ):
         super(TickangleValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type=kwargs.pop('edit_type', 'colorbars'),
-            role=kwargs.pop('role', 'style'),
+            edit_type=kwargs.pop("edit_type", "colorbars"),
             **kwargs
         )
