@@ -2,26 +2,23 @@ import _plotly_utils.basevalidators
 
 
 class MarkerValidator(_plotly_utils.basevalidators.CompoundValidator):
-
     def __init__(
-        self,
-        plotly_name='marker',
-        parent_name='barpolar.unselected',
-        **kwargs
+        self, plotly_name="marker", parent_name="barpolar.unselected", **kwargs
     ):
         super(MarkerValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            data_class_str=kwargs.pop('data_class_str', 'Marker'),
+            data_class_str=kwargs.pop("data_class_str", "Marker"),
             data_docs=kwargs.pop(
-                'data_docs', """
+                "data_docs",
+                """
             color
                 Sets the marker color of unselected points,
                 applied only when a selection exists.
             opacity
                 Sets the marker opacity of unselected points,
                 applied only when a selection exists.
-"""
+""",
             ),
             **kwargs
         )
