@@ -2,12 +2,10 @@ import _plotly_utils.basevalidators
 
 
 class X0Validator(_plotly_utils.basevalidators.AnyValidator):
-
-    def __init__(self, plotly_name='x0', parent_name='box', **kwargs):
+    def __init__(self, plotly_name="x0", parent_name="box", **kwargs):
         super(X0Validator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type=kwargs.pop('edit_type', 'calc+clearAxisTypes'),
-            role=kwargs.pop('role', 'info'),
+            edit_type=kwargs.pop("edit_type", "calc+clearAxisTypes"),
             **kwargs
         )
