@@ -16,6 +16,7 @@ if sys.version_info < (3, 7):
     from ._metasrc import MetasrcValidator
     from ._meta import MetaValidator
     from ._legendrank import LegendrankValidator
+    from ._legendgrouptitle import LegendgrouptitleValidator
     from ._idssrc import IdssrcValidator
     from ._ids import IdsValidator
     from ._font import FontValidator
@@ -56,6 +57,7 @@ else:
             "._metasrc.MetasrcValidator",
             "._meta.MetaValidator",
             "._legendrank.LegendrankValidator",
+            "._legendgrouptitle.LegendgrouptitleValidator",
             "._idssrc.IdssrcValidator",
             "._ids.IdsValidator",
             "._font.FontValidator",
