@@ -32,7 +32,7 @@ class BaxisValidator(_plotly_utils.basevalidators.CompoundValidator):
                 is set to "array". Used with `categoryorder`.
             categoryarraysrc
                 Sets the source reference on Chart Studio Cloud
-                for  categoryarray .
+                for `categoryarray`.
             categoryorder
                 Specifies the ordering logic for the case of
                 categorical variables. By default, plotly uses
@@ -173,14 +173,17 @@ class BaxisValidator(_plotly_utils.basevalidators.CompoundValidator):
             tickformat
                 Sets the tick label formatting rule using d3
                 formatting mini-languages which are very
-                similar to those in Python. For numbers, see:
-                https://github.com/d3/d3-3.x-api-
-                reference/blob/master/Formatting.md#d3_format
-                And for dates see:  We add one item to d3's
-                date formatter: "%{n}f" for fractional seconds
-                with n digits. For example, *2016-10-13
-                09:15:23.456* with tickformat "%H~%M~%S.%2f"
-                would display "09~15~23.46"
+                similar to those in Python. For numbers, see: h
+                ttps://github.com/d3/d3-format/tree/v1.4.5#d3-f
+                ormat. And for dates see:
+                https://github.com/d3/d3-time-
+                format/tree/v2.2.3#locale_format. We add two
+                items to d3's date formatter: "%h" for half of
+                the year as a decimal number as well as "%{n}f"
+                for fractional seconds with n digits. For
+                example, *2016-10-13 09:15:23.456* with
+                tickformat "%H~%M~%S.%2f" would display
+                "09~15~23.46"
             tickformatstops
                 A tuple of :class:`plotly.graph_objects.carpet.
                 baxis.Tickformatstop` instances or dicts with
@@ -203,14 +206,14 @@ class BaxisValidator(_plotly_utils.basevalidators.CompoundValidator):
                 `tickvals`.
             ticktextsrc
                 Sets the source reference on Chart Studio Cloud
-                for  ticktext .
+                for `ticktext`.
             tickvals
                 Sets the values at which ticks on this axis
                 appear. Only has an effect if `tickmode` is set
                 to "array". Used with `ticktext`.
             tickvalssrc
                 Sets the source reference on Chart Studio Cloud
-                for  tickvals .
+                for `tickvals`.
             title
                 :class:`plotly.graph_objects.carpet.baxis.Title
                 ` instance or dict with compatible properties
