@@ -2,14 +2,10 @@ import _plotly_utils.basevalidators
 
 
 class TickformatValidator(_plotly_utils.basevalidators.StringValidator):
-
-    def __init__(
-        self, plotly_name='tickformat', parent_name='carpet.aaxis', **kwargs
-    ):
+    def __init__(self, plotly_name="tickformat", parent_name="carpet.aaxis", **kwargs):
         super(TickformatValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type=kwargs.pop('edit_type', 'calc'),
-            role=kwargs.pop('role', 'style'),
+            edit_type=kwargs.pop("edit_type", "calc"),
             **kwargs
         )
