@@ -2,14 +2,10 @@ import _plotly_utils.basevalidators
 
 
 class TicktextValidator(_plotly_utils.basevalidators.DataArrayValidator):
-
-    def __init__(
-        self, plotly_name='ticktext', parent_name='carpet.aaxis', **kwargs
-    ):
+    def __init__(self, plotly_name="ticktext", parent_name="carpet.aaxis", **kwargs):
         super(TicktextValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type=kwargs.pop('edit_type', 'calc'),
-            role=kwargs.pop('role', 'data'),
+            edit_type=kwargs.pop("edit_type", "calc"),
             **kwargs
         )
