@@ -10,10 +10,9 @@ class RangeValidator(_plotly_utils.basevalidators.InfoArrayValidator):
             items=kwargs.pop(
                 "items",
                 [
-                    {"valType": "any", "editType": "calc"},
-                    {"valType": "any", "editType": "calc"},
+                    {"editType": "calc", "valType": "any"},
+                    {"editType": "calc", "valType": "any"},
                 ],
             ),
-            role=kwargs.pop("role", "info"),
             **kwargs
         )
