@@ -2,17 +2,15 @@ import _plotly_utils.basevalidators
 
 
 class NameValidator(_plotly_utils.basevalidators.StringValidator):
-
     def __init__(
         self,
-        plotly_name='name',
-        parent_name='choropleth.colorbar.tickformatstop',
+        plotly_name="name",
+        parent_name="choropleth.colorbar.tickformatstop",
         **kwargs
     ):
         super(NameValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type=kwargs.pop('edit_type', 'colorbars'),
-            role=kwargs.pop('role', 'style'),
+            edit_type=kwargs.pop("edit_type", "colorbars"),
             **kwargs
         )
