@@ -19,13 +19,13 @@ class LineValidator(_plotly_utils.basevalidators.CompoundValidator):
                 set.
             colorsrc
                 Sets the source reference on Chart Studio Cloud
-                for  color .
+                for `color`.
             width
                 Sets the width (in px) of the lines bounding
                 the marker points.
             widthsrc
                 Sets the source reference on Chart Studio Cloud
-                for  width .
+                for `width`.
 """,
             ),
             **kwargs
