@@ -38,6 +38,7 @@ if sys.version_info < (3, 7):
     from ._lightposition import LightpositionValidator
     from ._lighting import LightingValidator
     from ._legendrank import LegendrankValidator
+    from ._legendgrouptitle import LegendgrouptitleValidator
     from ._legendgroup import LegendgroupValidator
     from ._idssrc import IdssrcValidator
     from ._ids import IdsValidator
@@ -103,6 +104,7 @@ else:
             "._lightposition.LightpositionValidator",
             "._lighting.LightingValidator",
             "._legendrank.LegendrankValidator",
+            "._legendgrouptitle.LegendgrouptitleValidator",
             "._legendgroup.LegendgroupValidator",
             "._idssrc.IdssrcValidator",
             "._ids.IdsValidator",
