@@ -45,6 +45,7 @@ if sys.version_info < (3, 7):
     from ._meta import MetaValidator
     from ._line import LineValidator
     from ._legendrank import LegendrankValidator
+    from ._legendgrouptitle import LegendgrouptitleValidator
     from ._legendgroup import LegendgroupValidator
     from ._idssrc import IdssrcValidator
     from ._ids import IdsValidator
@@ -119,6 +120,7 @@ else:
             "._meta.MetaValidator",
             "._line.LineValidator",
             "._legendrank.LegendrankValidator",
+            "._legendgrouptitle.LegendgrouptitleValidator",
             "._legendgroup.LegendgroupValidator",
             "._idssrc.IdssrcValidator",
             "._ids.IdsValidator",
