@@ -2,13 +2,11 @@ import _plotly_utils.basevalidators
 
 
 class YtypeValidator(_plotly_utils.basevalidators.EnumeratedValidator):
-
-    def __init__(self, plotly_name='ytype', parent_name='contour', **kwargs):
+    def __init__(self, plotly_name="ytype", parent_name="contour", **kwargs):
         super(YtypeValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type=kwargs.pop('edit_type', 'calc+clearAxisTypes'),
-            role=kwargs.pop('role', 'info'),
-            values=kwargs.pop('values', ['array', 'scaled']),
+            edit_type=kwargs.pop("edit_type", "calc+clearAxisTypes"),
+            values=kwargs.pop("values", ["array", "scaled"]),
             **kwargs
         )
