@@ -2,16 +2,16 @@ import _plotly_utils.basevalidators
 
 
 class TickfontValidator(_plotly_utils.basevalidators.CompoundValidator):
-
     def __init__(
-        self, plotly_name='tickfont', parent_name='contour.colorbar', **kwargs
+        self, plotly_name="tickfont", parent_name="contour.colorbar", **kwargs
     ):
         super(TickfontValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            data_class_str=kwargs.pop('data_class_str', 'Tickfont'),
+            data_class_str=kwargs.pop("data_class_str", "Tickfont"),
             data_docs=kwargs.pop(
-                'data_docs', """
+                "data_docs",
+                """
             color
 
             family
@@ -22,17 +22,18 @@ class TickfontValidator(_plotly_utils.basevalidators.CompoundValidator):
                 Provide multiple font families, separated by
                 commas, to indicate the preference in which to
                 apply fonts if they aren't available on the
-                system. The plotly service (at https://plot.ly
-                or on-premise) generates images on a server,
-                where only a select number of fonts are
-                installed and supported. These include "Arial",
-                "Balto", "Courier New", "Droid Sans",, "Droid
-                Serif", "Droid Sans Mono", "Gravitas One", "Old
+                system. The Chart Studio Cloud (at
+                https://chart-studio.plotly.com or on-premise)
+                generates images on a server, where only a
+                select number of fonts are installed and
+                supported. These include "Arial", "Balto",
+                "Courier New", "Droid Sans",, "Droid Serif",
+                "Droid Sans Mono", "Gravitas One", "Old
                 Standard TT", "Open Sans", "Overpass", "PT Sans
                 Narrow", "Raleway", "Times New Roman".
             size
 
-"""
+""",
             ),
             **kwargs
         )
