@@ -2,16 +2,14 @@ import _plotly_utils.basevalidators
 
 
 class TitleValidator(_plotly_utils.basevalidators.TitleValidator):
-
-    def __init__(
-        self, plotly_name='title', parent_name='contour.colorbar', **kwargs
-    ):
+    def __init__(self, plotly_name="title", parent_name="contour.colorbar", **kwargs):
         super(TitleValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            data_class_str=kwargs.pop('data_class_str', 'Title'),
+            data_class_str=kwargs.pop("data_class_str", "Title"),
             data_docs=kwargs.pop(
-                'data_docs', """
+                "data_docs",
+                """
             font
                 Sets this color bar's title font. Note that the
                 title's font used to be set by the now
@@ -27,7 +25,7 @@ class TitleValidator(_plotly_utils.basevalidators.TitleValidator):
                 title's contents used to be defined as the
                 `title` attribute itself. This behavior has
                 been deprecated.
-"""
+""",
             ),
             **kwargs
         )
