@@ -2,18 +2,13 @@ import _plotly_utils.basevalidators
 
 
 class SideValidator(_plotly_utils.basevalidators.EnumeratedValidator):
-
     def __init__(
-        self,
-        plotly_name='side',
-        parent_name='contour.colorbar.title',
-        **kwargs
+        self, plotly_name="side", parent_name="contour.colorbar.title", **kwargs
     ):
         super(SideValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type=kwargs.pop('edit_type', 'colorbars'),
-            role=kwargs.pop('role', 'style'),
-            values=kwargs.pop('values', ['right', 'top', 'bottom']),
+            edit_type=kwargs.pop("edit_type", "colorbars"),
+            values=kwargs.pop("values", ["right", "top", "bottom"]),
             **kwargs
         )
