@@ -24,6 +24,7 @@ if sys.version_info < (3, 7):
     from ._meta import MetaValidator
     from ._marker import MarkerValidator
     from ._legendrank import LegendrankValidator
+    from ._legendgrouptitle import LegendgrouptitleValidator
     from ._legendgroup import LegendgroupValidator
     from ._labelssrc import LabelssrcValidator
     from ._labels import LabelsValidator
@@ -74,6 +75,7 @@ else:
             "._meta.MetaValidator",
             "._marker.MarkerValidator",
             "._legendrank.LegendrankValidator",
+            "._legendgrouptitle.LegendgrouptitleValidator",
             "._legendgroup.LegendgroupValidator",
             "._labelssrc.LabelssrcValidator",
             "._labels.LabelsValidator",
