@@ -2,15 +2,11 @@ import _plotly_utils.basevalidators
 
 
 class NticksValidator(_plotly_utils.basevalidators.IntegerValidator):
-
-    def __init__(
-        self, plotly_name='nticks', parent_name='heatmap.colorbar', **kwargs
-    ):
+    def __init__(self, plotly_name="nticks", parent_name="heatmap.colorbar", **kwargs):
         super(NticksValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type=kwargs.pop('edit_type', 'colorbars'),
-            min=kwargs.pop('min', 0),
-            role=kwargs.pop('role', 'style'),
+            edit_type=kwargs.pop("edit_type", "colorbars"),
+            min=kwargs.pop("min", 0),
             **kwargs
         )
