@@ -2,17 +2,12 @@ import _plotly_utils.basevalidators
 
 
 class ColorValidator(_plotly_utils.basevalidators.ColorValidator):
-
     def __init__(
-        self,
-        plotly_name='color',
-        parent_name='heatmap.colorbar.title.font',
-        **kwargs
+        self, plotly_name="color", parent_name="heatmap.colorbar.title.font", **kwargs
     ):
         super(ColorValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type=kwargs.pop('edit_type', 'colorbars'),
-            role=kwargs.pop('role', 'style'),
+            edit_type=kwargs.pop("edit_type", "colorbars"),
             **kwargs
         )
